@@ -29,7 +29,7 @@ class _DiffOp {
 
 class _DiffOp_Copy extends _DiffOp {
     var $type = 'copy';
-    
+
     function __construct($orig, $closing = false) {
         if (!is_array($closing))
             $closing = $orig;
@@ -44,7 +44,7 @@ class _DiffOp_Copy extends _DiffOp {
 
 class _DiffOp_Delete extends _DiffOp {
     var $type = 'delete';
-    
+
     function __construct($lines) {
         $this->orig = $lines;
         $this->closing = false;
@@ -57,7 +57,7 @@ class _DiffOp_Delete extends _DiffOp {
 
 class _DiffOp_Add extends _DiffOp {
     var $type = 'add';
-    
+
     function __construct($lines) {
         $this->closing = $lines;
         $this->orig = false;
@@ -70,7 +70,7 @@ class _DiffOp_Add extends _DiffOp {
 
 class _DiffOp_Change extends _DiffOp {
     var $type = 'change';
-    
+
     function __construct($orig, $closing) {
         $this->orig = $orig;
         $this->closing = $closing;
@@ -818,6 +818,39 @@ class DiffFormatter {
     }
 }
 
+/**
+ * Utilityclass for styling HTML formatted diffs
+ *
+ * Depends on global var $DIFF_INLINESTYLES, if true some minimal predefined
+ * inline styles are used. Useful for HTML mails and RSS feeds
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+class HTMLDiff {
+    /**
+     * Holds the style names and basic CSS
+     */
+    static public $styles = array(
+            'diff-addedline'    => 'background-color: #ddffdd;',
+            'diff-deletedline'  => 'background-color: #ffdddd;',
+            'diff-context'      => 'background-color: #f5f5f5;',
+            'diff-mark'         => 'color: #ff0000;',
+        );
+
+    /**
+     * Return a class or style parameter
+     */
+    static function css($classname){
+        global $DIFF_INLINESTYLES;
+
+        if($DIFF_INLINESTYLES){
+            if(!isset(self::$styles[$classname])) return '';
+            return 'style="'.self::$styles[$classname].'"';
+        }else{
+            return 'class="'.$classname.'"';
+        }
+    }
+}
 
 /**
  *  Additions by Axel Boldt follow, partly taken from diff.php, phpwiki-1.3.3
@@ -838,11 +871,11 @@ class _HWLDF_WordAccumulator {
     function _flushGroup($new_tag) {
         if ($this->_group !== '') {
             if ($this->_tag == 'mark')
-                $this->_line .= '<strong>'.$this->_group.'</strong>';
+                $this->_line .= '<strong '.HTMLDiff::css('diff-mark').'>'.$this->_group.'</strong>';
             elseif ($this->_tag == 'add')
-                $this->_line .= '<span class="diff-addedline">'.$this->_group.'</span>';
+                $this->_line .= '<span '.HTMLDiff::css('diff-addedline').'>'.$this->_group.'</span>';
             elseif ($this->_tag == 'del')
-                $this->_line .= '<span class="diff-deletedline"><del>'.$this->_group.'</del></span>';
+                $this->_line .= '<span '.HTMLDiff::css('diff-deletedline').'><del>'.$this->_group.'</del></span>';
             else
                 $this->_line .= $this->_group;
         }
@@ -924,7 +957,7 @@ class WordLevelDiff extends MappedDiff {
 }
 
 class InlineWordLevelDiff extends MappedDiff {
-    
+
     function __construct($orig_lines, $closing_lines) {
         list ($orig_words, $orig_stripped) = $this->_split($orig_lines);
         list ($closing_words, $closing_stripped) = $this->_split($closing_lines);
@@ -1006,8 +1039,8 @@ class TableDiffFormatter extends DiffFormatter {
         // Preserve whitespaces by converting some to non-breaking spaces.
         // Do not convert all of them to allow word-wrap.
         $val = parent::format($diff);
-        $val = str_replace('  ','&nbsp; ', $val);
-        $val = preg_replace('/ (?=<)|(?<=[ >]) /', '&nbsp;', $val);
+        $val = str_replace('  ','&#160; ', $val);
+        $val = preg_replace('/ (?=<)|(?<=[ >]) /', '&#160;', $val);
         return $val;
     }
 
@@ -1020,8 +1053,8 @@ class TableDiffFormatter extends DiffFormatter {
         global $lang;
         $l1 = $lang['line'].' '.$xbeg;
         $l2 = $lang['line'].' '.$ybeg;
-        $r = '<tr><td class="diff-blockheader" colspan="2">'.$l1.":</td>\n".
-             '<td class="diff-blockheader" colspan="2">'.$l2.":</td>\n".
+        $r = '<tr><td '.HTMLDiff::css('diff-blockheader').' colspan="2">'.$l1.":</td>\n".
+             '<td '.HTMLDiff::css('diff-blockheader').' colspan="2">'.$l2.":</td>\n".
              "</tr>\n";
         return $r;
     }
@@ -1037,19 +1070,19 @@ class TableDiffFormatter extends DiffFormatter {
     }
 
     function addedLine($line) {
-        return '<td>+</td><td class="diff-addedline">' .  $line.'</td>';
+        return '<td>+</td><td '.HTMLDiff::css('diff-addedline').'>' .  $line.'</td>';
     }
 
     function deletedLine($line) {
-        return '<td>-</td><td class="diff-deletedline">' .  $line.'</td>';
+        return '<td>-</td><td '.HTMLDiff::css('diff-deletedline').'>' .  $line.'</td>';
     }
 
     function emptyLine() {
-        return '<td colspan="2">&nbsp;</td>';
+        return '<td colspan="2">&#160;</td>';
     }
 
     function contextLine($line) {
-        return '<td> </td><td class="diff-context">'.$line.'</td>';
+        return '<td> </td><td '.HTMLDiff::css('diff-context').'>'.$line.'</td>';
     }
 
     function _added($lines) {
@@ -1099,8 +1132,8 @@ class InlineDiffFormatter extends DiffFormatter {
         // Preserve whitespaces by converting some to non-breaking spaces.
         // Do not convert all of them to allow word-wrap.
         $val = parent::format($diff);
-        $val = str_replace('  ','&nbsp; ', $val);
-        $val = preg_replace('/ (?=<)|(?<=[ >]) /', '&nbsp;', $val);
+        $val = str_replace('  ','&#160; ', $val);
+        $val = preg_replace('/ (?=<)|(?<=[ >]) /', '&#160;', $val);
         return $val;
     }
 
@@ -1115,9 +1148,9 @@ class InlineDiffFormatter extends DiffFormatter {
             $xbeg .= "," . $xlen;
         if ($ylen != 1)
             $ybeg .= "," . $ylen;
-        $r = '<tr><td colspan="'.$this->colspan.'" class="diff-blockheader">@@ '.$lang['line']." -$xbeg +$ybeg @@";
-        $r .= ' <span class="diff-deletedline"><del>'.$lang['deleted'].'</del></span>';
-        $r .= ' <span class="diff-addedline">'.$lang['created'].'</span>';
+        $r = '<tr><td colspan="'.$this->colspan.'" '.HTMLDiff::css('diff-blockheader').'>@@ '.$lang['line']." -$xbeg +$ybeg @@";
+        $r .= ' <span '.HTMLDiff::css('diff-deletedline').'><del>'.$lang['deleted'].'</del></span>';
+        $r .= ' <span '.HTMLDiff::css('diff-addedline').'>'.$lang['created'].'</span>';
         $r .= "</td></tr>\n";
         return $r;
     }
@@ -1134,19 +1167,19 @@ class InlineDiffFormatter extends DiffFormatter {
 
     function _added($lines) {
         foreach ($lines as $line) {
-            print('<tr><td colspan="'.$this->colspan.'" class="diff-addedline">'. $line . "</td></tr>\n");
+            print('<tr><td colspan="'.$this->colspan.'" '.HTMLDiff::css('diff-addedline').'>'. $line . "</td></tr>\n");
         }
     }
 
     function _deleted($lines) {
         foreach ($lines as $line) {
-            print('<tr><td colspan="'.$this->colspan.'" class="diff-deletedline"><del>' . $line . "</del></td></tr>\n");
+            print('<tr><td colspan="'.$this->colspan.'" '.HTMLDiff::css('diff-deletedline').'><del>' . $line . "</del></td></tr>\n");
         }
     }
 
     function _context($lines) {
         foreach ($lines as $line) {
-            print('<tr><td colspan="'.$this->colspan.'" class="diff-context">'.$line."</td></tr>\n");
+            print('<tr><td colspan="'.$this->colspan.'" '.HTMLDiff::css('diff-context').'>'.$line."</td></tr>\n");
         }
     }
 
