@@ -22,11 +22,11 @@ class DokuHTTPClient extends HTTPClient {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function DokuHTTPClient(){
+    function __construct(){
         global $conf;
 
         // call parent constructor
-        $this->HTTPClient();
+        parent::__construct();
 
         // set some values from the config
         $this->proxy_host   = $conf['proxy']['host'];
@@ -61,6 +61,8 @@ class DokuHTTPClient extends HTTPClient {
 
 }
 
+class HTTPClientException extends Exception { }
+
 /**
  * This class implements a basic HTTP client
  *
@@ -121,7 +123,7 @@ class HTTPClient {
      *
      * @author Andreas Gohr <andi@splitbrain.org>
      */
-    function HTTPClient(){
+    function __construct(){
         $this->agent        = 'Mozilla/4.0 (compatible; DokuWiki HTTP Client; '.PHP_OS.')';
         $this->timeout      = 15;
         $this->cookies      = array();
@@ -227,7 +229,7 @@ class HTTPClient {
         $path   = $uri['path'];
         if(empty($path)) $path = '/';
         if(!empty($uri['query'])) $path .= '?'.$uri['query'];
-        if(isset($uri['port']) && !empty($uri['port'])) $port = $uri['port'];
+        if(!empty($uri['port'])) $port = $uri['port'];
         if(isset($uri['user'])) $this->user = $uri['user'];
         if(isset($uri['pass'])) $this->pass = $uri['pass'];
 
@@ -249,7 +251,7 @@ class HTTPClient {
         // prepare headers
         $headers               = $this->headers;
         $headers['Host']       = $uri['host'];
-        if($uri['port']) $headers['Host'].= ':'.$uri['port'];
+        if(!empty($uri['port'])) $headers['Host'].= ':'.$uri['port'];
         $headers['User-Agent'] = $this->agent;
         $headers['Referer']    = $this->referer;
         if ($this->keep_alive) {
@@ -279,16 +281,13 @@ class HTTPClient {
             $headers['Proxy-Authorization'] = 'Basic '.base64_encode($this->proxy_user.':'.$this->proxy_pass);
         }
 
-        // stop time
-        $start = time();
-
         // already connected?
         $connectionId = $this->_uniqueConnectionId($server,$port);
-        $this->_debug('connection pool', $this->connections);
+        $this->_debug('connection pool', self::$connections);
         $socket = null;
-        if (isset($this->connections[$connectionId])) {
+        if (isset(self::$connections[$connectionId])) {
             $this->_debug('reusing connection', $connectionId);
-            $socket = $this->connections[$connectionId];
+            $socket = self::$connections[$connectionId];
         }
         if (is_null($socket) || feof($socket)) {
             $this->_debug('opening connection', $connectionId);
@@ -302,218 +301,161 @@ class HTTPClient {
 
             // keep alive?
             if ($this->keep_alive) {
-                $this->connections[$connectionId] = $socket;
+                self::$connections[$connectionId] = $socket;
             } else {
-                unset($this->connections[$connectionId]);
+                unset(self::$connections[$connectionId]);
             }
         }
 
-        //set blocking
-        stream_set_blocking($socket,1);
+        try {
+            //set non-blocking
+            stream_set_blocking($socket, false);
 
-        // build request
-        $request  = "$method $request_url HTTP/".$this->http.HTTP_NL;
-        $request .= $this->_buildHeaders($headers);
-        $request .= $this->_getCookies();
-        $request .= HTTP_NL;
-        $request .= $data;
+            // build request
+            $request  = "$method $request_url HTTP/".$this->http.HTTP_NL;
+            $request .= $this->_buildHeaders($headers);
+            $request .= $this->_getCookies();
+            $request .= HTTP_NL;
+            $request .= $data;
 
-        $this->_debug('request',$request);
+            $this->_debug('request',$request);
+            $this->_sendData($socket, $request, 'request');
 
-        // select parameters
-        $sel_r = null;
-        $sel_w = array($socket);
-        $sel_e = null;
+            // read headers from socket
+            $r_headers = '';
+            do{
+                $r_line = $this->_readLine($socket, 'headers');
+                $r_headers .= $r_line;
+            }while($r_line != "\r\n" && $r_line != "\n");
 
-        // send request
-        $towrite = strlen($request);
-        $written = 0;
-        while($written < $towrite){
-            // check timeout
-            if(time()-$start > $this->timeout){
-                $this->status = -100;
-                $this->error = sprintf('Timeout while sending request (%.3fs)',$this->_time() - $this->start);
-                unset($this->connections[$connectionId]);
-                return false;
-            }
+            $this->_debug('response headers',$r_headers);
 
-            // wait for stream ready or timeout (1sec)
-            if(stream_select($sel_r,$sel_w,$sel_e,1) === false) continue;
-
-            // write to stream
-            $ret = fwrite($socket, substr($request,$written,4096));
-            if($ret === false){
-                $this->status = -100;
-                $this->error = 'Failed writing to socket';
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-            $written += $ret;
-        }
-
-        // continue non-blocking
-        stream_set_blocking($socket,0);
-
-        // read headers from socket
-        $r_headers = '';
-        do{
-            if(time()-$start > $this->timeout){
-                $this->status = -100;
-                $this->error = sprintf('Timeout while reading headers (%.3fs)',$this->_time() - $this->start);
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-            if(feof($socket)){
-                $this->error = 'Premature End of File (socket)';
-                unset($this->connections[$connectionId]);
-                return false;
-            }
-            $r_headers .= fgets($socket,1024);
-        }while(!preg_match('/\r?\n\r?\n$/',$r_headers));
-
-        $this->_debug('response headers',$r_headers);
-
-        // check if expected body size exceeds allowance
-        if($this->max_bodysize && preg_match('/\r?\nContent-Length:\s*(\d+)\r?\n/i',$r_headers,$match)){
-            if($match[1] > $this->max_bodysize){
-                $this->error = 'Reported content length exceeds allowed response size';
-                if ($this->max_bodysize_abort)
-                    unset($this->connections[$connectionId]);
-                    return false;
-            }
-        }
-
-        // get Status
-        if (!preg_match('/^HTTP\/(\d\.\d)\s*(\d+).*?\n/', $r_headers, $m)) {
-            $this->error = 'Server returned bad answer';
-            unset($this->connections[$connectionId]);
-            return false;
-        }
-        $this->status = $m[2];
-
-        // handle headers and cookies
-        $this->resp_headers = $this->_parseHeaders($r_headers);
-        if(isset($this->resp_headers['set-cookie'])){
-            foreach ((array) $this->resp_headers['set-cookie'] as $cookie){
-                list($cookie)   = explode(';',$cookie,2);
-                list($key,$val) = explode('=',$cookie,2);
-                $key = trim($key);
-                if($val == 'deleted'){
-                    if(isset($this->cookies[$key])){
-                        unset($this->cookies[$key]);
-                    }
-                }elseif($key){
-                    $this->cookies[$key] = $val;
+            // check if expected body size exceeds allowance
+            if($this->max_bodysize && preg_match('/\r?\nContent-Length:\s*(\d+)\r?\n/i',$r_headers,$match)){
+                if($match[1] > $this->max_bodysize){
+                    if ($this->max_bodysize_abort)
+                        throw new HTTPClientException('Reported content length exceeds allowed response size');
+                    else
+                        $this->error = 'Reported content length exceeds allowed response size';
                 }
             }
-        }
 
-        $this->_debug('Object headers',$this->resp_headers);
+            // get Status
+            if (!preg_match('/^HTTP\/(\d\.\d)\s*(\d+).*?\n/', $r_headers, $m))
+                throw new HTTPClientException('Server returned bad answer');
 
-        // check server status code to follow redirect
-        if($this->status == 301 || $this->status == 302 ){
-            // close the connection because we don't handle content retrieval here
-            // that's the easiest way to clean up the connection
-            fclose($socket);
-            unset($this->connections[$connectionId]);
+            $this->status = $m[2];
 
-            if (empty($this->resp_headers['location'])){
-                $this->error = 'Redirect but no Location Header found';
-                return false;
-            }elseif($this->redirect_count == $this->max_redirect){
-                $this->error = 'Maximum number of redirects exceeded';
-                return false;
-            }else{
-                $this->redirect_count++;
-                $this->referer = $url;
-                // handle non-RFC-compliant relative redirects
-                if (!preg_match('/^http/i', $this->resp_headers['location'])){
-                    if($this->resp_headers['location'][0] != '/'){
-                        $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
-                                                          dirname($uri['path']).'/'.$this->resp_headers['location'];
-                    }else{
-                        $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
-                                                          $this->resp_headers['location'];
+            // handle headers and cookies
+            $this->resp_headers = $this->_parseHeaders($r_headers);
+            if(isset($this->resp_headers['set-cookie'])){
+                foreach ((array) $this->resp_headers['set-cookie'] as $cookie){
+                    list($cookie)   = explode(';',$cookie,2);
+                    list($key,$val) = explode('=',$cookie,2);
+                    $key = trim($key);
+                    if($val == 'deleted'){
+                        if(isset($this->cookies[$key])){
+                            unset($this->cookies[$key]);
+                        }
+                    }elseif($key){
+                        $this->cookies[$key] = $val;
                     }
                 }
-                // perform redirected request, always via GET (required by RFC)
-                return $this->sendRequest($this->resp_headers['location'],array(),'GET');
             }
-        }
 
-        // check if headers are as expected
-        if($this->header_regexp && !preg_match($this->header_regexp,$r_headers)){
-            $this->error = 'The received headers did not match the given regexp';
-            unset($this->connections[$connectionId]);
-            return false;
-        }
+            $this->_debug('Object headers',$this->resp_headers);
 
-        //read body (with chunked encoding if needed)
-        $r_body    = '';
-        if(preg_match('/transfer\-(en)?coding:\s*chunked\r\n/i',$r_headers)){
-            do {
-                unset($chunk_size);
+            // check server status code to follow redirect
+            if($this->status == 301 || $this->status == 302 ){
+                if (empty($this->resp_headers['location'])){
+                    throw new HTTPClientException('Redirect but no Location Header found');
+                }elseif($this->redirect_count == $this->max_redirect){
+                    throw new HTTPClientException('Maximum number of redirects exceeded');
+                }else{
+                    // close the connection because we don't handle content retrieval here
+                    // that's the easiest way to clean up the connection
+                    fclose($socket);
+                    unset(self::$connections[$connectionId]);
+
+                    $this->redirect_count++;
+                    $this->referer = $url;
+                    // handle non-RFC-compliant relative redirects
+                    if (!preg_match('/^http/i', $this->resp_headers['location'])){
+                        if($this->resp_headers['location'][0] != '/'){
+                            $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
+                                                            dirname($uri['path']).'/'.$this->resp_headers['location'];
+                        }else{
+                            $this->resp_headers['location'] = $uri['scheme'].'://'.$uri['host'].':'.$uri['port'].
+                                                            $this->resp_headers['location'];
+                        }
+                    }
+                    // perform redirected request, always via GET (required by RFC)
+                    return $this->sendRequest($this->resp_headers['location'],array(),'GET');
+                }
+            }
+
+            // check if headers are as expected
+            if($this->header_regexp && !preg_match($this->header_regexp,$r_headers))
+                throw new HTTPClientException('The received headers did not match the given regexp');
+
+            //read body (with chunked encoding if needed)
+            $r_body    = '';
+            if((isset($this->resp_headers['transfer-encoding']) && $this->resp_headers['transfer-encoding'] == 'chunked')
+            || (isset($this->resp_headers['transfer-coding']) && $this->resp_headers['transfer-coding'] == 'chunked')){
+                $abort = false;
                 do {
-                    if(feof($socket)){
-                        $this->error = 'Premature End of File (socket)';
-                        unset($this->connections[$connectionId]);
-                        return false;
+                    $chunk_size = '';
+                    while (preg_match('/^[a-zA-Z0-9]?$/',$byte=$this->_readData($socket,1,'chunk'))){
+                        // read chunksize until \r
+                        $chunk_size .= $byte;
+                        if (strlen($chunk_size) > 128) // set an abritrary limit on the size of chunks
+                            throw new HTTPClientException('Allowed response size exceeded');
                     }
-                    if(time()-$start > $this->timeout){
-                        $this->status = -100;
-                        $this->error = sprintf('Timeout while reading chunk (%.3fs)',$this->_time() - $this->start);
-                        unset($this->connections[$connectionId]);
-                        return false;
-                    }
-                    $byte = fread($socket,1);
-                    $chunk_size .= $byte;
-                } while (preg_match('/[a-zA-Z0-9]/',$byte)); // read chunksize including \r
+                    $this->_readLine($socket, 'chunk');     // readtrailing \n
+                    $chunk_size = hexdec($chunk_size);
 
-                $byte = fread($socket,1);     // readtrailing \n
-                $chunk_size = hexdec($chunk_size);
-                if ($chunk_size) {
-                    $this_chunk = fread($socket,$chunk_size);
-                    $r_body    .= $this_chunk;
-                    $byte = fread($socket,2); // read trailing \r\n
-                }
-
-                if($this->max_bodysize && strlen($r_body) > $this->max_bodysize){
-                    $this->error = 'Allowed response size exceeded';
-                    if ($this->max_bodysize_abort){
-                        unset($this->connections[$connectionId]);
-                        return false;
-                    } else {
-                        break;
+                    if($this->max_bodysize && $chunk_size+strlen($r_body) > $this->max_bodysize){
+                        if ($this->max_bodysize_abort)
+                            throw new HTTPClientException('Allowed response size exceeded');
+                        $this->error = 'Allowed response size exceeded';
+                        $chunk_size = $this->max_bodysize - strlen($r_body);
+                        $abort = true;
                     }
-                }
-            } while ($chunk_size);
-        }else{
-            // read entire socket
-            while (!feof($socket)) {
-                if(time()-$start > $this->timeout){
-                    $this->status = -100;
-                    $this->error = sprintf('Timeout while reading response (%.3fs)',$this->_time() - $this->start);
-                    unset($this->connections[$connectionId]);
-                    return false;
-                }
-                $r_body .= fread($socket,4096);
-                $r_size = strlen($r_body);
-                if($this->max_bodysize && $r_size > $this->max_bodysize){
-                    $this->error = 'Allowed response size exceeded';
+
+                    if ($chunk_size > 0) {
+                        $r_body .= $this->_readData($socket, $chunk_size, 'chunk');
+                        $byte = $this->_readData($socket, 2, 'chunk'); // read trailing \r\n
+                    }
+                } while ($chunk_size && !$abort);
+            }elseif($this->max_bodysize){
+                // read just over the max_bodysize
+                $r_body = $this->_readData($socket, $this->max_bodysize+1, 'response', true);
+                if(strlen($r_body) > $this->max_bodysize){
                     if ($this->max_bodysize_abort) {
-                        unset($this->connections[$connectionId]);
-                        return false;
+                        throw new HTTPClientException('Allowed response size exceeded');
                     } else {
-                        break;
+                        $this->error = 'Allowed response size exceeded';
                     }
                 }
-                if(isset($this->resp_headers['content-length']) &&
-                   !isset($this->resp_headers['transfer-encoding']) &&
-                   $this->resp_headers['content-length'] == $r_size){
-                    // we read the content-length, finish here
-                    break;
+            }elseif(isset($this->resp_headers['content-length']) &&
+                    !isset($this->resp_headers['transfer-encoding'])){
+                // read up to the content-length
+                $r_body = $this->_readData($socket, $this->resp_headers['content-length'], 'response', true);
+            }else{
+                // read entire socket
+                $r_size = 0;
+                while (!feof($socket)) {
+                    $r_body .= $this->_readData($socket, 4096, 'response', true);
                 }
             }
+
+        } catch (HTTPClientException $err) {
+            $this->error = $err->getMessage();
+            if ($err->getCode())
+                $this->status = $err->getCode();
+            unset(self::$connections[$connectionId]);
+            fclose($socket);
+            return false;
         }
 
         if (!$this->keep_alive ||
@@ -521,7 +463,7 @@ class HTTPClient {
             // close socket
             $status = socket_get_status($socket);
             fclose($socket);
-            unset($this->connections[$connectionId]);
+            unset(self::$connections[$connectionId]);
         }
 
         // decode gzip if needed
@@ -542,6 +484,126 @@ class HTTPClient {
         return true;
     }
 
+    /**
+     * Safely write data to a socket
+     *
+     * @param  handle $socket     An open socket handle
+     * @param  string $data       The data to write
+     * @param  string $message    Description of what is being read
+     * @author Tom N Harris <tnharris@whoopdedo.org>
+     */
+    function _sendData($socket, $data, $message) {
+        // select parameters
+        $sel_r = null;
+        $sel_w = array($socket);
+        $sel_e = null;
+
+        // send request
+        $towrite = strlen($data);
+        $written = 0;
+        while($written < $towrite){
+            // check timeout
+            $time_used = $this->_time() - $this->start;
+            if($time_used > $this->timeout)
+                throw new HTTPClientException(sprintf('Timeout while sending %s (%.3fs)',$message, $time_used), -100);
+            if(feof($socket))
+                throw new HTTPClientException("Socket disconnected while writing $message");
+
+            // wait for stream ready or timeout
+            self::selecttimeout($this->timeout - $time_used, $sec, $usec);
+            if(@stream_select($sel_r, $sel_w, $sel_e, $sec, $usec) !== false){
+                // write to stream
+                $nbytes = fwrite($socket, substr($data,$written,4096));
+                if($nbytes === false)
+                    throw new HTTPClientException("Failed writing to socket while sending $message", -100);
+                $written += $nbytes;
+            }
+        }
+    }
+
+    /**
+     * Safely read data from a socket
+     *
+     * Reads up to a given number of bytes or throws an exception if the
+     * response times out or ends prematurely.
+     *
+     * @param  handle $socket     An open socket handle in non-blocking mode
+     * @param  int    $nbytes     Number of bytes to read
+     * @param  string $message    Description of what is being read
+     * @param  bool   $ignore_eof End-of-file is not an error if this is set
+     * @author Tom N Harris <tnharris@whoopdedo.org>
+     */
+    function _readData($socket, $nbytes, $message, $ignore_eof = false) {
+        // select parameters
+        $sel_r = array($socket);
+        $sel_w = null;
+        $sel_e = null;
+
+        $r_data = '';
+        // Does not return immediately so timeout and eof can be checked
+        if ($nbytes < 0) $nbytes = 0;
+        $to_read = $nbytes;
+        do {
+            $time_used = $this->_time() - $this->start;
+            if ($time_used > $this->timeout)
+                throw new HTTPClientException(
+                        sprintf('Timeout while reading %s (%.3fs)', $message, $time_used),
+                        -100);
+            if(feof($socket)) {
+                if(!$ignore_eof)
+                    throw new HTTPClientException("Premature End of File (socket) while reading $message");
+                break;
+            }
+
+            if ($to_read > 0) {
+                // wait for stream ready or timeout
+                self::selecttimeout($this->timeout - $time_used, $sec, $usec);
+                if(@stream_select($sel_r, $sel_w, $sel_e, $sec, $usec) !== false){
+                    $bytes = fread($socket, $to_read);
+                    if($bytes === false)
+                        throw new HTTPClientException("Failed reading from socket while reading $message", -100);
+                    $r_data .= $bytes;
+                    $to_read -= strlen($bytes);
+                }
+            }
+        } while ($to_read > 0 && strlen($r_data) < $nbytes);
+        return $r_data;
+    }
+
+    /**
+     * Safely read a \n-terminated line from a socket
+     *
+     * Always returns a complete line, including the terminating \n.
+     *
+     * @param  handle $socket     An open socket handle in non-blocking mode
+     * @param  string $message    Description of what is being read
+     * @author Tom N Harris <tnharris@whoopdedo.org>
+     */
+    function _readLine($socket, $message) {
+        // select parameters
+        $sel_r = array($socket);
+        $sel_w = null;
+        $sel_e = null;
+
+        $r_data = '';
+        do {
+            $time_used = $this->_time() - $this->start;
+            if ($time_used > $this->timeout)
+                throw new HTTPClientException(
+                        sprintf('Timeout while reading %s (%.3fs)', $message, $time_used),
+                        -100);
+            if(feof($socket))
+                throw new HTTPClientException("Premature End of File (socket) while reading $message");
+
+            // wait for stream ready or timeout
+            self::selecttimeout($this->timeout - $time_used, $sec, $usec);
+            if(@stream_select($sel_r, $sel_w, $sel_e, $sec, $usec) !== false){
+                $r_data = fgets($socket, 1024);
+            }
+        } while (!preg_match('/\n$/',$r_data));
+        return $r_data;
+    }
+
     /**
      * print debug info
      *
@@ -562,11 +624,19 @@ class HTTPClient {
     /**
      * Return current timestamp in microsecond resolution
      */
-    function _time(){
+    static function _time(){
         list($usec, $sec) = explode(" ", microtime());
         return ((float)$usec + (float)$sec);
     }
 
+    /**
+     * Calculate seconds and microseconds
+     */
+    static function selecttimeout($time, &$sec, &$usec){
+        $sec = floor($time);
+        $usec = (int)(($time - $sec) * 1000000);
+    }
+
     /**
      * convert given header string to Header array
      *
@@ -576,13 +646,14 @@ class HTTPClient {
      */
     function _parseHeaders($string){
         $headers = array();
-        if (!preg_match_all('/^\s*([\w-]+)\s*:\s*([\S \t]+)\s*$/m', $string,
-                            $matches, PREG_SET_ORDER)) {
-            return $headers;
-        }
-        foreach($matches as $match){
-            list(, $key, $val) = $match;
+        $lines = explode("\n",$string);
+        array_shift($lines); //skip first line (status)
+        foreach($lines as $line){
+            @list($key, $val) = explode(':',$line,2);
+            $key = trim($key);
+            $val = trim($val);
             $key = strtolower($key);
+            if(!$key) continue;
             if(isset($headers[$key])){
                 if(is_array($headers[$key])){
                     $headers[$key][] = $val;
