@@ -42,12 +42,14 @@ $lang['btn_backtomedia']       = 'ارجع إلى اختيار ملف الوسا
 $lang['btn_subscribe']         = 'ادر الاشتراكات';
 $lang['btn_profile']           = 'حدث الملف الشخصي';
 $lang['btn_reset']             = 'صفّر';
-$lang['btn_resendpwd']         = 'ارسل كلمة سر جديدة';
+$lang['btn_resendpwd']         = 'اضبط كلمة سر جديدة';
 $lang['btn_draft']             = 'حرر المسودة';
 $lang['btn_recover']           = 'استرجع المسودة';
 $lang['btn_draftdel']          = 'احذف المسوّدة';
 $lang['btn_revert']            = 'استعد';
 $lang['btn_register']          = 'سجّل';
+$lang['btn_apply']             = 'طبق';
+$lang['btn_media']             = 'مدير الوسائط';
 $lang['loggedinas']            = 'داخل باسم';
 $lang['user']                  = 'اسم المستخدم';
 $lang['pass']                  = 'كلمة السر';
@@ -77,7 +79,7 @@ $lang['profnoempty']           = 'غير مسموح باسم مستخدم أو 
 $lang['profchanged']           = 'حُدث الملف الشخصي للمستخدم بنجاح.';
 $lang['pwdforget']             = 'أنسيت كلمة السر؟ احصل على واحدة جديدة';
 $lang['resendna']              = 'هذه الويكي لا تدعم إعادة إرسال كلمة المرور.';
-$lang['resendpwd']             = 'إرسال كلمة مرور';
+$lang['resendpwd']             = 'اضبط كلمة سر جديدة لـ';
 $lang['resendpwdmissing']      = 'عذراّ، يجب أن تملأ كل الحقول.';
 $lang['resendpwdnouser']       = 'عذراً، لم نجد المستخدم هذا في قاعدة بياناتنا.';
 $lang['resendpwdbadauth']      = 'عذراً، رمز التفعيل هذا غير صحيح. نأكد من استخدامك كامل وصلة التأكيد.';
@@ -92,7 +94,7 @@ $lang['txt_filename']          = 'رفع كـ (اختياري)';
 $lang['txt_overwrt']           = 'اكتب على ملف موجود';
 $lang['lockedby']              = 'مقفلة حاليا لـ';
 $lang['lockexpire']            = 'ينتهي القفل في';
-$lang['js']['willexpire']            = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
+$lang['js']['willexpire']      = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
 $lang['js']['notsavedyet']     = 'التعديلات غير المحفوظة ستفقد.';
 $lang['js']['searchmedia']     = 'ابحث عن ملفات';
 $lang['js']['keepopen']        = 'أبقي النافذة مفتوحة أثناء الاختيار';
@@ -123,6 +125,17 @@ $lang['js']['nosmblinks']      = 'الروابط لمجلدات مشاركة و
 $lang['js']['linkwiz']         = 'مرشد الروابط';
 $lang['js']['linkto']          = 'الرابط إلى :';
 $lang['js']['del_confirm']     = 'هل حقاً تريد حذف البنود المختارة؟';
+$lang['js']['restore_confirm'] = 'أمتأكد من استرجاع هذه النسخة؟';
+$lang['js']['media_diff']      = 'عرض الفروق:';
+$lang['js']['media_diff_both'] = 'جنبا إلى جنب';
+$lang['js']['media_diff_opacity'] = 'Shine-through';
+$lang['js']['media_diff_portions'] = 'Swipe';
+$lang['js']['media_select']    = 'اختر ملفا...';
+$lang['js']['media_upload_btn'] = 'ارفع';
+$lang['js']['media_done_btn']  = 'تم';
+$lang['js']['media_drop']      = 'اسقط الملف هنا لرفعه';
+$lang['js']['media_cancel']    = 'أزل';
+$lang['js']['media_overwrt']   = 'أكتب فوق الملفات الموجودة';
 $lang['rssfailed']             = 'خطأ ما حدث أثناء جلب ملف التغذية:';
 $lang['nothingfound']          = 'لا يوجد شيء';
 $lang['mediaselect']           = 'ملفات الوسائط';
@@ -172,11 +185,20 @@ $lang['external_edit']         = 'تحرير خارجي';
 $lang['summary']               = 'ملخص التحرير';
 $lang['noflash']               = 'تحتاج إلى<a href="http://www.adobe.com/products/flashplayer/">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
 $lang['download']              = 'نزل Snippet';
+$lang['tools']                 = 'أدوات';
+$lang['user_tools']            = 'أدوات المستخدم';
+$lang['site_tools']            = 'أدوات الموقع';
+$lang['page_tools']            = 'أدوات الصفحة';
+$lang['skip_to_content']       = 'تجاوز إلى المحتوى';
 $lang['mail_newpage']          = 'إضافة صفحة:';
 $lang['mail_changed']          = 'تعديل صفحة:';
 $lang['mail_subscribe_list']   = 'صفحات غيرت في النطاق:';
 $lang['mail_new_user']         = 'مشترك جديد:';
 $lang['mail_upload']           = 'رفع ملف:';
+$lang['changes_type']          = 'أظهر تغييرات الـ';
+$lang['pages_changes']         = 'صفحات';
+$lang['media_changes']         = 'ملفات الوسائط';
+$lang['both_changes']          = 'كلا من الصفحات وملفات الوسائط';
 $lang['qb_bold']               = 'نص عريض';
 $lang['qb_italic']             = 'نص مائل';
 $lang['qb_underl']             = 'نص مسطر';
@@ -217,6 +239,9 @@ $lang['img_copyr']             = 'حقوق النسخ';
 $lang['img_format']            = 'الهيئة';
 $lang['img_camera']            = 'الكمرا';
 $lang['img_keywords']          = 'كلمات مفتاحية';
+$lang['img_width']             = 'العرض';
+$lang['img_height']            = 'الإرتفاع';
+$lang['img_manager']           = 'اعرض في مدير الوسائط';
 $lang['subscr_subscribe_success'] = 'اضيف %s لقائمة اشتراك %s';
 $lang['subscr_subscribe_error'] = 'خطأ في إضافة %s لقائمة اشتراك %s';
 $lang['subscr_subscribe_noaddress'] = 'ليس هناك عنوان مرتبط بولوجك، لا يمكن اضافتك لقائمة الاشتراك';
@@ -235,6 +260,7 @@ $lang['subscr_style_digest']   = 'بريد ملخص عن تغييرات كل ص
 $lang['subscr_style_list']     = 'قائمة بالصفحات المتغيرة منذ آخر بريد';
 $lang['authmodfailed']         = 'إعدادات تصريح فاسدة، يرجى مراسلة المدير.';
 $lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
+$lang['authpwdexpire']         = 'ستنتهي صلاحية كلمة السر في %d . عليك بتغييرها سريعا.';
 $lang['i_chooselang']          = 'اختر لغتك';
 $lang['i_installer']           = 'برنامج تنصيب دوكو ويكي';
 $lang['i_wikiname']            = 'اسم الويكي';
@@ -275,3 +301,26 @@ $lang['hours']                 = '%d ساعة مضت';
 $lang['minutes']               = '%d دقيقة مضت';
 $lang['seconds']               = '%d ثانية مضت';
 $lang['wordblock']             = 'لم تحفظ تغييراتك لاحتوائها على نص ممنوع )غثاء(';
+$lang['media_uploadtab']       = 'ارفع';
+$lang['media_searchtab']       = 'ابحث';
+$lang['media_file']            = 'ملف';
+$lang['media_viewtab']         = 'عرض';
+$lang['media_edittab']         = 'تحرير';
+$lang['media_historytab']      = 'التاريخ';
+$lang['media_list_thumbs']     = 'المصغرات';
+$lang['media_list_rows']       = 'صفوف';
+$lang['media_sort_name']       = 'الاسم';
+$lang['media_sort_date']       = 'التاريخ';
+$lang['media_namespaces']      = 'اختر نطاقا';
+$lang['media_files']           = 'الملفات في %s';
+$lang['media_upload']          = 'ارفع إلى %s';
+$lang['media_search']          = 'ابحث في %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s في %s';
+$lang['media_edit']            = 'حرر %s';
+$lang['media_history']         = 'تاريخ %s';
+$lang['media_meta_edited']     = 'عُدلت الميتاداتا';
+$lang['media_perm_read']       = 'عفوا، لست مخولا بقراءة الملفات.';
+$lang['media_perm_upload']     = 'عفوا، لست مخولا برفع الملفات.';
+$lang['media_update']          = 'ارفع إصدارا أحدث';
+$lang['media_restore']         = 'استرجع هذه النسخة';
