@@ -13,6 +13,7 @@
  * @author Erik Bjørn Pedersen <erik.pedersen@shaw.ca>
  * @author rasmus@kinnerup.com
  * @author Michael Pedersen subben@gmail.com
+ * @author Mikael Lyngvig <mikael@lyngvig.org>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,12 +49,14 @@ $lang['btn_backtomedia']       = 'Tilbage til valg af mediefil';
 $lang['btn_subscribe']         = 'Abonnér på ændringer';
 $lang['btn_profile']           = 'Opdatér profil';
 $lang['btn_reset']             = 'Nulstil';
-$lang['btn_resendpwd']         = 'Send ny adgangskode';
+$lang['btn_resendpwd']         = 'Vælg ny adgangskode';
 $lang['btn_draft']             = 'Redigér kladde';
 $lang['btn_recover']           = 'Gendan kladde';
 $lang['btn_draftdel']          = 'Slet kladde';
 $lang['btn_revert']            = 'Reetablér';
 $lang['btn_register']          = 'Registrér';
+$lang['btn_apply']             = 'Anvend';
+$lang['btn_media']             = 'Media Manager';
 $lang['loggedinas']            = 'Logget ind som';
 $lang['user']                  = 'Brugernavn';
 $lang['pass']                  = 'Adgangskode';
@@ -83,7 +86,7 @@ $lang['profnoempty']           = 'Tomt navn eller e-mail adresse er ikke tilladt
 $lang['profchanged']           = 'Brugerprofil opdateret korrekt.';
 $lang['pwdforget']             = 'Har du glemt dit adgangskode? Få et nyt';
 $lang['resendna']              = 'Denne wiki understøtter ikke udsendelse af nyt adgangskode.';
-$lang['resendpwd']             = 'Send nyt adgangskode for';
+$lang['resendpwd']             = 'Vælg ny adgangskode for';
 $lang['resendpwdmissing']      = 'Du skal udfylde alle felter.';
 $lang['resendpwdnouser']       = 'Vi kan ikke finde denne bruger i vores database.';
 $lang['resendpwdbadauth']      = 'Beklager, denne autoriseringskode er ikke gyldig. Kontroller venligst at du benyttede det fulde link til bekræftelse.';
@@ -96,9 +99,10 @@ $lang['searchmedia_in']        = 'Søg i %s';
 $lang['txt_upload']            = 'Vælg den fil der skal overføres';
 $lang['txt_filename']          = 'Indtast wikinavn (valgfrit)';
 $lang['txt_overwrt']           = 'Overskriv eksisterende fil';
+$lang['maxuploadsize']         = 'Upload max. %s pr. fil.';
 $lang['lockedby']              = 'Midlertidig låst af';
 $lang['lockexpire']            = 'Lås udløber kl.';
-$lang['js']['willexpire']            = 'Din lås på dette dokument udløber om et minut.\nTryk på Forhåndsvisning-knappen for at undgå konflikter.';
+$lang['js']['willexpire']      = 'Din lås på dette dokument udløber om et minut.\nTryk på Forhåndsvisning-knappen for at undgå konflikter.';
 $lang['js']['notsavedyet']     = 'Ugemte ændringer vil blive mistet
 Fortsæt alligevel?';
 $lang['js']['searchmedia']     = 'Søg efter filer';
@@ -130,6 +134,16 @@ Du kan stadig kopiere og indsætte linket.';
 $lang['js']['linkwiz']         = 'guiden til henvisninger';
 $lang['js']['linkto']          = 'Henvise til:';
 $lang['js']['del_confirm']     = 'Slet valgte post(er)?';
+$lang['js']['restore_confirm'] = 'Vil du virkeligt genskabe denne version?';
+$lang['js']['media_diff']      = 'Vis forskelle:';
+$lang['js']['media_diff_both'] = 'Side ved Side';
+$lang['js']['media_diff_opacity'] = 'Skin-igennem';
+$lang['js']['media_select']    = 'Vælg filer...';
+$lang['js']['media_upload_btn'] = 'Upload';
+$lang['js']['media_done_btn']  = 'Færdig';
+$lang['js']['media_drop']      = 'Drop filer her for at uploade';
+$lang['js']['media_cancel']    = 'fjern';
+$lang['js']['media_overwrt']   = 'Overskriv eksisterende filer';
 $lang['rssfailed']             = 'Der opstod en fejl ved indhentning af: ';
 $lang['nothingfound']          = 'Søgningen gav intet resultat.';
 $lang['mediaselect']           = 'Vælg mediefil';
@@ -164,6 +178,9 @@ $lang['yours']                 = 'Din version';
 $lang['diff']                  = 'Vis forskelle i forhold til den nuværende udgave';
 $lang['diff2']                 = 'Vis forskelle i forhold til de valgte revisioner';
 $lang['difflink']              = 'Link til denne sammenlinings vising';
+$lang['diff_type']             = 'Vis forskelle:';
+$lang['diff_inline']           = 'Indeni';
+$lang['diff_side']             = 'Side ved Side';
 $lang['line']                  = 'Linje';
 $lang['breadcrumb']            = 'Sti';
 $lang['youarehere']            = 'Du er her';
@@ -176,11 +193,20 @@ $lang['external_edit']         = 'ekstern redigering';
 $lang['summary']               = 'Redigerings resumé';
 $lang['noflash']               = 'Den <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> er nødvendig til at vise denne indehold.';
 $lang['download']              = 'Hente kodestykke';
+$lang['tools']                 = 'Værktøjer';
+$lang['user_tools']            = 'Brugerværktøjer';
+$lang['site_tools']            = 'Webstedsværktøjer';
+$lang['page_tools']            = 'Sideværktøjer';
+$lang['skip_to_content']       = 'hop til indhold';
 $lang['mail_newpage']          = 'dokument tilføjet:';
 $lang['mail_changed']          = 'dokument ændret:';
 $lang['mail_subscribe_list']   = 'sider ændret i navnerum';
 $lang['mail_new_user']         = 'Ny bruger';
 $lang['mail_upload']           = 'fil overføret:';
+$lang['changes_type']          = 'Vis ændringer af';
+$lang['pages_changes']         = 'Sider';
+$lang['media_changes']         = 'Media filer';
+$lang['both_changes']          = 'Både sider og media filer';
 $lang['qb_bold']               = 'Fed';
 $lang['qb_italic']             = 'Kursiv';
 $lang['qb_underl']             = 'Understregning';
@@ -221,6 +247,9 @@ $lang['img_copyr']             = 'Ophavsret';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Emneord';
+$lang['img_width']             = 'Bredde';
+$lang['img_height']            = 'Højde';
+$lang['img_manager']           = 'Vis i Media Manager';
 $lang['subscr_subscribe_success'] = 'Tilføjede %s til abonnement listen for %s';
 $lang['subscr_subscribe_error'] = 'Fejl ved tilføjelse af %s til abonnement listen for %s';
 $lang['subscr_subscribe_noaddress'] = 'Der er ikke nogen addresse forbundet til din bruger, så du kan ikke blive tilføjet til abonnement listen';
@@ -235,9 +264,11 @@ $lang['subscr_m_unsubscribe']  = 'Fjern abonnement';
 $lang['subscr_m_subscribe']    = 'Abonér';
 $lang['subscr_m_receive']      = 'Modtag';
 $lang['subscr_style_every']    = 'email på hver ændring';
+$lang['subscr_style_digest']   = 'opsummeringsmail med ændringer for hver side (hver %.2f dage)';
 $lang['subscr_style_list']     = 'list af ændrede sider siden sidste email (hver %.2f dage)';
 $lang['authmodfailed']         = 'Fejl i brugervalideringens konfiguration. Kontakt venligst wikiens administrator.';
 $lang['authtempfail']          = 'Brugervalidering er midlertidigt ude af drift. Hvis dette er vedvarende, kontakt venligst wikiens administrator.';
+$lang['authpwdexpire']         = 'Din adgangskode vil udløbe om %d dage, du bør ændre det snart.';
 $lang['i_chooselang']          = 'Vælg dit sprog';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Wiki Navn';
@@ -271,3 +302,26 @@ $lang['hours']                 = '%d timer siden';
 $lang['minutes']               = '%d minutter siden';
 $lang['seconds']               = '%d sekunder siden';
 $lang['wordblock']             = 'Din ændring blev ikke gemt da den indeholder blokeret tekst (spam).';
+$lang['media_uploadtab']       = 'Upload';
+$lang['media_searchtab']       = 'Søg';
+$lang['media_file']            = 'Fil';
+$lang['media_viewtab']         = 'Vis';
+$lang['media_edittab']         = 'Rediger';
+$lang['media_historytab']      = 'Historie';
+$lang['media_list_thumbs']     = 'Thumbnails';
+$lang['media_list_rows']       = 'Rækker';
+$lang['media_sort_name']       = 'Navn';
+$lang['media_sort_date']       = 'Dato';
+$lang['media_namespaces']      = 'Vælg navneområde';
+$lang['media_files']           = 'Filer i %s';
+$lang['media_upload']          = 'Upload til %s';
+$lang['media_search']          = 'Søg i %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s ved %s';
+$lang['media_edit']            = 'Rediger %s';
+$lang['media_history']         = 'Historie for %s';
+$lang['media_meta_edited']     = 'metadata redigered';
+$lang['media_perm_read']       = 'Du har ikke nok rettigheder til at læse filer.';
+$lang['media_perm_upload']     = 'Du har ikke nok rettigheder til at uploade filer.';
+$lang['media_update']          = 'Upload ny version';
+$lang['media_restore']         = 'Genskab denne version';
