@@ -43,7 +43,6 @@ $lang['btn_backtomedia']       = 'Επιστροφή στην επιλογή α
 $lang['btn_subscribe']         = 'Εγγραφή σε λήψη ενημερώσεων σελίδας';
 $lang['btn_profile']           = 'Επεξεργασία προφίλ';
 $lang['btn_reset']             = 'Ακύρωση';
-$lang['btn_resendpwd']         = 'Αποστολή νέου κωδικού';
 $lang['btn_draft']             = 'Επεξεργασία  αυτόματα αποθηκευμένης σελίδας';
 $lang['btn_recover']           = 'Επαναφορά αυτόματα αποθηκευμένης σελίδας';
 $lang['btn_draftdel']          = 'Διαγραφή αυτόματα αποθηκευμένης σελίδας';
@@ -80,7 +79,6 @@ $lang['profnoempty']           = 'Δεν επιτρέπεται κενό όνο
 $lang['profchanged']           = 'Το προφίλ χρήστη τροποποιήθηκε επιτυχώς.';
 $lang['pwdforget']             = 'Ξεχάσατε το κωδικό σας; Αποκτήστε νέο.';
 $lang['resendna']              = 'Αυτό το wiki δεν υποστηρίζει την εκ\' νέου αποστολή κωδικών.';
-$lang['resendpwd']             = 'Αποστολή νέων κωδικών για τον χρήστη';
 $lang['resendpwdmissing']      = 'Πρέπει να συμπληρώσετε όλα τα πεδία.';
 $lang['resendpwdnouser']       = 'Αυτός ο χρήστης δεν υπάρχει στα αρχεία μας.';
 $lang['resendpwdbadauth']      = 'Αυτός ο κωδικός ενεργοποίησης δεν είναι έγκυρος.';
@@ -308,4 +306,3 @@ $lang['media_perm_read']       = 'Συγνώμη, δεν έχετε επαρκή
 $lang['media_perm_upload']     = 'Συγνώμη, δεν έχετε επαρκή διακαιώματα για να φορτώσετε αυτά τα αρχεία.';
 $lang['media_update']          = 'Φόρτωση νέας έκδοσης';
 $lang['media_restore']         = 'Επαναφορά αυτή της έκδοσης';
-$lang['plugin_install_err']    = 'Η επέκταση δεν εγκαταστήθηκε σωστά. Μετονομασία φακέλου επεκτάσεων από \'%s\' σε \'%s\'.';
