@@ -24,6 +24,9 @@
  * @author Victor Castelan <victorcastelan@gmail.com>
  * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
  * @author emezeta <emezeta@infoprimo.com>
+ * @author Oscar Ciudad <oscar@jacho.net>
+ * @author Ruben Figols <ruben.figols@gmail.com>
+ * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -54,17 +57,19 @@ $lang['btn_admin']             = 'Administrar';
 $lang['btn_update']            = 'Actualizar';
 $lang['btn_delete']            = 'Borrar';
 $lang['btn_back']              = 'Atrás';
-$lang['btn_backlink']          = 'Enlaces anteriores';
+$lang['btn_backlink']          = 'Enlaces a esta página';
 $lang['btn_backtomedia']       = 'Volver a la selección de archivos multimedia';
 $lang['btn_subscribe']         = 'Suscribirse a cambios de la página';
 $lang['btn_profile']           = 'Actualizar perfil';
 $lang['btn_reset']             = 'Restablecer';
-$lang['btn_resendpwd']         = 'Enviar nueva contraseña';
+$lang['btn_resendpwd']         = 'Establecer nueva contraseña';
 $lang['btn_draft']             = 'Editar borrador';
 $lang['btn_recover']           = 'Recuperar borrador';
 $lang['btn_draftdel']          = 'Eliminar borrador';
 $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Registrarse';
+$lang['btn_apply']             = 'Aplicar';
+$lang['btn_media']             = 'Gestor de ficheros';
 $lang['loggedinas']            = 'Conectado como ';
 $lang['user']                  = 'Usuario';
 $lang['pass']                  = 'Contraseña';
@@ -94,7 +99,7 @@ $lang['profnoempty']           = 'No se permite que el nombre o la dirección de
 $lang['profchanged']           = 'Se actualizó correctamente el perfil del usuario.';
 $lang['pwdforget']             = '¿Has olvidado tu contraseña? Consigue una nueva';
 $lang['resendna']              = 'Este wiki no brinda la posibilidad de reenvío de contraseña.';
-$lang['resendpwd']             = 'Enviar una nueva contraseña para';
+$lang['resendpwd']             = 'Establecer nueva contraseña para';
 $lang['resendpwdmissing']      = 'Lo siento, debes completar todos los campos.';
 $lang['resendpwdnouser']       = 'Lo siento, no se encuentra este usuario en nuestra base de datos.';
 $lang['resendpwdbadauth']      = 'Lo siento, este código de autenticación no es válido. Asegúrate de haber usado el enlace de confirmación entero.';
@@ -107,9 +112,10 @@ $lang['searchmedia_in']        = 'Buscar en %s';
 $lang['txt_upload']            = 'Selecciona el archivo a subir';
 $lang['txt_filename']          = 'Subir como (opcional)';
 $lang['txt_overwrt']           = 'Sobreescribir archivo existente';
+$lang['maxuploadsize']         = 'Peso máximo de %s por archivo';
 $lang['lockedby']              = 'Actualmente bloqueado por';
 $lang['lockexpire']            = 'El bloqueo expira en';
-$lang['willexpire']            = 'Tu bloqueo para editar esta página expira en un minuto.\nPara evitar conflictos usa el botón previsualizar para reiniciar el contador de tiempo.';
+$lang['js']['willexpire']      = 'El bloqueo para la edición de esta página expira en un minuto.\nPAra prevenir conflictos uso el botón Previsualizar para restaurar el contador de bloqueo.';
 $lang['js']['notsavedyet']     = 'Los cambios que no se han guardado se perderán.
 ¿Realmente quieres continuar?';
 $lang['js']['searchmedia']     = 'Buscar archivos';
@@ -141,7 +147,17 @@ Lo que sí puedes hacer es copiar y pegar el enlace.';
 $lang['js']['linkwiz']         = 'Asistente de enlaces';
 $lang['js']['linkto']          = 'Enlazar a:';
 $lang['js']['del_confirm']     = '¿Quieres realmente borrar lo seleccionado?';
-$lang['js']['mu_btn']          = 'Subir varios archivos a la vez';
+$lang['js']['restore_confirm'] = '¿Estás seguro de querer restaurar esta versión?';
+$lang['js']['media_diff']      = 'Ver diferencias:';
+$lang['js']['media_diff_both'] = 'Lado por lado';
+$lang['js']['media_diff_opacity'] = 'A través de Shine';
+$lang['js']['media_diff_portions'] = 'Pasar';
+$lang['js']['media_select']    = 'Seleccionar ficheros';
+$lang['js']['media_upload_btn'] = 'Cargar';
+$lang['js']['media_done_btn']  = 'Hecho';
+$lang['js']['media_drop']      = 'Arrastra los ficheros aquí para cargar';
+$lang['js']['media_cancel']    = 'Eliminar';
+$lang['js']['media_overwrt']   = 'Sobreescribir ficheros exitentes';
 $lang['rssfailed']             = 'Se ha producido un error mientras se leían los datos de este feed: ';
 $lang['nothingfound']          = 'No se ha encontrado nada.';
 $lang['mediaselect']           = 'Archivos Multimedia';
@@ -191,11 +207,21 @@ $lang['external_edit']         = 'editor externo';
 $lang['summary']               = 'Resumen de la edición';
 $lang['noflash']               = 'Para mostrar este contenido es necesario el <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a>.';
 $lang['download']              = 'Descargar trozo de código fuente';
+$lang['tools']                 = 'Herramientas';
+$lang['user_tools']            = 'Herramientas de usuario';
+$lang['site_tools']            = 'Herramientas del sitio';
+$lang['page_tools']            = 'Herramientas de la página';
+$lang['skip_to_content']       = 'Saltar a contenido';
+$lang['sidebar']               = 'Barra lateral';
 $lang['mail_newpage']          = 'página añadida:';
 $lang['mail_changed']          = 'página cambiada:';
 $lang['mail_subscribe_list']   = 'páginas cambiadas en el espacio de nombre:';
 $lang['mail_new_user']         = 'nuevo usuario:';
 $lang['mail_upload']           = 'archivo subido:';
+$lang['changes_type']          = 'Ver cambios de';
+$lang['pages_changes']         = 'Páginas';
+$lang['media_changes']         = 'Archivos multimedia';
+$lang['both_changes']          = 'Ambas páginas y archivos multimedia';
 $lang['qb_bold']               = 'Negrita';
 $lang['qb_italic']             = 'Itálica';
 $lang['qb_underl']             = 'Subrayado';
@@ -236,6 +262,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Cámara';
 $lang['img_keywords']          = 'Palabras claves';
+$lang['img_width']             = 'Ancho';
+$lang['img_height']            = 'Alto';
+$lang['img_manager']           = 'Ver en el Administrador de medios';
 $lang['subscr_subscribe_success'] = 'Se agregó %s a las listas de suscripción para %s';
 $lang['subscr_subscribe_error'] = 'Error al agregar %s a las listas de suscripción para %s';
 $lang['subscr_subscribe_noaddress'] = 'No hay dirección asociada con tu registro, no se puede agregarte a la lista de suscripción';
@@ -254,6 +283,7 @@ $lang['subscr_style_digest']   = 'recopilar correo de cambios por cada página';
 $lang['subscr_style_list']     = 'lista de páginas con cambios desde el último correo';
 $lang['authmodfailed']         = 'Está mal configurada la autenticación de usuarios. Por favor, avisa al administrador del wiki.';
 $lang['authtempfail']          = 'La autenticación de usuarios no está disponible temporalmente. Si esta situación persiste, por favor avisa al administrador del wiki.';
+$lang['authpwdexpire']         = 'Su contraseña caducara en %d días, debería cambiarla lo antes posible';
 $lang['i_chooselang']          = 'Elija su idioma';
 $lang['i_installer']           = 'Instalador de DokuWiki';
 $lang['i_wikiname']            = 'Nombre del wiki';
@@ -261,9 +291,9 @@ $lang['i_enableacl']           = 'Habilitar ACL (recomendado) (ACL: lista de con
 $lang['i_superuser']           = 'Super-usuario';
 $lang['i_problems']            = 'El instalador encontró algunos problemas, se muestran abajo. No se puede continuar la instalación hasta que usted no los corrija.';
 $lang['i_modified']            = 'Por razones de seguridad este script sólo funcionará con una instalación nueva y no modificada de Dokuwiki. Usted debe extraer nuevamente los ficheros del paquete bajado, o bien consultar las <a href="http://dokuwiki.org/install">instrucciones de instalación de Dokuwiki</a> completas.';
-$lang['i_funcna']              = 'La función de PHP <code>%s</code> no está disponible. Tal vez su proveedor de hosting la ha deshabilitado por alguna razón?';
+$lang['i_funcna']              = 'La función de PHP <code>%s</code> no está disponible. ¿Tal vez su proveedor de hosting la ha deshabilitado por alguna razón?';
 $lang['i_phpver']              = 'Su versión de PHP <code>%s</code> es menor que la necesaria <code>%s</code>. Es necesario que actualice su instalación de PHP.';
-$lang['i_permfail']            = 'DokuWili no puede escribir <code>%s</code>. Es necesario establecer  correctamente los permisos de este directorio!';
+$lang['i_permfail']            = 'DokuWili no puede escribir <code>%s</code>. ¡Es necesario establecer  correctamente los permisos de este directorio!';
 $lang['i_confexists']          = '<code>%s</code> ya existe';
 $lang['i_writeerr']            = 'Imposible crear <code>%s</code>. Se necesita que usted controle los permisos del fichero/directorio y que cree el fichero manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php no reconocido o modificado (hash=<code>%s</code>)';
@@ -276,21 +306,6 @@ $lang['i_pol1']                = 'Wiki público (leer para todos, escribir y sub
 $lang['i_pol2']                = 'Wiki cerrado (leer, escribir y subir archivos para usuarios registrados únicamente)';
 $lang['i_retry']               = 'Reintentar';
 $lang['i_license']             = 'Por favor escoja una licencia bajo la que publicar su contenido:';
-$lang['mu_intro']              = 'Puedes subir varios archivos a la vez desde aquí. Pulsa el botón del navegador para agregarlos a la cola. Pulsa "subir archivo" para proceder.';
-$lang['mu_gridname']           = 'Nombre de archivo';
-$lang['mu_gridsize']           = 'Tamaño';
-$lang['mu_gridstat']           = 'Estado';
-$lang['mu_namespace']          = 'Espacio de nombres';
-$lang['mu_browse']             = 'Buscar';
-$lang['mu_toobig']             = 'demasiado grande';
-$lang['mu_ready']              = 'listo para subir';
-$lang['mu_done']               = 'completado';
-$lang['mu_fail']               = 'falló';
-$lang['mu_authfail']           = 'la sesión caducó';
-$lang['mu_progress']           = '@PCT@% transferido';
-$lang['mu_filetypes']          = 'Tipos de archivos permitidos';
-$lang['mu_info']               = 'Archivos subidos:';
-$lang['mu_lasterr']            = 'Último error:';
 $lang['recent_global']         = 'Actualmente estás viendo los cambios dentro del namespace <b>%s</b>. También puedes <a href="%s">ver los cambios recientes en el wiki completo</a>.';
 $lang['years']                 = '%d años atrás';
 $lang['months']                = '%d meses atrás';
@@ -300,3 +315,26 @@ $lang['hours']                 = '%d horas atrás';
 $lang['minutes']               = '%d minutos atrás';
 $lang['seconds']               = '%d segundos atrás';
 $lang['wordblock']             = 'Sus cambios no se han guardado porque contienen textos bloqueados (spam).';
+$lang['media_uploadtab']       = 'Cargar';
+$lang['media_searchtab']       = 'Buscar';
+$lang['media_file']            = 'Fichero';
+$lang['media_viewtab']         = 'Ver';
+$lang['media_edittab']         = 'Editar';
+$lang['media_historytab']      = 'Historial';
+$lang['media_list_thumbs']     = 'Miniaturas';
+$lang['media_list_rows']       = 'Celdas';
+$lang['media_sort_name']       = 'Nombre';
+$lang['media_sort_date']       = 'Fecha';
+$lang['media_namespaces']      = 'Escoge "espacio de nombre"';
+$lang['media_files']           = 'Ficheros en %s';
+$lang['media_upload']          = 'Cargar a %s';
+$lang['media_search']          = 'Buscar en %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s en %s';
+$lang['media_edit']            = 'Editar %s';
+$lang['media_history']         = 'Historial de %s';
+$lang['media_meta_edited']     = 'Metadatos editados';
+$lang['media_perm_read']       = 'Disculpa, no tienes los permisos necesarios para leer ficheros.';
+$lang['media_perm_upload']     = 'Disculpa, no tienes los permisos necesarios para cargar ficheros.';
+$lang['media_update']          = 'Actualizar nueva versión';
+$lang['media_restore']         = 'Restaurar esta versión';
