@@ -12,6 +12,7 @@
  * @author Mohsen Firoozmandan <info@mambolearn.com>
  * @author Omid Mottaghi <omidmr@gmail.com>
  * @author Mohammad Reza Shoaei <shoaei@gmail.com>
+ * @author Milad DZand <M.DastanZand@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'rtl';
@@ -47,12 +48,14 @@ $lang['btn_backtomedia']       = 'بازگشت به انتخاب فایل';
 $lang['btn_subscribe']         = 'عضویت در تغییرات صفحه';
 $lang['btn_profile']           = 'به روز رسانی پروفایل';
 $lang['btn_reset']             = 'بازنشاندن';
-$lang['btn_resendpwd']         = 'یک گذرواژه‌ی جدید برای شما فرستاده شود';
+$lang['btn_resendpwd']         = 'تعیین کلمه عبور جدید';
 $lang['btn_draft']             = 'ویرایش پیش‌نویس';
 $lang['btn_recover']           = 'بازیابی پیش‌نویس';
 $lang['btn_draftdel']          = 'حذف پیش‌نویس';
 $lang['btn_revert']            = 'بازیابی';
 $lang['btn_register']          = 'یک حساب جدید بسازید';
+$lang['btn_apply']             = 'اعمال کن';
+$lang['btn_media']             = 'مدیریت محتوای چند رسانه ای';
 $lang['loggedinas']            = 'به عنوان کاربر روبرو وارد شده‌اید:';
 $lang['user']                  = 'نام کاربری:';
 $lang['pass']                  = 'گذرواژه‌ی شما';
@@ -82,7 +85,7 @@ $lang['profnoempty']           = 'نام و آدرس ایمیل باید پر ش
 $lang['profchanged']           = 'پروفایل کاربر با موفقیت به روز شد';
 $lang['pwdforget']             = 'گذرواژه‌ی خود را فراموش کرده‌اید؟ جدید دریافت کنید';
 $lang['resendna']              = 'این ویکی ارسال مجدد گذرواژه را پشتیبانی نمی‌کند';
-$lang['resendpwd']             = 'گذرواژه‌ی جدید ارسال شد';
+$lang['resendpwd']             = 'تعیین کلمه عبور جدید برای ';
 $lang['resendpwdmissing']      = 'متاسفم، شما باید تمام قسمت‌ها را پر کنید';
 $lang['resendpwdnouser']       = 'متاسفم، ما نتوانستیم این نام کاربری را در بانک خود پیدا کنیم';
 $lang['resendpwdbadauth']      = 'متاسفم، کد شناسایی معتبر نیست. از صحت لینک تاییدیه اطمینان حاصل کنید.';
@@ -95,10 +98,11 @@ $lang['searchmedia_in']        = 'جستجو در %s';
 $lang['txt_upload']            = 'فایل را برای ارسال انتخاب کنید';
 $lang['txt_filename']          = 'ارسال به صورت (اختیاری)';
 $lang['txt_overwrt']           = 'بر روی فایل موجود بنویس';
+$lang['maxuploadsize']         = 'حداکثر %s برای هر فایل مجاز است.';
 $lang['lockedby']              = 'در حال حاضر قفل شده است';
 $lang['lockexpire']            = 'قفل منقضی شده است';
-$lang['willexpire']            = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
-$lang['js']['notsavedyet']     = 'تغییرات ذخیره شده از بین خواهد رفت. 
+$lang['js']['willexpire']      = 'حالت قفل شما مدتی است منقضی شده است \n برای جلوگیری از تداخل دکمه‌ی پیش‌نمایش را برای صفر شدن ساعت قفل بزنید.';
+$lang['js']['notsavedyet']     = 'تغییرات ذخیره شده از بین خواهد رفت.
  می‌خواهید ادامه دهید؟';
 $lang['js']['searchmedia']     = 'جستجو برای فایل';
 $lang['js']['keepopen']        = 'پنجره را ر زمان انتخاب باز نگه‌دار';
@@ -129,7 +133,17 @@ $lang['js']['nosmblinks']      = 'پیوند به Windows share فقط در ای
 $lang['js']['linkwiz']         = 'ویزارد پیوند';
 $lang['js']['linkto']          = 'پیوند به:';
 $lang['js']['del_confirm']     = 'واقعن تصمیم به حذف این موارد دارید؟';
-$lang['js']['mu_btn']          = 'ارسال هم‌زمان چندین فایل ';
+$lang['js']['restore_confirm'] = 'آیا مطمئن هستید که می خواهید این نسخه را بازیابی کنید؟';
+$lang['js']['media_diff']      = 'تفاوت ها را ببینید : ';
+$lang['js']['media_diff_both'] = 'پهلو به پهلو';
+$lang['js']['media_diff_opacity'] = 'درخشش از';
+$lang['js']['media_diff_portions'] = 'کش رفتن';
+$lang['js']['media_select']    = 'انتخاب فایل -یا فایلها- ...';
+$lang['js']['media_upload_btn'] = 'آپلود';
+$lang['js']['media_done_btn']  = 'انجام شد';
+$lang['js']['media_drop']      = 'فایل ها را در اینجا قرار دهید تا آپلود شود';
+$lang['js']['media_cancel']    = 'حذف';
+$lang['js']['media_overwrt']   = 'جاینوشت فایل های موجود';
 $lang['rssfailed']             = 'بروز خطا در هنگام واکشی';
 $lang['nothingfound']          = 'چیزی پیدا نشد';
 $lang['mediaselect']           = 'فایل‌ها';
@@ -164,9 +178,9 @@ $lang['yours']                 = 'نسخه‌ی شما';
 $lang['diff']                  = 'تفاوت‌ها را با نگارش کنونی نمایش بده.';
 $lang['diff2']                 = 'تفاوت‌ها را با نگارش انتخابی نمایش بده.';
 $lang['difflink']              = 'پیوند به صفحه‌ی تفاوت‌ها';
-$lang['diff_type']             = 'مشاهده‌ی تفاوت‌ها';
-$lang['diff_inline']           = 'داخلی';
-$lang['diff_side']             = 'کنارهم';
+$lang['diff_type']             = 'مشاهده تغییرات:';
+$lang['diff_inline']           = 'خطی';
+$lang['diff_side']             = 'کلی';
 $lang['line']                  = 'خط';
 $lang['breadcrumb']            = 'ردپا';
 $lang['youarehere']            = 'محل شما';
@@ -179,11 +193,20 @@ $lang['external_edit']         = 'ویرایش خارجی';
 $lang['summary']               = 'پیش‌نمایش';
 $lang['noflash']               = 'برای نمایش محتویات <a href="http://www.adobe.com/products/flashplayer/">افزونه‌ی فلش</a> مورد نیاز است.';
 $lang['download']              = 'دیافت فایل منقطع گردید';
+$lang['tools']                 = 'ابزار';
+$lang['user_tools']            = 'ابزار کاربر';
+$lang['site_tools']            = 'ابزار سایت';
+$lang['page_tools']            = 'ابزار صفحه';
+$lang['skip_to_content']       = 'پرش به محتوا';
 $lang['mail_newpage']          = 'صفحه اضافه شد:';
 $lang['mail_changed']          = 'صفحه تغییر داده شد:';
 $lang['mail_subscribe_list']   = 'صفحات تغییر داده شده در فضای‌نام';
 $lang['mail_new_user']         = 'کاربر جدید:';
 $lang['mail_upload']           = 'فایل ارسال شده:';
+$lang['changes_type']          = 'دیدن تغییرات';
+$lang['pages_changes']         = 'صفحات';
+$lang['media_changes']         = 'فایلهای چند رسانه ای';
+$lang['both_changes']          = 'صفحات و فایل های چند رسانه ای هر دو';
 $lang['qb_bold']               = 'متن پُررنگ';
 $lang['qb_italic']             = 'متن ایتالیک';
 $lang['qb_underl']             = 'متن زیرخط‌دار';
@@ -224,6 +247,9 @@ $lang['img_copyr']             = 'دارنده‌ی حق تکثیر';
 $lang['img_format']            = 'فرمت';
 $lang['img_camera']            = 'دوربین';
 $lang['img_keywords']          = 'واژه‌های کلیدی';
+$lang['img_width']             = 'عرض';
+$lang['img_height']            = 'ارتفاع';
+$lang['img_manager']           = 'دیدن در مدیریت محتوای چند رسانه ای';
 $lang['subscr_subscribe_success'] = '%s به لیست آبونه %s افزوده شد';
 $lang['subscr_subscribe_error'] = 'اشکال در افزودن %s به لیست آبونه %s';
 $lang['subscr_subscribe_noaddress'] = 'هیچ آدرسی برای این عضویت اضافه نشده است، شما نمی‌توانید به لیست آبونه اضافه شوید';
@@ -242,6 +268,7 @@ $lang['subscr_style_digest']   = 'ارسال ایمیل‌های فشرده بر
 $lang['subscr_style_list']     = 'لیست صفحات تغییر داده شده از آخرین رای‌نامه';
 $lang['authmodfailed']         = 'اشکال در نوع معتبرسازی کاربران، مدیر ویکی را باخبر سازید.';
 $lang['authtempfail']          = 'معتبرسازی کابران موقتن مسدود می‌باشد. اگر این حالت پایدار بود، مدیر ویکی را باخبر سازید.';
+$lang['authpwdexpire']         = 'کلمه عبور شما در %d روز منقضی خواهد شد ، شما باید آن را زود تغییر دهید';
 $lang['i_chooselang']          = 'انتخاب زبان';
 $lang['i_installer']           = 'نصب کننده‌ی Dokuwiki';
 $lang['i_wikiname']            = 'نام ویکی';
@@ -264,21 +291,6 @@ $lang['i_pol1']                = 'ویکی عمومی (همه می‌توانن
 $lang['i_pol2']                = 'ویکی بسته (فقط کاربران ثبت شده می‌توانند بخوانند، بنویسند و فایل ارسال کنند)';
 $lang['i_retry']               = 'تلاش مجدد';
 $lang['i_license']             = 'لطفن مجوز این محتوا را وارد کنید:';
-$lang['mu_intro']              = 'شما می‌توانید چندین فایل را با یک حرکت ارسال کنید. روی دکمه‌ی «بچر» کلیک کنید و فایل‌ها را به صف ارسال اضافه نمایید. سپس دکمه‌ی «ارسال» را فشار دهید. ';
-$lang['mu_gridname']           = 'نام فایل';
-$lang['mu_gridsize']           = 'اندازه';
-$lang['mu_gridstat']           = 'وضعیت';
-$lang['mu_namespace']          = 'فضای‌نام';
-$lang['mu_browse']             = 'بچر';
-$lang['mu_toobig']             = 'خیلی بزرگ';
-$lang['mu_ready']              = 'آماده‌ی ارسال';
-$lang['mu_done']               = 'کامل';
-$lang['mu_fail']               = 'شکست خورد';
-$lang['mu_authfail']           = 'سشن به پایان رسید';
-$lang['mu_progress']           = '@PCT@% ارسال شد';
-$lang['mu_filetypes']          = 'توسعه‌های مجاز';
-$lang['mu_info']               = 'فایل ارسال گردید';
-$lang['mu_lasterr']            = 'آخرین خطا:';
 $lang['recent_global']         = 'شما هم‌اکنون تغییرات فضای‌نام <b>%s</b> را مشاهده می‌کنید. شما هم‌چنین می‌توانید <a href="%s">تغییرات اخیر در کل ویکی را مشاهده نمایید</a>.';
 $lang['years']                 = '%d سال پیش';
 $lang['months']                = '%d ماه پیش';
@@ -288,3 +300,26 @@ $lang['hours']                 = '%d ساعت پیش';
 $lang['minutes']               = '%d دقیقه‌ی پیش';
 $lang['seconds']               = '%d ثانیه‌ی پیش';
 $lang['wordblock']             = 'تغییرات شما به دلیل داشتن محتوای مشکوک (مثل اسپم) ذخیره نشد.';
+$lang['media_uploadtab']       = 'آپلود';
+$lang['media_searchtab']       = 'جستجو';
+$lang['media_file']            = 'فایل';
+$lang['media_viewtab']         = 'دیدن';
+$lang['media_edittab']         = 'ویرایش';
+$lang['media_historytab']      = 'تاریخچه';
+$lang['media_list_thumbs']     = 'ریز عکسها';
+$lang['media_list_rows']       = 'سطرها';
+$lang['media_sort_name']       = 'ستون ها';
+$lang['media_sort_date']       = 'تاریخ';
+$lang['media_namespaces']      = 'انتخاب فضای نام';
+$lang['media_files']           = 'فایل در %s';
+$lang['media_upload']          = 'آپلود به %s';
+$lang['media_search']          = 'جستجو در %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s در %s';
+$lang['media_edit']            = '%s ویرایش';
+$lang['media_history']         = 'تاریخچه %s';
+$lang['media_meta_edited']     = 'فرا داده ها ویرایش شدند.';
+$lang['media_perm_read']       = 'متاسفانه ، شما حق خواندن این فایل ها را ندارید.';
+$lang['media_perm_upload']     = 'متاسفانه ، شما حق آپلود این فایل ها را ندارید.';
+$lang['media_update']          = 'آپلود نسخه جدید';
+$lang['media_restore']         = 'بازیابی این نسخه';
