@@ -43,7 +43,7 @@ $lang['btn_backtomedia']       = 'Takaisin mediatiedostojen valintaan';
 $lang['btn_subscribe']         = 'Tilaa muutokset';
 $lang['btn_profile']           = 'Päivitä profiili';
 $lang['btn_reset']             = 'Tyhjennä';
-$lang['btn_resendpwd']         = 'Lähetä uusi salasana';
+$lang['btn_resendpwd']         = 'Aseta uusi salasana';
 $lang['btn_draft']             = 'Muokkaa luonnosta';
 $lang['btn_recover']           = 'Palauta luonnos';
 $lang['btn_draftdel']          = 'Poista luonnos';
@@ -80,7 +80,7 @@ $lang['profnoempty']           = 'Tyhjä nimi tai sähköpostiosoite ei ole sall
 $lang['profchanged']           = 'Käyttäjän profiilin päivitys onnistui.';
 $lang['pwdforget']             = 'Unohtuiko salasana? Hanki uusi';
 $lang['resendna']              = 'Tämä wiki ei tue salasanan uudelleenlähettämistä.';
-$lang['resendpwd']             = 'Lähetä uusi salasana käyttäjälle';
+$lang['resendpwd']             = 'Aseta uusisalasana';
 $lang['resendpwdmissing']      = 'Kaikki kentät on täytettävä.';
 $lang['resendpwdnouser']       = 'Käyttäjää ei löydy tietokannastamme.';
 $lang['resendpwdbadauth']      = 'Tunnistuskoodi on virheellinen. Varmista, että käytit koko varmistuslinkkiä.';
@@ -93,6 +93,7 @@ $lang['searchmedia_in']        = 'Etsi kohteesta %s';
 $lang['txt_upload']            = 'Valitse tiedosto lähetettäväksi';
 $lang['txt_filename']          = 'Lähetä nimellä (valinnainen)';
 $lang['txt_overwrt']           = 'Ylikirjoita olemassa oleva';
+$lang['maxuploadsize']         = 'Palvelimelle siirto max. %s / tiedosto.';
 $lang['lockedby']              = 'Tällä hetkellä tiedoston on lukinnut';
 $lang['lockexpire']            = 'Lukitus päättyy';
 $lang['js']['willexpire']      = 'Lukituksesi tämän sivun muokkaukseen päättyy minuutin kuluttua.\nRistiriitojen välttämiseksi paina esikatselu-nappia nollataksesi lukitusajan.';
@@ -187,6 +188,12 @@ $lang['external_edit']         = 'ulkoinen muokkaus';
 $lang['summary']               = 'Yhteenveto muokkauksesta';
 $lang['noflash']               = 'Tarvitset <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash-liitännäisen</a> nähdäksesi tämän sisällön.';
 $lang['download']              = 'Lataa palanen';
+$lang['tools']                 = 'Työkalut';
+$lang['user_tools']            = 'Käyttäjän työkalut';
+$lang['site_tools']            = 'Sivuston työkalut';
+$lang['page_tools']            = 'Sivutyökalut';
+$lang['skip_to_content']       = 'Siirry sisältöön';
+$lang['sidebar']               = 'Sivupalkki';
 $lang['mail_newpage']          = 'sivu lisätty:';
 $lang['mail_changed']          = 'sivu muutettu:';
 $lang['mail_subscribe_list']   = 'muuttuneet sivut nimiavaruudessa:';
@@ -257,6 +264,7 @@ $lang['subscr_style_digest']   = 'yhteenveto-sähköposti joka sivusta (joka %.2
 $lang['subscr_style_list']     = 'lista muuttuneista sivuista edellisen sähköpostin jälkeen (joka %.2f. päivä)';
 $lang['authmodfailed']         = 'Käyttäjien autentikoinnin asetukset ovat virheelliset. Ilmoita asiasta wikin ylläpitäjälle.';
 $lang['authtempfail']          = 'Käyttäjien autentikointi ei tällä hetkellä onnistu. Jos ongelma jatkuu, ota yhteyttä wikin ylläpitäjään.';
+$lang['authpwdexpire']         = 'Salasanasi vanhenee %d pv:n päästä, vaihda salasanasi pikaisesti.';
 $lang['i_chooselang']          = 'Valitse kieli';
 $lang['i_installer']           = 'DokuWikin asentaja';
 $lang['i_wikiname']            = 'Wikin nimi';
@@ -311,4 +319,3 @@ $lang['media_perm_read']       = 'Anteeksi. Sinulla ei ole riittävästi oikeuks
 $lang['media_perm_upload']     = 'Anteeksi. Sinulla ei ole riittävästi oikeuksia lähettääksesi tiedostoja.';
 $lang['media_update']          = 'Lähetä uusi versio';
 $lang['media_restore']         = 'Palauta tämä versio';
-$lang['plugin_install_err']    = 'Liitännäinen asentui virheellisesti. Nimeä liitännäisen hakemisto \'%s\' -> \'%s\'';
