@@ -40,7 +40,6 @@ $lang['btn_backtomedia']       = 'Volver á Selección de Arquivos-Media';
 $lang['btn_subscribe']         = 'Avísame dos trocos na páxina';
 $lang['btn_profile']           = 'Actualizar Perfil';
 $lang['btn_reset']             = 'Reiniciar';
-$lang['btn_resendpwd']         = 'Envíame un novo contrasinal';
 $lang['btn_draft']             = 'Editar borrador';
 $lang['btn_recover']           = 'Recuperar borrador';
 $lang['btn_draftdel']          = 'Eliminar borrador';
@@ -77,7 +76,6 @@ $lang['profnoempty']           = 'Non se permite un nome ou un enderezo de corre
 $lang['profchanged']           = 'Perfil de usuario actualizado correctamente.';
 $lang['pwdforget']             = 'Esqueceches o teu contrasinal? Consegue un novo';
 $lang['resendna']              = 'Este wiki non permite o reenvío de contrasinais.';
-$lang['resendpwd']             = 'Enviar novo contrasinal para';
 $lang['resendpwdmissing']      = 'Sentímolo, tes que cubrir todos os campos.';
 $lang['resendpwdnouser']       = 'Sentímolo, non atopamos este usuario no noso banco de datos.';
 $lang['resendpwdbadauth']      = 'Sentímolo, mais este código de autorización non é válido. Asegúrate de que usaches a ligazón completa de confirmación.';
@@ -312,4 +310,3 @@ $lang['media_perm_read']       = 'Sentímolo, non tes permisos suficientes para
 $lang['media_perm_upload']     = 'Sentímolo, non tes permisos suficientes para subir arquivos.';
 $lang['media_update']          = 'Subir nova versión';
 $lang['media_restore']         = 'Restaurar esta versión';
-$lang['plugin_install_err']    = 'Extensión instalada correctamente. Re-nomea o directorio da extensión de \'%s\' a \'%s\'.';
