@@ -45,7 +45,6 @@ $lang['btn_backtomedia']       = 'חזרה לבחירת קובץ מדיה';
 $lang['btn_subscribe']         = 'מעקב אחרי שינוים';
 $lang['btn_profile']           = 'עדכון הפרופיל';
 $lang['btn_reset']             = 'איפוס';
-$lang['btn_resendpwd']         = 'שליחת ססמה חדשה';
 $lang['btn_draft']             = 'עריכת טיוטה';
 $lang['btn_recover']           = 'שחזור טיוטה';
 $lang['btn_draftdel']          = 'מחיקת טיוטה';
@@ -80,7 +79,6 @@ $lang['profnoempty']           = 'השם וכתובת הדוא״ל לא יכול
 $lang['profchanged']           = 'הפרופיל עודכן בהצלחה';
 $lang['pwdforget']             = 'שכחת את הססמה שלך? ניתן לקבל חדשה';
 $lang['resendna']              = 'הוויקי הזה אינו תומך בחידוש ססמה';
-$lang['resendpwd']             = 'שליחת ססמה חדשה עבור';
 $lang['resendpwdmissing']      = 'עליך למלא את כל השדות, עמך הסליחה.';
 $lang['resendpwdnouser']       = 'משתמש בשם זה לא נמצא במסד הנתונים, עמך הסליחה.';
 $lang['resendpwdbadauth']      = 'קוד אימות זה אינו תקף. יש לוודא כי נעשה שימוש בקישור האימות המלא, עמך הסליחה.';
@@ -95,7 +93,7 @@ $lang['txt_filename']          = 'העלאה בשם (נתון לבחירה)';
 $lang['txt_overwrt']           = 'שכתוב על קובץ קיים';
 $lang['lockedby']              = 'נעול על ידי';
 $lang['lockexpire']            = 'הנעילה פגה';
-$lang['willexpire']            = 'הנעילה תחלוף עוד זמן קצר. \nלמניעת התנגשויות יש להשתמש בכפתור הרענון מטה כדי לאפס את מד משך הנעילה.';
+$lang['js']['willexpire']            = 'הנעילה תחלוף עוד זמן קצר. \nלמניעת התנגשויות יש להשתמש בכפתור הרענון מטה כדי לאפס את מד משך הנעילה.';
 $lang['js']['notsavedyet']     = 'שינויים שלא נשמרו ילכו לאיבוד.';
 $lang['js']['searchmedia']     = 'חיפוש אחר קבצים';
 $lang['js']['keepopen']        = 'השארת חלון פתוח על הבחירה';
@@ -126,7 +124,6 @@ $lang['js']['nosmblinks']      = 'קישור לכונני שיתוף של Window
 $lang['js']['linkwiz']         = 'אשף הקישורים';
 $lang['js']['linkto']          = 'קישור אל:';
 $lang['js']['del_confirm']     = 'באמת למחוק?';
-$lang['js']['mu_btn']          = 'העלאת מספר קבצים יחד';
 $lang['rssfailed']             = 'אירע כשל בעת קבלת הזנה זו:';
 $lang['nothingfound']          = 'לא נמצאו תוצאות.';
 $lang['mediaselect']           = 'קובצי מדיה';
@@ -260,21 +257,6 @@ $lang['i_pol1']                = ' ויקי ציבורי (קריאה לכולם,
 $lang['i_pol2']                = 'ויקי סגור (קריאה, כתיבה והעלאה למשתמשים רשומים בלבד)';
 $lang['i_retry']               = 'ניסיון נוסף';
 $lang['i_license']             = 'נא לבחור את הרישיון שיחול על התוכן שבוויקי שלך:';
-$lang['mu_intro']              = 'דרך כאן ניתן להעלות מספר קבצים בבת אחת. יש ללחוץ על לחצן החיפוש להוסיף אותם למחסנית. ניתן ללחוץ על העלאה לסיום.';
-$lang['mu_gridname']           = 'שם הקובץ';
-$lang['mu_gridsize']           = 'גודל';
-$lang['mu_gridstat']           = 'מצב';
-$lang['mu_namespace']          = 'מרחב שם';
-$lang['mu_browse']             = 'חיפוש';
-$lang['mu_toobig']             = 'גדול מדי';
-$lang['mu_ready']              = 'בהמתנה להעלאה';
-$lang['mu_done']               = 'הסתיים';
-$lang['mu_fail']               = 'נכשל';
-$lang['mu_authfail']           = 'תוקף ההפעלה פג';
-$lang['mu_progress']           = '@PCT@% הועלה';
-$lang['mu_filetypes']          = 'סוגי קבצים מורשים';
-$lang['mu_info']               = 'הקבצים הועלו';
-$lang['mu_lasterr']            = 'שגיאה אחרונה:';
 $lang['recent_global']         = 'נכון לעכשיו מתנהל על ידיך מעקב אחר מרחב השם <b>%s</b>. כמו כן, באפשרותך <a href="%s">לצפות בשינויים האחרונים בוויקי כולו</a>.';
 $lang['years']                 = 'לפני %d שנים';
 $lang['months']                = 'לפני %d חודשים';
