@@ -45,7 +45,6 @@ $lang['btn_backtomedia']       = 'Retornar al selection de files multimedia';
 $lang['btn_subscribe']         = 'Gerer subscriptiones';
 $lang['btn_profile']           = 'Actualisar profilo';
 $lang['btn_reset']             = 'Reinitialisar';
-$lang['btn_resendpwd']         = 'Inviar nove contrasigno';
 $lang['btn_draft']             = 'Modificar version provisori';
 $lang['btn_recover']           = 'Recuperar version provisori';
 $lang['btn_draftdel']          = 'Deler version provisori';
@@ -80,7 +79,6 @@ $lang['profnoempty']           = 'Un nomine o adresse de e-mail vacue non es per
 $lang['profchanged']           = 'Actualisation del profilo de usator succedite.';
 $lang['pwdforget']             = 'Contrasigno oblidate? Obtene un altere';
 $lang['resendna']              = 'Iste wiki non supporta le invio de un nove contrasigno.';
-$lang['resendpwd']             = 'Inviar nove contrasigno pro';
 $lang['resendpwdmissing']      = 'Es necessari completar tote le campos.';
 $lang['resendpwdnouser']       = 'Iste usator non ha essite trovate in le base de datos.';
 $lang['resendpwdbadauth']      = 'Iste codice de authentication non es valide. Assecura te que tu ha usate le ligamine de confirmation complete.';
