@@ -42,7 +42,6 @@ $lang['btn_subscribe']         = 'Ikuti Perubahan';
 $lang['btn_unsubscribe']       = 'Berhenti Ikuti Perubahan';
 $lang['btn_profile']           = 'Ubah Profil';
 $lang['btn_reset']             = 'Reset';
-$lang['btn_resendpwd']         = 'Kirim password baru';
 $lang['btn_draft']             = 'Edit draft';
 $lang['btn_draftdel']          = 'Hapus draft';
 $lang['btn_register']          = 'Daftar';
@@ -74,7 +73,6 @@ $lang['profnoempty']           = 'Mohon mengisikan nama atau alamat email.';
 $lang['profchanged']           = 'Profil User berhasil diubah.';
 $lang['pwdforget']             = 'Lupa Password? Dapatkan yang baru';
 $lang['resendna']              = 'Wiki ini tidak mendukung pengiriman ulang password.';
-$lang['resendpwd']             = 'Kirim password baru untuk';
 $lang['resendpwdmissing']      = 'Maaf, Anda harus mengisikan semua field.';
 $lang['resendpwdnouser']       = 'Maaf, user ini tidak ditemukan.';
 $lang['resendpwdbadauth']      = 'Maaf, kode autentikasi tidak valid. Pastikan Anda menggunakan keseluruhan link konfirmasi.';
