@@ -47,7 +47,6 @@ $lang['btn_subscribe']         = 'Vakta';
 $lang['btn_unsubscribe']       = 'Afvakta';
 $lang['btn_profile']           = 'Uppfæra notanda';
 $lang['btn_reset']             = 'Endurstilla';
-$lang['btn_resendpwd']         = 'Senda nýtt aðgangsorð með tölvupósti';
 $lang['btn_draft']             = 'Breyta uppkasti';
 $lang['btn_recover']           = 'Endurheimta uppkast';
 $lang['btn_draftdel']          = 'Eyða uppkasti';
@@ -82,7 +81,6 @@ $lang['profnoempty']           = 'Það er ekki leyfilegt að skilja nafn og pó
 $lang['profchanged']           = 'Notendaupplýsingum breytt';
 $lang['pwdforget']             = 'Gleymt aðgangsorð? Fáðu nýtt';
 $lang['resendna']              = 'Þessi wiki styður ekki endursendingar aðgangsorðs';
-$lang['resendpwd']             = 'Senda nýtt aðgangsorð fyrir';
 $lang['resendpwdmissing']      = 'Afsakið, þú verður að út eyðublaðið allt';
 $lang['resendpwdnouser']       = 'Afsakið, notandi finnst ekki.';
 $lang['resendpwdbadauth']      = 'Afsakið, þessi sannvottunorð er ekki gild. Gakktu úr skugga um að þú notaðir að ljúka staðfesting hlekkur.';
