@@ -13,6 +13,8 @@
  * @author Matteo Carnevali <rekstorm@gmail.com>
  * @author Osman Tekin <osman.tekin93@hotmail.it>
  * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
+ * @author Matteo Pasotti <matteo@xquiet.eu>
+ * @author snarchio@gmail.com
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,12 +50,14 @@ $lang['btn_backtomedia']       = 'Torna alla selezione file';
 $lang['btn_subscribe']         = 'Sottoscrivi modifiche';
 $lang['btn_profile']           = 'Aggiorna profilo';
 $lang['btn_reset']             = 'Annulla';
-$lang['btn_resendpwd']         = 'Invia nuova password';
+$lang['btn_resendpwd']         = 'Imposta nuova password';
 $lang['btn_draft']             = 'Modifica bozza';
 $lang['btn_recover']           = 'Ripristina bozza';
 $lang['btn_draftdel']          = 'Elimina bozza';
 $lang['btn_revert']            = 'Ripristina';
 $lang['btn_register']          = 'Registrazione';
+$lang['btn_apply']             = 'Applica';
+$lang['btn_media']             = 'Gestore Media';
 $lang['loggedinas']            = 'Collegato come';
 $lang['user']                  = 'Nome utente';
 $lang['pass']                  = 'Password';
@@ -83,7 +87,7 @@ $lang['profnoempty']           = 'Nome o indirizzo email vuoti non sono consenti
 $lang['profchanged']           = 'Aggiornamento del profilo utente riuscito.';
 $lang['pwdforget']             = 'Hai dimenticato la password? Richiedine una nuova';
 $lang['resendna']              = 'Questo wiki non supporta l\'invio di nuove password.';
-$lang['resendpwd']             = 'Invia nuova password per';
+$lang['resendpwd']             = 'Imposta nuova password per';
 $lang['resendpwdmissing']      = 'Devi riempire tutti i campi.';
 $lang['resendpwdnouser']       = 'Impossibile trovare questo utente nel database.';
 $lang['resendpwdbadauth']      = 'Spiacenti, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
@@ -96,9 +100,10 @@ $lang['searchmedia_in']        = 'Cerca in %s';
 $lang['txt_upload']            = 'Seleziona un file da caricare';
 $lang['txt_filename']          = 'Carica come (opzionale)';
 $lang['txt_overwrt']           = 'Sovrascrivi file esistente';
+$lang['maxuploadsize']         = 'Upload max. %s per ogni file.';
 $lang['lockedby']              = 'Attualmente bloccato da';
 $lang['lockexpire']            = 'Il blocco scade alle';
-$lang['js']['willexpire']            = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
+$lang['js']['willexpire']      = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
 $lang['js']['notsavedyet']     = 'Le modifiche non salvate andranno perse.';
 $lang['js']['searchmedia']     = 'Cerca file';
 $lang['js']['keepopen']        = 'Tieni la finestra aperta durante la selezione';
@@ -129,6 +134,15 @@ $lang['js']['nosmblinks']      = 'I collegamenti con le risorse condivise di Win
 $lang['js']['linkwiz']         = 'Collegamento guidato';
 $lang['js']['linkto']          = 'Collega a:';
 $lang['js']['del_confirm']     = 'Eliminare veramente questa voce?';
+$lang['js']['restore_confirm'] = 'Vuoi davvero ripristinare questa versione?';
+$lang['js']['media_diff']      = 'Guarda le differenze:';
+$lang['js']['media_diff_both'] = 'Fianco a Fianco';
+$lang['js']['media_select']    = 'Seleziona files..';
+$lang['js']['media_upload_btn'] = 'Upload';
+$lang['js']['media_done_btn']  = 'Fatto';
+$lang['js']['media_drop']      = 'Sgancia i files qui per caricarli';
+$lang['js']['media_cancel']    = 'rimuovi';
+$lang['js']['media_overwrt']   = 'Sovrascrivi i file esistenti';
 $lang['rssfailed']             = 'Si è verificato un errore cercando questo feed: ';
 $lang['nothingfound']          = 'Nessun risultato trovato.';
 $lang['mediaselect']           = 'Selezione dei file';
@@ -163,6 +177,9 @@ $lang['yours']                 = 'la tua versione';
 $lang['diff']                  = 'differenze con la versione attuale';
 $lang['diff2']                 = 'differenze tra le versioni selezionate';
 $lang['difflink']              = 'Link a questa pagina di confronto';
+$lang['diff_type']             = 'Guarda le differenze:';
+$lang['diff_inline']           = 'In linea';
+$lang['diff_side']             = 'Fianco a Fianco';
 $lang['line']                  = 'Linea';
 $lang['breadcrumb']            = 'Traccia';
 $lang['youarehere']            = 'Ti trovi qui';
@@ -175,11 +192,20 @@ $lang['external_edit']         = 'modifica esterna';
 $lang['summary']               = 'Oggetto della modifica';
 $lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">il plugin Adobe Flash</a> per visualizzare questo contenuto.';
 $lang['download']              = 'Scarica lo "snippet"';
+$lang['tools']                 = 'Strumenti';
+$lang['user_tools']            = 'Strumenti Utente';
+$lang['site_tools']            = 'Strumenti Sito';
+$lang['page_tools']            = 'Strumenti Pagina';
+$lang['skip_to_content']       = 'salta al contenuto';
+$lang['sidebar']               = 'Barra laterale';
 $lang['mail_newpage']          = 'pagina aggiunta:';
 $lang['mail_changed']          = 'pagina modificata:';
 $lang['mail_subscribe_list']   = 'pagine modificate nella categoria:';
 $lang['mail_new_user']         = 'nuovo utente:';
 $lang['mail_upload']           = 'file caricato:';
+$lang['changes_type']          = 'Guarda cambiamenti di';
+$lang['pages_changes']         = 'Pagine';
+$lang['both_changes']          = 'Sia pagine che media files';
 $lang['qb_bold']               = 'Grassetto';
 $lang['qb_italic']             = 'Corsivo';
 $lang['qb_underl']             = 'Sottolineato';
@@ -220,6 +246,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Parole chiave';
+$lang['img_width']             = 'Larghezza';
+$lang['img_height']            = 'Altezza';
+$lang['img_manager']           = 'Guarda nel gestore media';
 $lang['subscr_subscribe_success'] = 'Aggiunto %s alla lista di sottoscrizioni %s';
 $lang['subscr_subscribe_error'] = 'Impossibile aggiungere %s alla lista di sottoscrizioni %s';
 $lang['subscr_subscribe_noaddress'] = 'Non esiste alcun indirizzo associato al tuo account, non puoi essere aggiunto alla lista di sottoscrizioni';
@@ -238,6 +267,7 @@ $lang['subscr_style_digest']   = 'email riassuntiva delle modifiche di ogni pagi
 $lang['subscr_style_list']     = 'elenco delle pagine modificate dall\'ultima email';
 $lang['authmodfailed']         = 'La configurazione dell\'autenticazione non è corretta. Informa l\'amministratore di questo wiki.';
 $lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, informa l\'amministratore di questo wiki.';
+$lang['authpwdexpire']         = 'La tua password scadrà in %d giorni, dovresti cambiarla quanto prima.';
 $lang['i_chooselang']          = 'Scegli la lingua';
 $lang['i_installer']           = 'Installazione di DokuWiki';
 $lang['i_wikiname']            = 'Nome Wiki';
@@ -271,3 +301,24 @@ $lang['hours']                 = '%d ore fa';
 $lang['minutes']               = '%d minuti fa';
 $lang['seconds']               = '%d secondi fa';
 $lang['wordblock']             = 'La modifica non è stata salvata perché contiene testo bloccato (spam).';
+$lang['media_uploadtab']       = 'Upload';
+$lang['media_searchtab']       = 'Cerca';
+$lang['media_file']            = 'File';
+$lang['media_viewtab']         = 'Guarda';
+$lang['media_edittab']         = 'Modifica';
+$lang['media_historytab']      = 'Storia';
+$lang['media_list_thumbs']     = 'Miniatura';
+$lang['media_list_rows']       = 'Righe';
+$lang['media_sort_name']       = 'Nome';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Scegli il namespace';
+$lang['media_files']           = 'File in %s';
+$lang['media_upload']          = 'Upload al %s';
+$lang['media_search']          = 'Cerca in %s';
+$lang['media_view']            = '%s';
+$lang['media_edit']            = 'Modifica %s';
+$lang['media_history']         = 'Storia di %s';
+$lang['media_perm_read']       = 'Spiacente, non hai abbastanza privilegi per leggere i files.';
+$lang['media_perm_upload']     = 'Spiacente, non hai abbastanza privilegi per caricare files.';
+$lang['media_update']          = 'Carica nuova versione';
+$lang['media_restore']         = 'Ripristina questa versione';
