@@ -44,7 +44,6 @@ $lang['btn_backtomedia']       = 'Ad media redire';
 $lang['btn_subscribe']         = 'Custodire';
 $lang['btn_profile']           = 'Tabellam nouare';
 $lang['btn_reset']             = 'Abrogare';
-$lang['btn_resendpwd']         = 'Tesseram nouam cursu interretiali petere';
 $lang['btn_draft']             = 'Propositum recensere';
 $lang['btn_recover']           = 'Propositum reficere';
 $lang['btn_draftdel']          = 'Propositum delere';
@@ -79,7 +78,6 @@ $lang['profnoempty']           = 'Omnes campi complendi sunt.';
 $lang['profchanged']           = 'Tabella Sodalis feliciter nouatur';
 $lang['pwdforget']             = 'Tesseram amisistine? Nouam petere';
 $lang['resendna']              = 'Tesseram non mutare potest.';
-$lang['resendpwd']             = 'Tesseram mitte';
 $lang['resendpwdmissing']      = 'Omnes campi complendi sunt.';
 $lang['resendpwdnouser']       = 'In tabellis Sodalium nomen non inuentum est.';
 $lang['resendpwdbadauth']      = 'Tesseram non legitima est.';
