@@ -39,12 +39,13 @@ $lang['btn_backtomedia']       = 'Atpakaļ uz mēdiju failu izvēli';
 $lang['btn_subscribe']         = 'Abonēt izmaiņu paziņojumus';
 $lang['btn_profile']           = 'Labot savu profilu';
 $lang['btn_reset']             = 'Atsaukt izmaiņas';
-$lang['btn_resendpwd']         = 'Nosūtīt jaunu paroli';
 $lang['btn_draft']             = 'Labot melnrakstu';
 $lang['btn_recover']           = 'Atjaunot melnrakstu';
 $lang['btn_draftdel']          = 'Dzēst melnrakstu';
 $lang['btn_revert']            = 'Atjaunot';
 $lang['btn_register']          = 'Reģistrēties';
+$lang['btn_apply']             = 'Labi';
+$lang['btn_media']             = 'Mēdiju pārvaldnieks';
 $lang['loggedinas']            = 'Pieteicies kā';
 $lang['user']                  = 'Lietotājvārds';
 $lang['pass']                  = 'Parole';
@@ -74,7 +75,6 @@ $lang['profnoempty']           = 'Bez vārda vai e-pasta adreses nevar.';
 $lang['profchanged']           = 'Profils veiksmīgi izlabots.';
 $lang['pwdforget']             = 'Aizmirsi paroli? Saņem jaunu';
 $lang['resendna']              = 'Paroļu izsūtīšanu nepiedāvāju.';
-$lang['resendpwd']             = 'Nosūtīt jaunu paroli lietotājam';
 $lang['resendpwdmissing']      = 'Atvaino, jāizpilda visas ailes.';
 $lang['resendpwdnouser']       = 'Atvaino, tāda lietotāja nav.';
 $lang['resendpwdbadauth']      = 'Atvaino, šis autorizācijas kods nav derīgs. Pārliecinies, ka lietoji pilnu apstiprināšanas adresi.';
@@ -89,7 +89,7 @@ $lang['txt_filename']          = 'Ievadi vikivārdu (nav obligāts)';
 $lang['txt_overwrt']           = 'Aizstāt esošo failu';
 $lang['lockedby']              = 'Patlaban bloķējis ';
 $lang['lockexpire']            = 'Bloķējums beigsies ';
-$lang['willexpire']            = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';
+$lang['js']['willexpire']      = 'Tavs bloķējums uz šo lapu pēc minūtes beigsies.\nLai izvairītos no konflikta, nospied Iepriekšapskata pogu\n un bloķējuma laiku sāks skaitīt no jauna.';
 $lang['js']['notsavedyet']     = 'Veiktas bet nav saglabātas izmaiņas.
 Vai tiešām tās nevajag?';
 $lang['js']['searchmedia']     = 'Meklēt failus';
@@ -121,7 +121,15 @@ Protams, ka vari saiti kopēt un iespraust citā programmā.';
 $lang['js']['linkwiz']         = 'Saišu vednis';
 $lang['js']['linkto']          = 'Saite uz: ';
 $lang['js']['del_confirm']     = 'Dzēst šo šķirkli?';
-$lang['js']['mu_btn']          = 'Augšuplādēt uzreiz vairākus failus.';
+$lang['js']['restore_confirm'] = 'Tiešām atjaunot šo versiju';
+$lang['js']['media_diff']      = 'Skatīt atšķirību';
+$lang['js']['media_diff_both'] = 'Blakus';
+$lang['js']['media_diff_opacity'] = 'Pārklāti';
+$lang['js']['media_select']    = 'Norādīt failus...';
+$lang['js']['media_upload_btn'] = 'Augšuplādēt';
+$lang['js']['media_done_btn']  = 'Gatavs';
+$lang['js']['media_drop']      = 'Nomet te augšuplādējamos failus';
+$lang['js']['media_overwrt']   = 'Rakstīt pāri esošajiem failiem';
 $lang['rssfailed']             = 'Kļūda saņemot saturu no ';
 $lang['nothingfound']          = 'Nekas nav atrasts.';
 $lang['mediaselect']           = 'Mēdiju faila izvēle';
@@ -160,7 +168,7 @@ $lang['diff_type']             = 'Skatīt atšķirības:';
 $lang['diff_inline']           = 'Iekļauti';
 $lang['diff_side']             = 'Blakus';
 $lang['line']                  = 'Rinda';
-$lang['breadcrumb']            = 'Ceļš';
+$lang['breadcrumb']            = 'Apmeklēts';
 $lang['youarehere']            = 'Tu atrodies šeit';
 $lang['lastmod']               = 'Labota';
 $lang['by']                    = ', labojis';
@@ -176,6 +184,10 @@ $lang['mail_changed']          = 'lapa mainīta:';
 $lang['mail_subscribe_list']   = 'Nodaļā mainītās lapas:';
 $lang['mail_new_user']         = 'Jauns lietotājs:';
 $lang['mail_upload']           = 'augšupielādētais fails:';
+$lang['changes_type']          = 'Skatīt izmaiņas';
+$lang['pages_changes']         = 'Lapās';
+$lang['media_changes']         = 'Mēdiju failos';
+$lang['both_changes']          = 'Gan lapās, gan mēdiju failos';
 $lang['qb_bold']               = 'Trekninājums';
 $lang['qb_italic']             = 'Kursīvs';
 $lang['qb_underl']             = 'Pasvītrojums';
@@ -216,6 +228,9 @@ $lang['img_copyr']             = 'Autortiesības';
 $lang['img_format']            = 'Formāts';
 $lang['img_camera']            = 'Fotoaparāts';
 $lang['img_keywords']          = 'Atslēgvārdi';
+$lang['img_width']             = 'Platums';
+$lang['img_height']            = 'Augstums';
+$lang['img_manager']           = 'Skatīt mēdiju pārvaldniekā';
 $lang['subscr_subscribe_success'] = '%s pievienots %s abonēšanas sarakstam';
 $lang['subscr_subscribe_error'] = 'Kļūme pievienojot %s %s abonēšanas sarakstam.';
 $lang['subscr_subscribe_noaddress'] = 'Nav zināma jūsu e-pasta adrese, tāpēc nevarat abonēt.';
@@ -230,9 +245,9 @@ $lang['subscr_m_unsubscribe']  = 'Atteikties no abonēšanas';
 $lang['subscr_m_subscribe']    = 'Abonēt';
 $lang['subscr_m_receive']      = 'Saņemt';
 $lang['subscr_style_every']    = 'vēstuli par katru izmaiņu';
-$lang['subscr_style_digest']   = 'kopsavilkumu par katru lapu';
-$lang['subscr_style_list']     = 'kopš pēdējās vēstules notikušo labojumu sarakstu';
-$lang['authmodfailed']         = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzo ziņo Wiki administratoram.';
+$lang['subscr_style_digest']   = 'kopsavilkumu par katru lapu (reizi %.2f dienās)';
+$lang['subscr_style_list']     = 'kopš pēdējās vēstules notikušo labojumu sarakstu (reizi %.2f dienās)';
+$lang['authmodfailed']         = 'Aplami konfigurēta lietotāju autentifikācija. Lūdzu ziņo Wiki administratoram.';
 $lang['authtempfail']          = 'Lietotāju autentifikācija pašlaik nedarbojas. Ja tas turpinās ilgstoši, lūduz ziņo Wiki administratoram.';
 $lang['i_chooselang']          = 'Izvēlies valodu';
 $lang['i_installer']           = 'DokuWiki instalētājs';
@@ -257,27 +272,35 @@ $lang['i_pol1']                = 'Publisks Wiki (lasa ikviens, raksta un augšup
 $lang['i_pol2']                = 'Slēgts Wiki (raksta, lasa un augšupielādē tikai reģistrēti lietotāji)';
 $lang['i_retry']               = 'Atkārtot';
 $lang['i_license']             = 'Ar kādu licenci saturs tiks publicēts:';
-$lang['mu_intro']              = 'Šeit var augšupielādēt uzreiz vairāku failus. Uzklikšķini Pārlūkot pogai, lai tos ieliktu rindā. Nospied Augšupielādēt, kad rinda sastādīta.';
-$lang['mu_gridname']           = 'Faila vārds';
-$lang['mu_gridsize']           = 'Izmērs';
-$lang['mu_gridstat']           = 'Statuss';
-$lang['mu_namespace']          = 'Nodaļa';
-$lang['mu_browse']             = 'Pārlūkot';
-$lang['mu_toobig']             = 'par lielu';
-$lang['mu_ready']              = 'gatavs augšupielādei';
-$lang['mu_done']               = 'pabeigts';
-$lang['mu_fail']               = 'neizdevās';
-$lang['mu_authfail']           = 'sesijas laiks iztecējis';
-$lang['mu_progress']           = '@PCT@% augšupielādēts';
-$lang['mu_filetypes']          = 'Atļautie failu tipi';
-$lang['mu_info']               = 'faili ir augšupielādēti.';
-$lang['mu_lasterr']            = 'Pēdējā ķļūda.';
 $lang['recent_global']         = 'Tu skati izmaiņas nodaļā <b>%s</b>. Ir iespējams <a href="%s">skatīt jaunākos grozījums visā viki</a>. ';
 $lang['years']                 = 'pirms %d gadiem';
 $lang['months']                = 'pirms %d mēnešiem';
-$lang['weeks']                 = 'pirms % nedēļām';
+$lang['weeks']                 = 'pirms %d nedēļām';
 $lang['days']                  = 'pirms %d  dienām';
 $lang['hours']                 = 'pirms %d stundām';
 $lang['minutes']               = 'pirms %d minūtēm';
 $lang['seconds']               = 'pirms %d sekundēm';
 $lang['wordblock']             = 'Grozījumus nevarēju saglabāt, jo tie satur aizliegto vārdu (spamu).';
+$lang['media_uploadtab']       = 'Augšuplādēt';
+$lang['media_searchtab']       = 'Meklēt';
+$lang['media_file']            = 'Fails';
+$lang['media_viewtab']         = 'Skatīt';
+$lang['media_edittab']         = 'Labot';
+$lang['media_historytab']      = 'Vēsture';
+$lang['media_list_thumbs']     = 'Sīktēli';
+$lang['media_list_rows']       = 'Rindas';
+$lang['media_sort_name']       = 'Nosaukums';
+$lang['media_sort_date']       = 'Datums';
+$lang['media_namespaces']      = 'Norādīt nodaļu';
+$lang['media_files']           = 'Faili nodaļā %s';
+$lang['media_upload']          = 'Augšuplādēt nodaļā %s';
+$lang['media_search']          = 'Meklēt nodaļā %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s nodaļā %s';
+$lang['media_edit']            = 'Labot %s';
+$lang['media_history']         = '%s vēsture';
+$lang['media_meta_edited']     = 'metadati laboti';
+$lang['media_perm_read']       = 'Atvainojiet, jums nav tiesību skatīt failus. ';
+$lang['media_perm_upload']     = 'Atvainojiet, jums nav tiesību augšupielādēt. ';
+$lang['media_update']          = 'Augšupielādēt jaunu versiju';
+$lang['media_restore']         = 'Atjaunot šo versiju';
