@@ -42,7 +42,6 @@ $lang['btn_backtomedia']       = 'Назад до изборот за медиа
 $lang['btn_subscribe']         = 'Менаџирај претплати';
 $lang['btn_profile']           = 'Ажурирај профил';
 $lang['btn_reset']             = 'Ресет';
-$lang['btn_resendpwd']         = 'Испрати нов пасворд';
 $lang['btn_draft']             = 'Уреди скица';
 $lang['btn_recover']           = 'Поврати скица';
 $lang['btn_draftdel']          = 'Избриши скица';
@@ -77,7 +76,6 @@ $lang['profnoempty']           = 'Празно име или адреса за 
 $lang['profchanged']           = 'Корисничкиот профил е успешно ажуриран.';
 $lang['pwdforget']             = 'Ја заборавивте лозинката? Добијте нова';
 $lang['resendna']              = 'Ова вики не поддржува повторно испраќање на лозинка.';
-$lang['resendpwd']             = 'Испрати нова лозинка за';
 $lang['resendpwdmissing']      = 'Жалам, морате да ги пополните сите полиња.';
 $lang['resendpwdnouser']       = 'Жалам, таков корисник не постои во нашата база со податоци.';
 $lang['resendpwdbadauth']      = 'Жалам, овај код за валидација не е валиден. Проверете повторно дали ја искористивте целосната врска за потврда.';
