@@ -44,14 +44,16 @@ $lang['btn_back']              = 'मागॆ';
 $lang['btn_backlink']          = 'येथे काय जोडले आहे';
 $lang['btn_backtomedia']       = 'परत माध्यम फाइल निवडीकड़े';
 $lang['btn_subscribe']         = 'पृष्ठाच्या बदलांची पुरवणी (फीड) लावा ';
-$lang['btn_unsubscribe']       = 'पृष्ठाच्या बदलांची पुरवणी (फीड) बंद करा';
 $lang['btn_profile']           = 'प्रोफाइल अद्ययावत करा';
 $lang['btn_reset']             = 'रिसेट';
-$lang['btn_resendpwd']         = 'कृपया परवलीचा नवीन शब्द माझ्या इमेल पत्त्यावर पाठविणे.';
+$lang['btn_resendpwd']         = 'नवीन पासवर्ड';
 $lang['btn_draft']             = 'प्रत संपादन';
 $lang['btn_recover']           = 'प्रत परत मिळवा';
 $lang['btn_draftdel']          = 'प्रत रद्द';
+$lang['btn_revert']            = 'पुनर्स्थापन';
 $lang['btn_register']          = 'नोंदणी';
+$lang['btn_apply']             = 'लागू';
+$lang['btn_media']             = 'मिडिया व्यवस्थापक';
 $lang['loggedinas']            = 'लॉगिन नाव';
 $lang['user']                  = 'वापरकर्ता';
 $lang['pass']                  = 'परवलीचा शब्द';
@@ -82,20 +84,58 @@ $lang['profchanged']           = 'सदस्याची प्रोफाइ
 $lang['pwdforget']             = 'परवलीचा शब्द विसरला आहे का? नविन मागवा.';
 $lang['resendna']              = 'ह्या विकी मधे परवलीचा शब्द परत पाथाव्न्याची सुविधा नाही.';
 $lang['resendpwd']             = 'नविन परवली इच्छुक';
-$lang['resendpwdmissing']      = 'कृपया सर्व रकाने भरा.';
+$lang['resendpwdmissing']      = 'माफ करा, पण सर्व जागा भरल्या पाहिजेत.';
 $lang['resendpwdnouser']       = 'माफ़ करा, हा सदस्य आमच्या माहितिसंग्रहात सापडला नाही.';
 $lang['resendpwdbadauth']      = 'माफ़ करा, हा अधिकार कोड बरोबर नाही. कृपया आपण पूर्ण शिकामोर्तबाची लिंक वापरल्याची खात्री करा.';
 $lang['resendpwdconfirm']      = 'शिक्कामोर्तबाची लिंक ईमेल द्वारा पाठवली आहे.';
 $lang['resendpwdsuccess']      = 'शिक्कामोर्तबाची लिंक ईमेल द्वारा पाठवली आहे.';
 $lang['license']               = 'विशिष्ठ नोंद केलि नसल्यास ह्या विकी वरील सर्व मजकूर खालील लायसन्स मधे मोडतो : ';
 $lang['licenseok']             = 'नोंद : हे पृष्ठ संपादित केल्यास तुम्ही तुमचे योगदान खालील लायसन्स अंतर्गत येइल : ';
+$lang['searchmedia']           = 'फाईल शोधा:';
+$lang['searchmedia_in']        = '%s मधे शोधा';
 $lang['txt_upload']            = 'अपलोड करण्याची फाइल निवडा';
 $lang['txt_filename']          = 'अपलोड उर्फ़ ( वैकल्पिक )';
 $lang['txt_overwrt']           = 'अस्तित्वात असलेल्या फाइलवरच सुरक्षित करा.';
 $lang['lockedby']              = 'सध्या लॉक करणारा :';
 $lang['lockexpire']            = 'सध्या लॉक करणारा :';
-$lang['js']['willexpire']            = 'हे पृष्ठ संपादित करण्यासाठी मिळालेले लॉक एखाद्या मिनिटात संपणार आहे.\n चुका होऊ नयेत म्हणुन कृपया प्रीव्यू बटन दाबुन लॉक ची वेळ पुन्हा चालू करा.';
-$lang['js']['notsavedyet']     = "सुरक्षित न केलेले बदल नष्ट होतील. नक्की करू का ?";
+$lang['js']['willexpire']      = 'हे पृष्ठ संपादित करण्यासाठी मिळालेले लॉक एखाद्या मिनिटात संपणार आहे.\n चुका होऊ नयेत म्हणुन कृपया प्रीव्यू बटन दाबुन लॉक ची वेळ पुन्हा चालू करा.';
+$lang['js']['notsavedyet']     = 'सुरक्षित न केलेले बदल नष्ट होतील. नक्की करू का ?';
+$lang['js']['searchmedia']     = 'फाईल्ससाठी शोधा';
+$lang['js']['keepopen']        = 'निवड केल्यावर विण्डो उघडी ठेवा';
+$lang['js']['hidedetails']     = 'सविस्तर मजकूर लपवा';
+$lang['js']['mediatitle']      = 'लिंक सेटिंग';
+$lang['js']['mediadisplay']    = 'लिंकचा प्रकार';
+$lang['js']['mediaalign']      = 'जुळवणी';
+$lang['js']['mediasize']       = 'प्रतिमेचा आकार';
+$lang['js']['mediatarget']     = 'लिंकचे लक्ष्य';
+$lang['js']['mediaclose']      = 'बंद';
+$lang['js']['mediadisplayimg'] = 'प्रतिमा दाखवा.';
+$lang['js']['mediadisplaylnk'] = 'फक्त लिंक दाखवा.';
+$lang['js']['mediasmall']      = 'लहान आवृत्ती';
+$lang['js']['mediamedium']     = 'माध्यम आवृत्ती';
+$lang['js']['medialarge']      = 'मोठी आवृत्ती';
+$lang['js']['mediaoriginal']   = 'मूळ आवृत्ती';
+$lang['js']['medialnk']        = 'सविस्तर माहितीकडेची लिंक';
+$lang['js']['mediadirect']     = 'मूळ मजकुराकडे थेट लिंक';
+$lang['js']['medianolnk']      = 'लिंक नको';
+$lang['js']['medianolink']     = 'प्रतिमा लिंक करू नका';
+$lang['js']['medialeft']       = 'प्रतिमा डाव्या बाजूला जुळवून घ्या.';
+$lang['js']['mediaright']      = 'प्रतिमा उजव्या बाजूला जुळवून घ्या.';
+$lang['js']['mediacenter']     = 'प्रतिमा मध्यभागी जुळवून घ्या.';
+$lang['js']['medianoalign']    = 'जुळवाजुळव वापरू नका.';
+$lang['js']['nosmblinks']      = 'विन्डोज़ शेअर ला लिंक केल्यास ते फक्त मायक्रोसॉफ़्ट इन्टरनेट एक्स्प्लोरर वरच चालते. तरी तुम्ही लिंक कॉपी करू शकता.';
+$lang['js']['linkwiz']         = 'लिंक जादूगार';
+$lang['js']['linkto']          = 'याला लिंक करा:';
+$lang['js']['del_confirm']     = 'निवडलेल्या गोष्टी नक्की नष्ट करू का ?';
+$lang['js']['restore_confirm'] = 'हि आवृत्ती खरोखर पुनर्स्थापित करू का?';
+$lang['js']['media_diff']      = 'फरक बघू:';
+$lang['js']['media_diff_both'] = 'बाजूबाजूला';
+$lang['js']['media_diff_portions'] = 'स्वाईप';
+$lang['js']['media_select']    = 'फाईल निवड...';
+$lang['js']['media_upload_btn'] = 'अपलोड';
+$lang['js']['media_done_btn']  = 'झालं';
+$lang['js']['media_drop']      = 'अपलोड करण्यासाठी इथे फाईल टाका';
+$lang['js']['media_cancel']    = 'काढा';
 $lang['rssfailed']             = 'ही पुरवणी आणण्यात काही चूक झाली:';
 $lang['nothingfound']          = 'काही सापडला नाही.';
 $lang['mediaselect']           = 'दृकश्राव्य फाइल';
@@ -113,9 +153,7 @@ $lang['deletefail']            = '%s ही फाइल नष्ट करू
 $lang['mediainuse']            = '%s ही फाइल नष्ट केली नाही - ती अजुन वापरात आहे.';
 $lang['namespaces']            = 'नेमस्पेस';
 $lang['mediafiles']            = 'मध्ये उपलब्ध असलेल्या फाइल';
-$lang['js']['keepopen']        = 'निवड केल्यावर विण्डो उघडी ठेवा';
-$lang['js']['hidedetails']     = 'सविस्तर मजकूर लपवा';
-$lang['js']['nosmblinks']      = 'विन्डोज़ शेअर ला लिंक केल्यास ते फक्त मायक्रोसॉफ़्ट इन्टरनेट एक्स्प्लोरर वरच चालते. तरी तुम्ही लिंक कॉपी करू शकता.';
+$lang['accessdenied']          = 'तुम्हाला हे पान बघायची परवानगी नाही.';
 $lang['mediausage']            = 'ह्या फाइलचा संदर्भ देण्यासाठी खालील सिन्टॅक्स वापरा :';
 $lang['mediaview']             = 'मूळ फाइल बघू ';
 $lang['mediaroot']             = 'रूट';
@@ -131,6 +169,10 @@ $lang['current']               = 'चालू';
 $lang['yours']                 = 'तुमची आवृत्ति';
 $lang['diff']                  = 'सध्याच्या आवृत्तिंशी फरक दाखवा';
 $lang['diff2']                 = 'निवडलेल्या आवृत्तिंमधील फरक दाखवा';
+$lang['difflink']              = 'ह्या तुलना दृष्टीकोनाला लिंक करा';
+$lang['diff_type']             = 'फरक बघू:';
+$lang['diff_inline']           = 'एका ओळीत';
+$lang['diff_side']             = 'बाजूबाजूला';
 $lang['line']                  = 'ओळ';
 $lang['breadcrumb']            = 'मागमूस';
 $lang['youarehere']            = 'तुम्ही इथे आहात';
@@ -142,10 +184,21 @@ $lang['restored']              = 'जुनी आवृत्ति पुन
 $lang['external_edit']         = 'बाहेरून संपादित';
 $lang['summary']               = 'सारांश बदला';
 $lang['noflash']               = 'ही माहिती दाखवण्यासाठी <a href="http://www.adobe.com/products/flashplayer/">अडोब फ्लॅश प्लेअर</a> ची गरज आहे.';
+$lang['download']              = 'तुकडा डाउनलोड करा';
+$lang['tools']                 = 'साधने';
+$lang['user_tools']            = 'युजरची साधने';
+$lang['site_tools']            = 'साईटची साधने';
+$lang['page_tools']            = 'पानाची साधने';
+$lang['skip_to_content']       = 'सरळ मजकुराकडे ';
 $lang['mail_newpage']          = 'पृष्ठ जोडले : ';
 $lang['mail_changed']          = 'पृष्ठ बदलले : ';
+$lang['mail_subscribe_list']   = 'ह्या नेमस्पेस नाढे बदललेली पाने:';
 $lang['mail_new_user']         = 'नवीन सदस्य : ';
 $lang['mail_upload']           = 'फाइल अपलोड केली : ';
+$lang['changes_type']          = 'ह्याचे बदल बघू';
+$lang['pages_changes']         = 'पाने';
+$lang['media_changes']         = 'मिडिया फाईल';
+$lang['both_changes']          = 'पाने आणि मिडिया फाईल दोन्ही';
 $lang['qb_bold']               = 'ठळक मजकूर';
 $lang['qb_italic']             = 'तिरका मजकूर';
 $lang['qb_underl']             = 'अधोरेखित मजकूर';
@@ -156,6 +209,11 @@ $lang['qb_h2']                 = 'दुसर्या पातळीचे 
 $lang['qb_h3']                 = 'तिसर्या पातळीचे शीर्षक';
 $lang['qb_h4']                 = 'चवथ्या पातळीचे शीर्षक';
 $lang['qb_h5']                 = 'पाचव्या पातळीचे शीर्षक';
+$lang['qb_h']                  = 'शीर्षक';
+$lang['qb_hs']                 = 'शीर्षक निवड';
+$lang['qb_hplus']              = 'उंच शीर्षक';
+$lang['qb_hminus']             = 'खालचं शीर्षक';
+$lang['qb_hequal']             = 'समान लेवलचे शीर्षक';
 $lang['qb_link']               = 'अंतर्गत लिंक';
 $lang['qb_extlink']            = 'बाह्य लिंक';
 $lang['qb_hr']                 = 'आडवी पट्टी';
@@ -165,7 +223,7 @@ $lang['qb_media']              = 'प्रतिमा आणि इतर फ
 $lang['qb_sig']                = 'स्वाक्षरी टाका';
 $lang['qb_smileys']            = 'स्माइली';
 $lang['qb_chars']              = 'ख़ास चिन्ह';
-$lang['js']['del_confirm']           = 'निवडलेल्या गोष्टी नक्की नष्ट करू का ?';
+$lang['upperns']               = 'ह्यावरच्या नेमस्पेसकडे उडी मारा';
 $lang['admin_register']        = 'नवीन सदस्य';
 $lang['metaedit']              = 'मेटाडेटा बदला';
 $lang['metasaveerr']           = 'मेटाडेटा सुरक्षित झाला नाही';
@@ -181,11 +239,9 @@ $lang['img_copyr']             = 'कॉपीराइट';
 $lang['img_format']            = 'प्रकार';
 $lang['img_camera']            = 'कॅमेरा';
 $lang['img_keywords']          = 'मुख्य शब्द';
-$lang['subscribe_success']     = '%s  ला %s च्या पुरवणिसाठि नोंदवले';
-$lang['subscribe_error']       = '%s  ला %s च्या पुरवणिसाठि नोंदवताना चूक झाली';
-$lang['subscribe_noaddress']   = 'तुमच्या लॉगिनशी  सम्बंधित कुठलाही पत्ता नाही , त्यामुळे पुरवणिसाठि नोंद केली जाऊ शकत नाही';
-$lang['unsubscribe_success']   = '%s ला %s च्या पुरवणी यादी मधून काढून टाकले';
-$lang['unsubscribe_error']     = '%s  ला  %s  च्या पुरवणी यादी मधून काढून टाकण्यात चूक झाली';
+$lang['img_width']             = 'रुंदी';
+$lang['img_height']            = 'उंची';
+$lang['img_manager']           = 'मिडिया व्यवस्थापकात बघू';
 $lang['authmodfailed']         = 'सदस्य अधिकृत करण्याची व्यवस्था चुकीची आहे. कृपया तुमच्या विकीच्या व्यवस्थापकाशी सम्पर्क साधा.';
 $lang['authtempfail']          = 'सदस्य अधिकृत करण्याची सुविधा सध्या चालू नाही. सतत हा मजकूर दिसल्यास कृपया तुमच्या विकीच्या व्यवस्थापकाशी सम्पर्क साधा.';
 $lang['i_chooselang']          = 'तुमची भाषा निवडा';
