@@ -40,7 +40,6 @@ $lang['btn_subscribe']         = 'पृष्ठ परिवर्तन ग
 $lang['btn_unsubscribe']       = 'पृष्ठ परिवर्तन अग्राह्य गर्नुहोस्';
 $lang['btn_profile']           = 'प्रोफाइल अध्यावधिक गर्नुहोस् ';
 $lang['btn_reset']             = 'पूर्वरुपमा फर्काउनुहोस';
-$lang['btn_resendpwd']         = 'नयाँ प्रवेश शव्द(पासवर्ड) पठाउनुहोस् ';
 $lang['btn_draft']             = ' ड्राफ्ट सम्पादन गर्नुहोस् ';
 $lang['btn_recover']           = 'पहिलेको ड्राफ्ट हासिल गर्नुहोस ';
 $lang['btn_draftdel']          = ' ड्राफ्ट मेटाउनुहोस् ';
@@ -75,7 +74,6 @@ $lang['profchanged']           = 'प्रयोगकर्ताको प्
 $lang['pwdforget']             = 'आफ्नो पासवर्ड भुल्नु भयो ? नयाँ हासिल गर्नुहोस् ';
 $lang['resendna']              = 'यो विकिबाट प्रवेशशव्द पठाउन समर्थित छैन ।';
 $lang['resendpwd']             = 'नयाँ  प्रवेशशव्द पठाउनुहोस् ';
-$lang['resendpwdmissing']      = 'माफ गर्नुहोस् , तपाईले सबै ठाउ भर्नुपर्छ। ';
 $lang['resendpwdnouser']       = 'माफ गर्नुहोस्,  हाम्रो डेटावेसमा यो प्रयोगकर्ता भेटिएन ।';
 $lang['resendpwdbadauth']      = 'माफ गर्नुहोस् , यो अनुमति चिन्ह गलत छ। तपाईले पूरै जानकारी लिङ्क प्रयोग गर्नु पर्नेछ। ';
 $lang['resendpwdconfirm']      = 'तपाईको इमेलमा कन्फरमेशन लिङ्क पठाइएको छ। ';
