@@ -14,6 +14,9 @@
  * @author Matthias Carchon <webmaster@c-mattic.be>
  * @author Marijn Hofstra <hofstra.m@gmail.com>
  * @author Timon Van Overveldt <timonvo@gmail.com>
+ * @author Jeroen
+ * @author Ricardo Guijt <ricardoguijt@gmail.com>
+ * @author Gerrit <klapinklapin@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -49,12 +52,14 @@ $lang['btn_backtomedia']       = 'Terug naar Bestandsselectie';
 $lang['btn_subscribe']         = 'Inschrijven wijzigingen';
 $lang['btn_profile']           = 'Profiel aanpassen';
 $lang['btn_reset']             = 'Wissen';
-$lang['btn_resendpwd']         = 'Stuur een nieuw wachtwoord';
+$lang['btn_resendpwd']         = 'Nieuw wachtwoord bepalen';
 $lang['btn_draft']             = 'Bewerk concept';
 $lang['btn_recover']           = 'Herstel concept';
 $lang['btn_draftdel']          = 'Verwijder concept';
 $lang['btn_revert']            = 'Herstellen';
 $lang['btn_register']          = 'Registreren';
+$lang['btn_apply']             = 'Toepassen';
+$lang['btn_media']             = 'Mediabeheerder';
 $lang['loggedinas']            = 'Ingelogd als';
 $lang['user']                  = 'Gebruikersnaam';
 $lang['pass']                  = 'Wachtwoord';
@@ -84,7 +89,7 @@ $lang['profnoempty']           = 'Een lege gebruikersnaam of e-mailadres is niet
 $lang['profchanged']           = 'Gebruikersprofiel succesvol aangepast';
 $lang['pwdforget']             = 'Je wachtwoord vergeten? Vraag een nieuw wachtwoord aan';
 $lang['resendna']              = 'Deze wiki ondersteunt het verzenden van wachtwoorden niet';
-$lang['resendpwd']             = 'Stuur een nieuw wachtwoord voor';
+$lang['resendpwd']             = 'Nieuw wachtwoord bepalen voor';
 $lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen.';
 $lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database.';
 $lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
@@ -97,9 +102,10 @@ $lang['searchmedia_in']        = 'Zoek in %s';
 $lang['txt_upload']            = 'Selecteer een bestand om te uploaden';
 $lang['txt_filename']          = 'Vul nieuwe naam in (optioneel)';
 $lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
+$lang['maxuploadsize']         = 'Max %s per bestand';
 $lang['lockedby']              = 'Momenteel in gebruik door';
 $lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op';
-$lang['willexpire']            = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
+$lang['js']['willexpire']      = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
 $lang['js']['notsavedyet']     = 'Nog niet bewaarde wijzigingen zullen verloren gaan.
 Weet je zeker dat je wilt doorgaan?';
 $lang['js']['searchmedia']     = 'Zoek naar bestanden';
@@ -131,7 +137,17 @@ Je kan de link wel kopiëren en plakken.';
 $lang['js']['linkwiz']         = 'Linkwizard';
 $lang['js']['linkto']          = 'Link naar:';
 $lang['js']['del_confirm']     = 'Item(s) verwijderen?';
-$lang['js']['mu_btn']          = 'Meerdere files tegelijk uploaden';
+$lang['js']['restore_confirm'] = 'Werkelijk deze versie terugzetten?';
+$lang['js']['media_diff']      = 'Verschillen bekijken:';
+$lang['js']['media_diff_both'] = 'Naast elkaar';
+$lang['js']['media_diff_opacity'] = 'Doorschijnend';
+$lang['js']['media_diff_portions'] = 'Swipe';
+$lang['js']['media_select']    = 'Selecteer bestanden';
+$lang['js']['media_upload_btn'] = 'Uploaden';
+$lang['js']['media_done_btn']  = 'Klaar';
+$lang['js']['media_drop']      = 'Sleep bestanden hierheen om ze te uploaden';
+$lang['js']['media_cancel']    = 'Verwijderen';
+$lang['js']['media_overwrt']   = 'Bestaande bestanden overschrijven';
 $lang['rssfailed']             = 'Er is een fout opgetreden bij het ophalen van de feed: ';
 $lang['nothingfound']          = 'Er werd niets gevonden.';
 $lang['mediaselect']           = 'Bestandsselectie';
@@ -181,11 +197,21 @@ $lang['external_edit']         = 'Externe bewerking';
 $lang['summary']               = 'Samenvatting wijziging';
 $lang['noflash']               = 'De <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is vereist om de pagina te kunnen weergeven.';
 $lang['download']              = 'Download fragment';
+$lang['tools']                 = 'Hulpmiddelen';
+$lang['user_tools']            = 'Gebruikershulpmiddelen';
+$lang['site_tools']            = 'Site-hulpmiddelen';
+$lang['page_tools']            = 'Paginahulpmiddelen';
+$lang['skip_to_content']       = 'spring naar tekst';
+$lang['sidebar']               = 'Zijbalk';
 $lang['mail_newpage']          = 'pagina toegevoegd:';
 $lang['mail_changed']          = 'pagina aangepast:';
 $lang['mail_subscribe_list']   = 'Pagina\'s veranderd in namespace:';
 $lang['mail_new_user']         = 'nieuwe gebruiker:';
 $lang['mail_upload']           = 'bestand geüpload:';
+$lang['changes_type']          = 'Bekijk wijzigingen van';
+$lang['pages_changes']         = 'Pagina\'s';
+$lang['media_changes']         = 'Mediabestanden';
+$lang['both_changes']          = 'Zowel pagina\'s als mediabestanden';
 $lang['qb_bold']               = 'Vette tekst';
 $lang['qb_italic']             = 'Cursieve tekst';
 $lang['qb_underl']             = 'Onderstreepte tekst';
@@ -226,6 +252,9 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formaat';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Trefwoorden';
+$lang['img_width']             = 'Breedte';
+$lang['img_height']            = 'Hoogte';
+$lang['img_manager']           = 'In mediabeheerder bekijken';
 $lang['subscr_subscribe_success'] = '%s is ingeschreven voor %s';
 $lang['subscr_subscribe_error'] = 'Fout bij inschrijven van %s voor %s';
 $lang['subscr_subscribe_noaddress'] = 'Er is geen emailadres geassocieerd met uw account, u kunt daardoor niet worden ingeschreven.';
@@ -244,13 +273,14 @@ $lang['subscr_style_digest']   = 'Samenvattings-email met wijzigingen per pagina
 $lang['subscr_style_list']     = 'Lijst van veranderde pagina\'s sinds laatste email (elke %.2f dagen)';
 $lang['authmodfailed']         = 'Ongeldige gebruikersauthenticatie-configuratie. Informeer de wikibeheerder.';
 $lang['authtempfail']          = 'Gebruikersauthenticatie is tijdelijk niet beschikbaar. Als deze situatie zich blijft voordoen, informeer dan de wikibeheerder.';
+$lang['authpwdexpire']         = 'Je wachtwoord verloopt in %d dagen, je moet het binnenkort veranderen';
 $lang['i_chooselang']          = 'Kies je taal';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Wikinaam';
 $lang['i_enableacl']           = 'ACLs inschakelen (aanbevolen)';
 $lang['i_superuser']           = 'Superuser';
 $lang['i_problems']            = 'De installer vond problemen, hieronder aangegeven. Verhelp deze voor je doorgaat.';
-$lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installatie-instructies</a>';
+$lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://dokuwiki.org/install">Dokuwiki installatie-instructies</a>';
 $lang['i_funcna']              = 'PHP functie <code>%s</code> is niet beschikbaar. Wellicht heeft je hosting provider deze uitgeschakeld?';
 $lang['i_phpver']              = 'PHP-versie <code>%s</code> is lager dan de vereiste <code>%s</code>. Upgrade PHP.';
 $lang['i_permfail']            = '<code>%s</code> is niet schrijfbaar voor DokuWiki. Pas de permissie-instellingen van deze directory aan.';
@@ -266,21 +296,6 @@ $lang['i_pol1']                = 'Publieke wiki (lezen voor iedereen, schrijven
 $lang['i_pol2']                = 'Besloten wiki (lezen, schrijven en uploaden alleen voor geregistreerde gebruikers)';
 $lang['i_retry']               = 'Opnieuw';
 $lang['i_license']             = 'Kies a.u.b. een licentie die u voor uw inhoud wilt gebruiken:';
-$lang['mu_intro']              = 'Hiier kun je meerdere bestanden tegelijk uploaden. Klik de blader-knop om ze aan de lijst toe te voegen. Klik Upload als je klaar bent.';
-$lang['mu_gridname']           = 'Bestandsnaam';
-$lang['mu_gridsize']           = 'Grootte';
-$lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Namespace';
-$lang['mu_browse']             = 'Blader';
-$lang['mu_toobig']             = 'te groot';
-$lang['mu_ready']              = 'Klaar om te uploaden';
-$lang['mu_done']               = 'klaar';
-$lang['mu_fail']               = 'mislukt';
-$lang['mu_authfail']           = 'sessie beëindigd';
-$lang['mu_progress']           = '@PCT@% geüpload';
-$lang['mu_filetypes']          = 'Toegestane bestandstypes';
-$lang['mu_info']               = 'bestanden geüpload.';
-$lang['mu_lasterr']            = 'Laatste foutmelding:';
 $lang['recent_global']         = 'Je bekijkt momenteel de wijzigingen binnen de <b>%s</b> namespace. Je kunt ook de <a href="%s">recente wijzigingen van de hele wiki</a> bekijken.';
 $lang['years']                 = '%d jaar geleden';
 $lang['months']                = '%d maand geleden';
@@ -290,3 +305,26 @@ $lang['hours']                 = '%d uren geleden';
 $lang['minutes']               = '%d minuten geleden';
 $lang['seconds']               = '%d seconden geleden';
 $lang['wordblock']             = 'Uw wijziging is niet opgeslagen omdat deze niet-toegestane tekst bevat (spam).';
+$lang['media_uploadtab']       = 'Uploaden';
+$lang['media_searchtab']       = 'Zoeken';
+$lang['media_file']            = 'Bestand';
+$lang['media_viewtab']         = 'Beeld';
+$lang['media_edittab']         = 'Bewerken';
+$lang['media_historytab']      = 'Geschiedenis';
+$lang['media_list_thumbs']     = 'Miniatuurweergaven';
+$lang['media_list_rows']       = 'Regels';
+$lang['media_sort_name']       = 'Naam';
+$lang['media_sort_date']       = 'Datum';
+$lang['media_namespaces']      = 'Kies namespace';
+$lang['media_files']           = 'Bestanden in %s';
+$lang['media_upload']          = 'Upload naar %s';
+$lang['media_search']          = 'Zoeken in %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s bij %s';
+$lang['media_edit']            = '%s bewerken';
+$lang['media_history']         = 'Geschiedenis van %s';
+$lang['media_meta_edited']     = 'Metagegevens bewerkt';
+$lang['media_perm_read']       = 'Sorry, u heeft niet voldoende rechten om bestanden te lezen.';
+$lang['media_perm_upload']     = 'Sorry, u heeft niet voldoende rechten om bestanden te uploaden.';
+$lang['media_update']          = 'Upload nieuwe versie';
+$lang['media_restore']         = 'Deze versie terugzetten';
