@@ -53,7 +53,6 @@ $lang['btn_backtomedia']       = 'Tilbake til valg av mediafil';
 $lang['btn_subscribe']         = 'Abonnér på endringer';
 $lang['btn_profile']           = 'Oppdater profil';
 $lang['btn_reset']             = 'Tilbakestill';
-$lang['btn_resendpwd']         = 'Send nytt passord';
 $lang['btn_draft']             = 'Rediger kladd';
 $lang['btn_recover']           = 'Gjennvinn kladd';
 $lang['btn_draftdel']          = 'Slett kladd';
@@ -90,7 +89,6 @@ $lang['profnoempty']           = 'Tomt navn- eller e-postfelt er ikke tillatt.';
 $lang['profchanged']           = 'Brukerprofilen ble vellykket oppdatert.';
 $lang['pwdforget']             = 'Glemt passordet ditt? Få deg et nytt';
 $lang['resendna']              = 'Denne wikien støtter ikke nyutsending av passord.';
-$lang['resendpwd']             = 'Send nytt passord for';
 $lang['resendpwdmissing']      = 'Beklager, du må fylle inn alle felt.';
 $lang['resendpwdnouser']       = 'Beklager, vi kan ikke finne denne brukeren i vår database.';
 $lang['resendpwdbadauth']      = 'Beklager, denne autorisasjonskoden er ikke gyldig. Sjekk at du brukte hele bekreftelseslenken.';
@@ -325,4 +323,3 @@ $lang['media_perm_read']       = 'Beklager, du har ikke tilgang til å lese file
 $lang['media_perm_upload']     = 'Beklager, du har ikke tilgang til å laste opp filer.';
 $lang['media_update']          = 'Last opp ny versjon';
 $lang['media_restore']         = 'Gjenopprett denne versjonen';
-$lang['plugin_install_err']    = 'Tillegget ble feil installert. Skift navn på mappen \'%s\' til \'%s\'.';
