@@ -8,6 +8,7 @@
  * @author Emanuel-Emeric Andrași <n30@mandrivausers.ro>
  * @author Emanuel-Emeric Andraşi <em.andrasi@mandrivausers.ro>
  * @author Marius OLAR <olarmariusalex@gmail.com>
+ * @author Marius Olar <olarmariusalex@yahoo.com>
  * @author Emanuel-Emeric Andrași <em.andrasi@mandrivausers.ro>
  */
 $lang['encoding']              = 'utf-8';
@@ -44,7 +45,7 @@ $lang['btn_backtomedia']       = 'Înapoi la Selecţia Mediafile';
 $lang['btn_subscribe']         = 'Subscrie Modificarea Paginii';
 $lang['btn_profile']           = 'Actualizează Profil';
 $lang['btn_reset']             = 'Resetează';
-$lang['btn_resendpwd']         = 'Trimite parola nouă';
+$lang['btn_resendpwd']         = 'Setează o parolă nouă';
 $lang['btn_draft']             = 'Editează schiţă';
 $lang['btn_recover']           = 'Recuperează schiţă';
 $lang['btn_draftdel']          = 'Şterge schiţă';
@@ -81,7 +82,7 @@ $lang['profnoempty']           = 'Nu sunt admise numele sau adresa de email neco
 $lang['profchanged']           = 'Profilul de utilizator a fost actualizat succes.';
 $lang['pwdforget']             = 'Parola uitată? Luaţi una nouă';
 $lang['resendna']              = 'Această wiki nu suportă retrimiterea parolei.';
-$lang['resendpwd']             = 'Trimite parola nouă pentru';
+$lang['resendpwd']             = 'Setează o parolă nouă pentru';
 $lang['resendpwdmissing']      = 'Ne pare rău, trebuie completate toate câmpurile.';
 $lang['resendpwdnouser']       = 'Ne pare rău, acest utilizator nu poate fi găsit în baza de date.';
 $lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verificaţi dacă aţi folosit tot link-ul de confirmare.';
@@ -188,6 +189,11 @@ $lang['external_edit']         = 'editare externă';
 $lang['summary']               = 'Editează sumarul';
 $lang['noflash']               = 'Plugin-ul <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> este necesar pentru afişarea corectă a conţinutului.';
 $lang['download']              = 'Bloc descărcări';
+$lang['tools']                 = 'Unelte';
+$lang['user_tools']            = 'Unelte utilizator';
+$lang['site_tools']            = 'Unelte Site';
+$lang['page_tools']            = 'Unelte Pagină';
+$lang['skip_to_content']       = 'sari la conținut';
 $lang['mail_newpage']          = 'pagina adăugată:';
 $lang['mail_changed']          = 'page schimbată:';
 $lang['mail_subscribe_list']   = 'pagini modificate în spaţiul de nume:';
@@ -258,6 +264,7 @@ $lang['subscr_style_digest']   = 'digerează email la schimbări pentru fiecare
 $lang['subscr_style_list']     = 'lista paginilor schimbate de la ultimul email (la fiecare %.2f zile)';
 $lang['authmodfailed']         = 'Configuraţia autentificării utilizatorului este eronată. Anunţaţi Wiki Admin-ul.';
 $lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Anunţaţi Wiki Admin-ul.';
+$lang['authpwdexpire']         = 'Parola vă va expira în %d zile, ar trebui să o schimbați curând.';
 $lang['i_chooselang']          = 'Alegeţi limba';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Numele Wiki';
@@ -313,4 +320,3 @@ $lang['media_perm_read']       = 'Ne pare rău, dar nu aveți suficiente dreptur
 $lang['media_perm_upload']     = 'Ne pare rău, dar nu aveți suficiente drepturi pentru a putea încărca fișiere.';
 $lang['media_update']          = 'Încarcă noua versiune';
 $lang['media_restore']         = 'Restaurează această versiune';
-$lang['plugin_install_err']    = 'Modul instalat greșit. Redenumește directorul modulului \'%s\' în \'%s\'.';
