@@ -19,6 +19,7 @@
  * @author Aleksandr Selivanov <alexgearbox@gmail.com>
  * @author Ladyko Andrey <fylh@succexy.spb.ru>
  * @author Eugene <windy.wanderer@gmail.com>
+ * @author Johnny Utah <pcpa@cyberpunk.su>
  */
 $lang['encoding']              = ' utf-8';
 $lang['direction']             = 'ltr';
@@ -54,12 +55,14 @@ $lang['btn_backtomedia']       = 'Вернуться к выбору медиа
 $lang['btn_subscribe']         = 'Подписаться (все правки)';
 $lang['btn_profile']           = 'Профиль';
 $lang['btn_reset']             = 'Сброс';
-$lang['btn_resendpwd']         = 'Выслать новый пароль';
+$lang['btn_resendpwd']         = 'Установить новый пароль';
 $lang['btn_draft']             = 'Править черновик';
 $lang['btn_recover']           = 'Восстановить черновик';
 $lang['btn_draftdel']          = 'Удалить черновик';
 $lang['btn_revert']            = 'Восстановить';
 $lang['btn_register']          = 'Зарегистрироваться';
+$lang['btn_apply']             = 'Применить';
+$lang['btn_media']             = 'Media Manager';
 $lang['loggedinas']            = 'Зашли как';
 $lang['user']                  = 'Логин';
 $lang['pass']                  = 'Пароль';
@@ -89,7 +92,7 @@ $lang['profnoempty']           = 'Логин и адрес электронно
 $lang['profchanged']           = 'Профиль пользователя успешно обновлён.';
 $lang['pwdforget']             = 'Забыли пароль? Получите новый';
 $lang['resendna']              = 'Данная вики не поддерживает повторную отправку пароля.';
-$lang['resendpwd']             = 'Выслать пароль для';
+$lang['resendpwd']             = 'Установить новый пароль для';
 $lang['resendpwdmissing']      = 'Вы должны заполнить все поля формы.';
 $lang['resendpwdnouser']       = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
 $lang['resendpwdbadauth']      = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку. ';
@@ -102,9 +105,10 @@ $lang['searchmedia_in']        = 'Поиск в %s';
 $lang['txt_upload']            = 'Выберите файл для загрузки';
 $lang['txt_filename']          = 'Введите имя файла в вики (необязательно)';
 $lang['txt_overwrt']           = 'Перезаписать существующий файл';
+$lang['maxuploadsize']         = 'Максимальный размер загружаемого файла %s';
 $lang['lockedby']              = 'В данный момент заблокирован';
 $lang['lockexpire']            = 'Блокировка истекает в';
-$lang['willexpire']            = 'Ваша блокировка редактирования этой страницы истекает в течение минуты.\nЧтобы избежать конфликтов и сбросить таймер блокировки, нажмите кнопку просмотра.';
+$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течении минуты.\nЧтобы предотвратить конфликты используйте кнопку "Просмотр" для сброса таймера блокировки.';
 $lang['js']['notsavedyet']     = 'Несохранённые изменения будут потеряны. Вы действительно хотите продолжить?';
 $lang['js']['searchmedia']     = 'Поиск файлов';
 $lang['js']['keepopen']        = 'Не закрывать окно после выбора';
@@ -134,7 +138,17 @@ $lang['js']['nosmblinks']      = 'Ссылка на сетевые катало
 $lang['js']['linkwiz']         = 'Мастер ссылок';
 $lang['js']['linkto']          = 'Ссылка на:';
 $lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
-$lang['js']['mu_btn']          = 'Загрузить несколько файлов одновременно';
+$lang['js']['restore_confirm'] = 'Действительно восстановить эту версию?';
+$lang['js']['media_diff']      = 'Просмотр отличий:';
+$lang['js']['media_diff_both'] = 'Рядом';
+$lang['js']['media_diff_opacity'] = 'Наложением';
+$lang['js']['media_diff_portions'] = 'Частями';
+$lang['js']['media_select']    = 'Выбрать файлы…';
+$lang['js']['media_upload_btn'] = 'Загрузить';
+$lang['js']['media_done_btn']  = 'Готово';
+$lang['js']['media_drop']      = 'Переместите файлы сюда для загрузки';
+$lang['js']['media_cancel']    = 'отменить';
+$lang['js']['media_overwrt']   = 'Перезаписать существующие файлы';
 $lang['rssfailed']             = 'Произошла ошибка при получении следующей новостной ленты: ';
 $lang['nothingfound']          = 'Ничего не найдено.';
 $lang['mediaselect']           = 'Выбор медиафайла';
@@ -184,11 +198,20 @@ $lang['external_edit']         = 'внешнее изменение';
 $lang['summary']               = 'Сводка изменений';
 $lang['noflash']               = 'Для просмотра этого содержимого требуется <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Скачать код';
+$lang['tools']                 = 'Инструменты';
+$lang['user_tools']            = 'Инструменты пользователя';
+$lang['site_tools']            = 'Инструменты сайта';
+$lang['page_tools']            = 'Инструменты страницы';
+$lang['skip_to_content']       = 'Перейти к содержанию';
 $lang['mail_newpage']          = 'страница добавлена:';
 $lang['mail_changed']          = 'страница изменена:';
 $lang['mail_subscribe_list']   = 'изменились страницы в пространстве имён:';
 $lang['mail_new_user']         = 'новый пользователь:';
 $lang['mail_upload']           = 'файл закачан:';
+$lang['changes_type']          = 'Посмотреть изменения';
+$lang['pages_changes']         = 'Страниц';
+$lang['media_changes']         = 'Медиа файлов';
+$lang['both_changes']          = 'И страниц и медиа файлов';
 $lang['qb_bold']               = 'Полужирный';
 $lang['qb_italic']             = 'Курсив';
 $lang['qb_underl']             = 'Подчёркнутый';
@@ -229,6 +252,9 @@ $lang['img_copyr']             = 'Авторские права';
 $lang['img_format']            = 'Формат';
 $lang['img_camera']            = 'Модель';
 $lang['img_keywords']          = 'Ключевые слова';
+$lang['img_width']             = 'Ширина';
+$lang['img_height']            = 'Высота';
+$lang['img_manager']           = 'Просмотр в media manager';
 $lang['subscr_subscribe_success'] = 'Добавлен %s в подписку на %s';
 $lang['subscr_subscribe_error'] = 'Невозможно добавить %s в подписку на %s';
 $lang['subscr_subscribe_noaddress'] = 'Нет адреса электронной почты, сопоставленного с вашей учётной записью. Вы не можете подписаться на рассылку';
@@ -247,6 +273,7 @@ $lang['subscr_style_digest']   = 'сводка изменений по кажд
 $lang['subscr_style_list']     = 'перечислять изменившиеся страницы с прошлого уведомления';
 $lang['authmodfailed']         = 'Неправильная конфигурация аутентификации пользователя. Пожалуйста, сообщите об этом своему администратору вики.';
 $lang['authtempfail']          = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом своему администратору вики.';
+$lang['authpwdexpire']         = 'Действие вашего пароля истекает через %d дней. Вы должны изменить его как можно скорее';
 $lang['i_chooselang']          = 'Выберите свой язык/Choose your language';
 $lang['i_installer']           = 'Установка «ДокуВики»';
 $lang['i_wikiname']            = 'Название вики';
@@ -254,8 +281,8 @@ $lang['i_enableacl']           = 'Разрешить ограничение пр
 $lang['i_superuser']           = 'Суперпользователь';
 $lang['i_problems']            = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
 $lang['i_modified']            = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке «ДокуВики».
-Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
-<a href="http://www.dokuwiki.org/install">инструкции по установке «ДокуВики»</a>';
+                                  Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
+                                  <a href="http://www.dokuwiki.org/install">инструкции по установке «ДокуВики»</a>';
 $lang['i_funcna']              = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостером?';
 $lang['i_phpver']              = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
 $lang['i_permfail']            = '<code>%s</code> недоступна для записи «ДокуВики». Вам необходимо исправить системные права доступа для этой директории!';
@@ -264,7 +291,7 @@ $lang['i_writeerr']            = 'Не удалось создать <code>%s</c
 $lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (хэш=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> — недопустимое или пустое значение';
 $lang['i_success']             = 'Конфигурация прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
-                        <a href="doku.php">своей новой «ДокуВики»</a>.';
+                                 <a href="doku.php">своей новой «ДокуВики»</a>.';
 $lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php">свою новую «ДокуВики»</a>.';
 $lang['i_policy']              = 'Исходная политика прав доступа';
 $lang['i_pol0']                = 'Открытая вики (чтение, запись, закачка файлов для всех)';
@@ -272,21 +299,6 @@ $lang['i_pol1']                = 'Общедоступная вики (чтен
 $lang['i_pol2']                = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
 $lang['i_retry']               = 'Повторить попытку';
 $lang['i_license']             = 'Пожалуйста, выберите тип лицензии для своей вики:';
-$lang['mu_intro']              = 'Здесь вы можете загрузить несколько файлов сразу. Кликните на «обзор», чтобы добавить их в список. Нажмите «загрузить», когда будете готовы.';
-$lang['mu_gridname']           = 'Имя файла';
-$lang['mu_gridsize']           = 'Размер';
-$lang['mu_gridstat']           = 'Статус';
-$lang['mu_namespace']          = 'Пространство имён';
-$lang['mu_browse']             = 'Обзор';
-$lang['mu_toobig']             = 'слишком большой';
-$lang['mu_ready']              = 'готово к загрузке';
-$lang['mu_done']               = 'завершено';
-$lang['mu_fail']               = 'провалено';
-$lang['mu_authfail']           = 'истекло время сессии';
-$lang['mu_progress']           = '@PCT@% загружено';
-$lang['mu_filetypes']          = 'Допустимые типы файлов';
-$lang['mu_info']               = 'файлов загружено.';
-$lang['mu_lasterr']            = 'Последняя ошибка:';
 $lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения во всей вики</a>.';
 $lang['years']                 = '%d лет назад';
 $lang['months']                = '%d месяц(ев) назад';
@@ -296,3 +308,27 @@ $lang['hours']                 = '%d час(ов) назад';
 $lang['minutes']               = '%d минут назад';
 $lang['seconds']               = '%d секунд назад';
 $lang['wordblock']             = 'Ваши изменения не сохранены, поскольку они содержат блокируемые слова (спам).';
+$lang['media_uploadtab']       = 'Загрузка';
+$lang['media_searchtab']       = 'Поиск';
+$lang['media_file']            = 'Файл';
+$lang['media_viewtab']         = 'Просмотр';
+$lang['media_edittab']         = 'Правка';
+$lang['media_historytab']      = 'История';
+$lang['media_list_thumbs']     = 'Миниатюры';
+$lang['media_list_rows']       = 'Строки';
+$lang['media_sort_name']       = 'Сортировка по имени';
+$lang['media_sort_date']       = 'Сортировка по дате';
+$lang['media_namespaces']      = 'Выберите каталог';
+$lang['media_files']           = 'Файлы в %s';
+$lang['media_upload']          = 'Загрузка в пространство имён <strong>%s</strong>.';
+$lang['media_search']          = 'Поиск в пространстве имён <strong>%s</strong>.';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s в %s
+';
+$lang['media_edit']            = 'Правка %s';
+$lang['media_history']         = 'История %s';
+$lang['media_meta_edited']     = 'метаданные изменены';
+$lang['media_perm_read']       = 'Извините, у Вас недостаточно прав для чтения файлов.';
+$lang['media_perm_upload']     = 'Извините, у Вас недостаточно прав для загрузки файлов.';
+$lang['media_update']          = 'Загрузить новую версию';
+$lang['media_restore']         = 'Восстановить эту версию';
