@@ -43,11 +43,13 @@ $lang['btn_backtomedia']       = 'Nazaj na izbiro predstavnih datotek';
 $lang['btn_subscribe']         = 'Urejanje naročnin';
 $lang['btn_profile']           = 'Posodobi profil';
 $lang['btn_reset']             = 'Ponastavi';
-$lang['btn_resendpwd']         = 'Pošlji novo geslo';
 $lang['btn_draft']             = 'Uredi osnutek';
 $lang['btn_recover']           = 'Obnovi osnutek';
 $lang['btn_draftdel']          = 'Izbriši osnutek';
 $lang['btn_revert']            = 'Povrni';
+$lang['btn_register']          = 'Prijava';
+$lang['btn_apply']             = 'Uveljavi';
+$lang['btn_media']             = 'Urejevalnik predstavnih vsebin';
 $lang['loggedinas']            = 'Prijava kot';
 $lang['user']                  = 'Uporabniško ime';
 $lang['pass']                  = 'Geslo';
@@ -57,7 +59,6 @@ $lang['passchk']               = 'Ponovi novo geslo';
 $lang['remember']              = 'Zapomni si me';
 $lang['fullname']              = 'Pravo ime';
 $lang['email']                 = 'Elektronski naslov';
-$lang['register']              = 'Vpis računa';
 $lang['profile']               = 'Uporabniški profil';
 $lang['badlogin']              = 'Uporabniško ime ali geslo je napačno.';
 $lang['minoredit']             = 'Manjše spremembe';
@@ -72,13 +73,12 @@ $lang['regbadmail']            = 'Videti je, da je naveden elektronski naslov ne
 $lang['regbadpass']            = 'Gesli nista enaki. Poskusite znova.';
 $lang['regpwmail']             = 'Geslo za DokuWiki';
 $lang['reghere']               = 'Nimate še računa? Vpišite se za nov račun.';
-$lang['profna']                = 'Wiki ne podpira spreminjanja profila.';
+$lang['profna']                = 'DokuWiki ne podpira spreminjanja profila.';
 $lang['profnochange']          = 'Brez sprememb.';
 $lang['profnoempty']           = 'Prazno polje elektronskega naslova ali imena ni dovoljeno.';
 $lang['profchanged']           = 'Uporabniški profil je uspešno posodobljen.';
 $lang['pwdforget']             = 'Ali ste pozabili geslo? Pridobite si novo geslo.';
-$lang['resendna']              = 'Wiki ne podpira možnosti ponovnega pošiljanja gesel.';
-$lang['resendpwd']             = 'Pošlji novo geslo za';
+$lang['resendna']              = 'DokuWiki ne podpira možnosti ponovnega pošiljanja gesel.';
 $lang['resendpwdmissing']      = 'Izpolniti je treba vsa polja.';
 $lang['resendpwdnouser']       = 'Podanega uporabniškega imena v podatkovni zbirki ni mogoče najti.';
 $lang['resendpwdbadauth']      = 'Koda za overitev ni prava. Prepričajte se, da ste uporabili celotno povezavo za potrditev.';
@@ -93,7 +93,7 @@ $lang['txt_filename']          = 'Pošlji z imenom (izborno)';
 $lang['txt_overwrt']           = 'Prepiši obstoječo datoteko';
 $lang['lockedby']              = 'Trenutno je zaklenjeno s strani';
 $lang['lockexpire']            = 'Zaklep preteče ob';
-$lang['js']['willexpire']            = 'Zaklep za urejevanje bo pretekel čez eno minuto.\nV izogib sporom, uporabite predogled, da se merilnik časa za zaklep ponastavi.';
+$lang['js']['willexpire']      = 'Zaklep za urejevanje bo pretekel čez eno minuto.\nV izogib sporom, uporabite predogled, da se merilnik časa za zaklep ponastavi.';
 $lang['js']['notsavedyet']     = 'Neshranjene spremembe bodo izgubljene.';
 $lang['js']['searchmedia']     = 'Poišči datoteke';
 $lang['js']['keepopen']        = 'Od izbiri ohrani okno odprto';
@@ -123,6 +123,16 @@ $lang['js']['nosmblinks']      = 'Povezovanje do souporabnih datotek sistema Win
 $lang['js']['linkwiz']         = 'Čarovnik za povezave';
 $lang['js']['linkto']          = 'Poveži na:';
 $lang['js']['del_confirm']     = 'Ali naj se res izbrišejo izbrani predmeti?';
+$lang['js']['restore_confirm'] = 'Ali naj se koda obnovi na to različico?';
+$lang['js']['media_diff']      = 'Razlike:';
+$lang['js']['media_diff_both'] = 'Eno ob drugem';
+$lang['js']['media_diff_opacity'] = 'Prosojno';
+$lang['js']['media_select']    = 'Izbor datotek ...';
+$lang['js']['media_upload_btn'] = 'Naloži';
+$lang['js']['media_done_btn']  = 'Končano';
+$lang['js']['media_drop']      = 'Spusti datoteke za nalaganje.';
+$lang['js']['media_cancel']    = 'odstrani';
+$lang['js']['media_overwrt']   = 'Prepiši obstoječe datoteke';
 $lang['rssfailed']             = 'Prišlo je do napake med pridobivanjem vira: ';
 $lang['nothingfound']          = 'Ni najdenih predmetov.';
 $lang['mediaselect']           = 'Predstavne datoteke';
@@ -157,6 +167,9 @@ $lang['yours']                 = 'Vaša različica';
 $lang['diff']                  = 'Pokaži razlike s trenutno različico';
 $lang['diff2']                 = 'Pokaži razlike med izbranimi različicami.';
 $lang['difflink']              = 'Poveži s tem pogledom primerjave.';
+$lang['diff_type']             = 'Razlike:';
+$lang['diff_inline']           = 'V besedilu';
+$lang['diff_side']             = 'Eno ob drugem';
 $lang['line']                  = 'Vrstica';
 $lang['breadcrumb']            = 'Sled';
 $lang['youarehere']            = 'Trenutno dejavna stran';
@@ -169,11 +182,20 @@ $lang['external_edit']         = 'urejanje v zunanjem urejevalniku';
 $lang['summary']               = 'Povzetek urejanja';
 $lang['noflash']               = 'Za prikaz vsebine je treba namestiti <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
 $lang['download']              = 'Naloži izrezek';
+$lang['tools']                 = 'Orodja';
+$lang['user_tools']            = 'Uporabniška orodja';
+$lang['site_tools']            = 'Orodja spletišča';
+$lang['page_tools']            = 'Orodja strani';
+$lang['skip_to_content']       = 'preskoči na vsebino';
 $lang['mail_newpage']          = '[DokuWiki] stran dodana:';
 $lang['mail_changed']          = '[DokuWiki] stran spremenjena:';
 $lang['mail_subscribe_list']   = 'strani s spremenjenim imenom:';
 $lang['mail_new_user']         = 'nov uporabnik:';
 $lang['mail_upload']           = 'naložena datoteka:';
+$lang['changes_type']          = 'Poglej spremembe';
+$lang['pages_changes']         = 'Strani';
+$lang['media_changes']         = 'Predstavne datoteke';
+$lang['both_changes']          = 'Strani in predstavne datoteke';
 $lang['qb_bold']               = 'Krepko besedilo';
 $lang['qb_italic']             = 'Ležeče besedilo';
 $lang['qb_underl']             = 'Podčrtano besedilo';
@@ -214,6 +236,9 @@ $lang['img_copyr']             = 'Avtorska pravica';
 $lang['img_format']            = 'Zapis';
 $lang['img_camera']            = 'Fotoaparat';
 $lang['img_keywords']          = 'Ključne besede';
+$lang['img_width']             = 'Širina';
+$lang['img_height']            = 'Višina';
+$lang['img_manager']           = 'Poglej v urejevalniku predstavnih vsebin';
 $lang['subscr_subscribe_success'] = 'Uporabniški račun %s je dodan na seznam naročnin na %s';
 $lang['subscr_subscribe_error'] = 'Napaka med dodajanjem %s na seznam naročnin na %s';
 $lang['subscr_subscribe_noaddress'] = 'S trenutnimi prijavnimi podatki ni povezanega elektronskega naslova, zato uporabniškega računa ni mogoče dodati na seznam naročnikov.';
@@ -263,3 +288,26 @@ $lang['hours']                 = '%d ur nazaj';
 $lang['minutes']               = '%d minut nazaj';
 $lang['seconds']               = '%d sekund nazaj';
 $lang['wordblock']             = 'Spremembe niso shranjene, ker je v vsebini navedeno neželeno besedilo (spam).';
+$lang['media_uploadtab']       = 'Naloži';
+$lang['media_searchtab']       = 'Poišči';
+$lang['media_file']            = 'Datoteka';
+$lang['media_viewtab']         = 'Pogled';
+$lang['media_edittab']         = 'Uredi';
+$lang['media_historytab']      = 'Zgodovina';
+$lang['media_list_thumbs']     = 'Sličice';
+$lang['media_list_rows']       = 'Vrstice';
+$lang['media_sort_name']       = 'Ime';
+$lang['media_sort_date']       = 'Datum';
+$lang['media_namespaces']      = 'Izbor imenskega prostora';
+$lang['media_files']           = 'Datoteke v %s';
+$lang['media_upload']          = 'Naloži v %s';
+$lang['media_search']          = 'Poišči v %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s pri %s';
+$lang['media_edit']            = 'Uredi %s';
+$lang['media_history']         = 'Zgodovina %s';
+$lang['media_meta_edited']     = 'metapodatki so urejeni';
+$lang['media_perm_read']       = 'Ni ustreznih dovoljenj za branje datotek.';
+$lang['media_perm_upload']     = 'Ni ustreznih dovoljenj za nalaganje datotek.';
+$lang['media_update']          = 'Naloži novo različico';
+$lang['media_restore']         = 'Obnovi to različico';
