@@ -44,7 +44,6 @@ $lang['btn_backtomedia']       = 'Mbrapa tek Përzgjedhja e Media-ve';
 $lang['btn_subscribe']         = 'Menaxho Abonimet';
 $lang['btn_profile']           = 'Përditëso Profilin';
 $lang['btn_reset']             = 'Rivendos';
-$lang['btn_resendpwd']         = 'Dërgo fjalëkalim të ri';
 $lang['btn_draft']             = 'Redakto skicën';
 $lang['btn_recover']           = 'Rekupero skicën';
 $lang['btn_draftdel']          = 'Fshi skicën';
@@ -79,7 +78,6 @@ $lang['profnoempty']           = 'Një emër bosh ose adresë email-i bosh nuk l
 $lang['profchanged']           = 'Profili i përdoruesit u përditësua me sukses.';
 $lang['pwdforget']             = 'E harruat fjalëkalimin? Merni një të ri';
 $lang['resendna']              = 'Ky wiki nuk e lejon ridërgimin e fjalëkalimeve.';
-$lang['resendpwd']             = 'Dërgo një fjalëkalim të ri për';
 $lang['resendpwdmissing']      = 'Na vjen keq, duhet t\'i plotësoni të gjitha fushat.';
 $lang['resendpwdnouser']       = 'Na vjen keq, nuk mund ta gjejmë këtë përdorues në bazën tonë të të dhënave.';
 $lang['resendpwdbadauth']      = 'Na vjen keq, ky kod autorizimi nuk është i vlefshëm. Sigurohuni që përdoret linkun e plotë të konfirmimit.';
@@ -94,7 +92,7 @@ $lang['txt_filename']          = 'Ngarko si (alternative)';
 $lang['txt_overwrt']           = 'Zëvendëso skedarin ekzistues';
 $lang['lockedby']              = 'Kyçur momentalisht nga';
 $lang['lockexpire']            = 'Kyçi skadon në';
-$lang['willexpire']            = 'Kyçi juaj për redaktimin e kësaj faqeje është duke skaduar.\nPër të shmangur konflikte përdorni butonin Shiko Paraprakisht për të rivendosur kohën e kyçjes.';
+$lang['js']['willexpire']            = 'Kyçi juaj për redaktimin e kësaj faqeje është duke skaduar.\nPër të shmangur konflikte përdorni butonin Shiko Paraprakisht për të rivendosur kohën e kyçjes.';
 $lang['js']['notsavedyet']     = "Ndryshimet e paruajtura do të humbasin.\nVazhdo me të vërtetë?";
 $lang['rssfailed']             = 'Ndoshi një gabim gjatë kapjes së këtij lajmi:';
 $lang['nothingfound']          = 'Nuk u gjet asgjë.';
@@ -120,7 +118,6 @@ $lang['js']['nosmblinks']      = 'Lidhja te Windows shares funksionon vetëm në
 $lang['js']['linkwiz']         = 'Magjistari i Link';
 $lang['js']['linkto']          = 'Lidh tek:';
 $lang['js']['del_confirm']     = 'Fshiji vërtetë objektet e përzgjedhura?';
-$lang['js']['mu_btn']          = 'Ngarko shumë skedarë njëkohësisht';
 $lang['mediausage']            = 'Përdor sintaksën e mëposhtme për të referuar këtë skedar:';
 $lang['mediaview']             = 'Shiko skedarin origjinal';
 $lang['mediaroot']             = 'rrënja';
@@ -233,21 +230,6 @@ $lang['i_pol0']                = 'Wiki i Hapur (lexim, shkrim, ngarkim për këd
 $lang['i_pol1']                = 'Wiki Publike (lexim për këdo, shkrim dhe ngarkim për përdoruesit e regjistruar)';
 $lang['i_pol2']                = 'Wiki e Mbyllur (lexim, shkrim, ngarkim vetëm për përdoruesit e regjistruar)';
 $lang['i_retry']               = 'Provo Përsëri';
-$lang['mu_intro']              = 'Këtu mund të ngarkoni disa skedarë njëkohësisht. Klikoni butonin e shfletuesit për t\'i shtuar ata në radhë. Klikoni Ngarko kur të keni mbaruar.';
-$lang['mu_gridname']           = 'Emri Skedari';
-$lang['mu_gridsize']           = 'Madhësia';
-$lang['mu_gridstat']           = 'Statusi';
-$lang['mu_namespace']          = 'Hapësira Emrit';
-$lang['mu_browse']             = 'Shfleto';
-$lang['mu_toobig']             = 'shumë i/e madhe';
-$lang['mu_ready']              = 'gati për ngarkim';
-$lang['mu_done']               = 'përfundoi';
-$lang['mu_fail']               = 'dështoi';
-$lang['mu_authfail']           = 'sesioni skadoi';
-$lang['mu_progress']           = '@PCT@% u ngarkua';
-$lang['mu_filetypes']          = 'Tipet e Skedarëve të Lejuar';
-$lang['mu_info']               = 'skedarët e ngarkuar';
-$lang['mu_lasterr']            = 'Gabimi i fundit:';
 $lang['recent_global']         = 'Momentalisht jeni duke parë ndryshimet brenda hapësirës së emrit <b>%s</b>. Gjithashtu mund <a href="%s">të shihni ndryshimet më të fundit në të gjithë wiki-n</a>.';
 $lang['years']                 = '%d vite më parë';
 $lang['months']                = '%d muaj më parë';
