@@ -41,7 +41,6 @@ $lang['btn_backtomedia']       = 'Врати се на избор медијск
 $lang['btn_subscribe']         = 'Пријави се на измене';
 $lang['btn_profile']           = 'Ажурирај профил';
 $lang['btn_reset']             = 'Поништи';
-$lang['btn_resendpwd']         = 'Пошаљи нову лозинку';
 $lang['btn_draft']             = 'Измени нацрт';
 $lang['btn_recover']           = 'Опорави нацрт';
 $lang['btn_draftdel']          = 'Обриши нацрт';
@@ -76,7 +75,6 @@ $lang['profnoempty']           = 'Није дозвољено оставити 
 $lang['profchanged']           = 'Кориснички профил је ажуриран.';
 $lang['pwdforget']             = 'Заборавили сте лозинку? Направите нову';
 $lang['resendna']              = 'Овај вики не дозвољава слање лозинки.';
-$lang['resendpwd']             = 'Пошаљи нову лозинку за';
 $lang['resendpwdmissing']      = 'Жао ми је, сва поља морају бити попуњена.';
 $lang['resendpwdnouser']       = 'Жао ми је, овај корисник не постоји у нашој бази.';
 $lang['resendpwdbadauth']      = 'Жао ми је, потврдни код није исправан. Проверите да ли сте користили комплетан потврдни линк.';
