@@ -48,7 +48,6 @@ $lang['btn_subscribe']         = 'เฝ้าดู';
 $lang['btn_unsubscribe']       = 'เลิกเฝ้าดู';
 $lang['btn_profile']           = 'แก้ข้อมูลผู้ใช้';
 $lang['btn_reset']             = 'เริ่มใหม่';
-$lang['btn_resendpwd']         = 'ลืมรหัส ส่งให้ใหม่ทางอีเมล';
 $lang['btn_draft']             = 'แก้ไขเอกสารฉบับร่าง';
 $lang['btn_recover']           = 'กู้คืนเอกสารฉบับร่าง';
 $lang['btn_draftdel']          = 'ลบเอกสารฉบับร่าง';
@@ -83,7 +82,6 @@ $lang['profnoempty']           = 'ไม่อนุญาติให้เว
 $lang['profchanged']           = 'ปรับปรุงข้อมูลส่วนตัวผู้ใช้สำเร็จ';
 $lang['pwdforget']             = 'ลืมรหัสผ่านหรือ? เอาอันใหม่สิ';
 $lang['resendna']              = 'วิกินี้ไม่รองรับการส่งรหัสผ่านซ้ำ';
-$lang['resendpwd']             = 'ส่งรหัสผ่านใหม่ให้กับ';
 $lang['resendpwdmissing']      = 'ขออภัย, คุณต้องกรอกทุกช่อง';
 $lang['resendpwdnouser']       = 'ขออภัย, เราไม่พบผู้ใช้คนนี้ในฐานข้อมูลของเรา';
 $lang['resendpwdbadauth']      = 'ขออภัย, รหัสนี้ยังใช้ไม่ได้ กรุณาตรวจสอบว่าคุณกดลิ้งค์ยืนยันแล้ว';
