@@ -28,7 +28,7 @@ $lang['btn_top']               = 'Повернутися наверх';
 $lang['btn_newer']             = '<< більш нові';
 $lang['btn_older']             = 'більш старі >>';
 $lang['btn_revs']              = 'Старі ревізії';
-$lang['btn_recent']            = 'Недавні зміни';
+$lang['btn_recent']            = 'Останні зміни';
 $lang['btn_upload']            = 'Завантажити';
 $lang['btn_cancel']            = 'Скасувати';
 $lang['btn_index']             = 'Зміст';
@@ -37,19 +37,19 @@ $lang['btn_login']             = 'Увійти';
 $lang['btn_logout']            = 'Вийти';
 $lang['btn_admin']             = 'Керування';
 $lang['btn_update']            = 'Оновити';
-$lang['btn_delete']            = 'Знищити';
+$lang['btn_delete']            = 'Видалити';
 $lang['btn_back']              = 'Назад';
 $lang['btn_backlink']          = 'Посилання сюди';
 $lang['btn_backtomedia']       = 'Назад до вибору медіа-файлу';
 $lang['btn_subscribe']         = 'Підписатися';
 $lang['btn_profile']           = 'Оновити профіль';
 $lang['btn_reset']             = 'Очистити';
-$lang['btn_resendpwd']         = 'Надіслати новий пароль';
 $lang['btn_draft']             = 'Редагувати чернетку';
 $lang['btn_recover']           = 'Відновити чернетку';
 $lang['btn_draftdel']          = 'Знищити чернетку';
 $lang['btn_revert']            = 'Відновити';
 $lang['btn_register']          = 'Реєстрація';
+$lang['btn_apply']             = 'Застосувати';
 $lang['loggedinas']            = 'Ви';
 $lang['user']                  = 'Користувач';
 $lang['pass']                  = 'Пароль';
@@ -79,7 +79,6 @@ $lang['profnoempty']           = 'Ім’я або e-mail не можуть бу
 $lang['profchanged']           = 'Профіль успішно змінено.';
 $lang['pwdforget']             = 'Забули пароль? Отримайте новий';
 $lang['resendna']              = 'Ця Вікі не підтримує повторне відправлення пароля.';
-$lang['resendpwd']             = 'Надіслати пароль для';
 $lang['resendpwdmissing']      = 'Необхідно заповнити усі поля.';
 $lang['resendpwdnouser']       = 'Такий користувач не існує.';
 $lang['resendpwdbadauth']      = 'Код автентифікації невірний. Перевірте, чи ви використали повне посилання для підтвердження.';
@@ -94,7 +93,7 @@ $lang['txt_filename']          = 'Завантажити як (не обов\'я
 $lang['txt_overwrt']           = 'Перезаписати існуючий файл';
 $lang['lockedby']              = 'Заблоковано';
 $lang['lockexpire']            = 'Блокування завершується в';
-$lang['js']['willexpire']            = 'Блокування редагування цієї сторінки закінчується через хвилину.\n Щоб уникнути конфліктів використовуйте кнопку перегляду для продовження блокування.';
+$lang['js']['willexpire']      = 'Блокування редагування цієї сторінки закінчується через хвилину.\n Щоб уникнути конфліктів використовуйте кнопку перегляду для продовження блокування.';
 $lang['js']['notsavedyet']     = 'Незбережені зміни будуть втрачені.
  Дійсно продовжити?';
 $lang['js']['searchmedia']     = 'Шукати файли';
@@ -236,7 +235,7 @@ $lang['subscr_m_receive']      = 'Отримувати';
 $lang['subscr_style_every']    = 'повідомляти на пошту про кожну зміну';
 $lang['subscr_style_digest']   = 'лист з дайджестом для зміни кожної сторінки (кожні %.2f днів)';
 $lang['subscr_style_list']     = 'список змінених сторінок від часу отримання останнього листа (кожні %.2f днів)';
-$lang['authmodfailed']         = 'Неправильна настройка автентифікації користувача. Будь ласка, повідомте про це адміністратора.';
+$lang['authmodfailed']         = 'Неправильні налаштування автентифікації користувача. Будь ласка, повідомте про це адміністратора.';
 $lang['authtempfail']          = 'Автентифікація користувача тимчасово не доступна. Якщо це буде продовжуватись, будь ласка, повідомте адміністратора.';
 $lang['i_chooselang']          = 'Виберіть мову';
 $lang['i_installer']           = 'Програма установки ДокуВікі';
@@ -253,7 +252,7 @@ $lang['i_confexists']          = '<code>%s</code> вже існує';
 $lang['i_writeerr']            = 'Неможливо створити <code>%s</code>. Необхідно перевірити права доступа для файлу/папки та створити файл вручну.';
 $lang['i_badhash']             = 'Невпізнаний або модифікований dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - невірне або пусте значення.';
-$lang['i_success']             = 'Настройку завершено. Ми можете знищити файл install.php.
+$lang['i_success']             = 'Налаштування завершено. Ви можете знищити файл install.php.
 Перейдіть до <a href="doku.php">вашої нової ДокуВікі</a>';
 $lang['i_failure']             = 'При збереженні файлу конфігурації виникли помилки. Можливо вам доведеться виправити їх самостійно
 до початку використання <a href="doku.php">вашої нової ДокуВікі</a>.';
