@@ -10,6 +10,7 @@
  * @author Cheng-Wei Chien <e.cwchien@gmail.com>
  * @author Danny Lin
  * @author Shuo-Ting Jian <shoting@gmail.com>
+ * @author syaoranhinata@gmail.com
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -45,7 +46,7 @@ $lang['btn_backtomedia']       = '重新選擇圖檔';
 $lang['btn_subscribe']         = '訂閱更動通知';
 $lang['btn_profile']           = '更新個人資料';
 $lang['btn_reset']             = '資料重設';
-$lang['btn_resendpwd']         = '寄新密碼';
+$lang['btn_resendpwd']         = '設定新密碼';
 $lang['btn_draft']             = '編輯草稿';
 $lang['btn_recover']           = '復原草稿';
 $lang['btn_draftdel']          = '捨棄草稿';
@@ -61,40 +62,41 @@ $lang['oldpass']               = '目前密碼';
 $lang['passchk']               = '確認密碼';
 $lang['remember']              = '記住帳號密碼';
 $lang['fullname']              = '真實姓名';
-$lang['email']                 = 'E-Mail';
+$lang['email']                 = '電郵';
 $lang['profile']               = '使用者個人資料';
-$lang['badlogin']              = '很抱歉，您的使用者名稱或密碼可能有錯誤';
+$lang['badlogin']              = '很抱歉，您的使用者名稱或密碼可能有錯誤。';
 $lang['minoredit']             = '小修改';
 $lang['draftdate']             = '草稿已自動存檔於';
 $lang['nosecedit']             = '頁面在這之間已被修改，過時的區段資料已載入全頁取代。';
-$lang['regmissing']            = '很抱歉，所有欄位都要填寫';
-$lang['reguexists']            = '很抱歉，本帳號已被註冊';
+$lang['regmissing']            = '很抱歉，所有欄位都要填寫。';
+$lang['reguexists']            = '很抱歉，本帳號已被註冊。';
 $lang['regsuccess']            = '使用者已建立，密碼已寄發至該 email。';
-$lang['regsuccess2']           = '使用者已建立';
+$lang['regsuccess2']           = '使用者已建立。';
 $lang['regmailfail']           = '寄出密碼信似乎發生錯誤，請跟管理員聯絡！';
 $lang['regbadmail']            = '您輸入的 email 似乎不對，如果您認為是正確的，請與管理員聯絡。';
 $lang['regbadpass']            = '兩次輸入的密碼不一致，請再試一次。';
 $lang['regpwmail']             = '您的 DokuWiki 帳號密碼';
 $lang['reghere']               = '您還沒有帳號嗎？註冊一個吧。';
-$lang['profna']                = '本維基不開放修改個人資料';
-$lang['profnochange']          = '未做任何變更';
-$lang['profnoempty']           = '帳號或 email 地址不可空白！';
-$lang['profchanged']           = '個人資料已成功更新囉。';
+$lang['profna']                = '本維基不開放修改個人資料。';
+$lang['profnochange']          = '未做任何變更。';
+$lang['profnoempty']           = '帳號或電郵地址不可空白！';
+$lang['profchanged']           = '個人資料已成功更新。';
 $lang['pwdforget']             = '忘記密碼了？索取新密碼！';
-$lang['resendna']              = '本維基不開放重寄密碼';
-$lang['resendpwd']             = '寄新密碼給';
+$lang['resendna']              = '本維基不開放重寄密碼。';
+$lang['resendpwd']             = '設定新密碼供';
 $lang['resendpwdmissing']      = '抱歉，您必須填寫所有欄位。';
-$lang['resendpwdnouser']       = '抱歉，資料庫內找不到這個使用者';
+$lang['resendpwdnouser']       = '抱歉，資料庫內找不到這個使用者。';
 $lang['resendpwdbadauth']      = '抱歉，認證碼無效。請確認您使用了完整的確認連結。';
 $lang['resendpwdconfirm']      = '確認連結已通過郵件發送給您了。';
 $lang['resendpwdsuccess']      = '您的新密碼已寄出。';
 $lang['license']               = '若未特別註明，此維基上的內容都是採用以下授權方式：';
 $lang['licenseok']             = '注意：編輯此頁面表示您已同意以下的授權方式：';
 $lang['searchmedia']           = '搜尋檔名：';
-$lang['searchmedia_in']        = '在 %s 裡搜尋';
+$lang['searchmedia_in']        = '在 %s 裏搜尋';
 $lang['txt_upload']            = '請選擇要上傳的檔案';
 $lang['txt_filename']          = '請輸入要存在維基內的檔案名稱 (非必要)';
 $lang['txt_overwrt']           = '是否要覆蓋原有檔案';
+$lang['maxuploadsize']         = '每個上傳檔案不可大於 %s 。';
 $lang['lockedby']              = '目前已被下列人員鎖定';
 $lang['lockexpire']            = '預計解除鎖定於';
 $lang['js']['willexpire']      = '本頁的編輯鎖定將在一分鐘內到期。要避免發生衝突，請按「預覽」鍵重設鎖定計時。';
@@ -124,12 +126,12 @@ $lang['js']['mediaright']      = '圖像靠右對齊';
 $lang['js']['mediacenter']     = '圖像置中對齊';
 $lang['js']['medianoalign']    = '不對齊';
 $lang['js']['nosmblinks']      = '只有在 Microsoft IE 下才能執行「連結到 Windows shares」。
-不過您仍可複製及貼上這個連結';
+不過您仍可複製及貼上這個連結。';
 $lang['js']['linkwiz']         = '建立連結精靈';
 $lang['js']['linkto']          = '連結至：';
 $lang['js']['del_confirm']     = '確定刪除選取的項目？';
 $lang['js']['restore_confirm'] = '確定還原到這個版本？';
-$lang['js']['media_diff']      = '檢視差異:';
+$lang['js']['media_diff']      = '檢視差異：';
 $lang['js']['media_diff_both'] = '並排';
 $lang['js']['media_diff_opacity'] = '重疊';
 $lang['js']['media_diff_portions'] = '滑動';
@@ -147,21 +149,21 @@ $lang['uploadsucc']            = '上傳成功';
 $lang['uploadfail']            = '上傳失敗。似乎是權限錯誤？';
 $lang['uploadwrong']           = '拒絕上傳。這個副檔名被禁止了！';
 $lang['uploadexist']           = '檔案已存在，未處理。';
-$lang['uploadbadcontent']      = '上傳檔案的內容不符合 %s 檔的副檔名';
+$lang['uploadbadcontent']      = '上傳檔案的內容不符合 %s 檔的副檔名。';
 $lang['uploadspam']            = '這次的上傳被垃圾訊息黑名單阻檔了。';
 $lang['uploadxss']             = '這次的上傳因可能的惡意的內容而被阻檔。';
 $lang['uploadsize']            = '上傳的檔案太大了 (最大：%s)';
 $lang['deletesucc']            = '檔案 "%s" 已刪除。';
 $lang['deletefail']            = '檔案 "%s" 無法刪除，請檢查權限定。';
 $lang['mediainuse']            = '檔案 "%s" 未刪除，因為它正被使用。';
-$lang['namespaces']            = '命名空間';
+$lang['namespaces']            = '分類空間';
 $lang['mediafiles']            = '可用的檔案有';
-$lang['accessdenied']          = '您不被允許檢視此頁面';
-$lang['mediausage']            = '使用以下的語法來連結此檔案:';
+$lang['accessdenied']          = '您不可以檢視此頁面。';
+$lang['mediausage']            = '使用以下的語法來連結此檔案：';
 $lang['mediaview']             = '檢視原始檔案';
 $lang['mediaroot']             = 'root';
-$lang['mediaupload']           = '上傳檔案至目前的命名空間。要建立次級命名空間，將其名稱加在「上傳並重命名為」檔案名的前面，並用英文冒號隔開';
-$lang['mediaextchange']        = '檔案類型已由 .%s 變更為 .%s !';
+$lang['mediaupload']           = '上傳檔案至目前的分類空間。要建立子分類空間，將其名稱加在「上傳並重命名為」檔案名的前面，並用英文冒號隔開。';
+$lang['mediaextchange']        = '檔案類型已由 .%s 變更為 .%s ！';
 $lang['reference']             = '引用到本頁的，合計有';
 $lang['ref_inuse']             = '此檔案無法刪除，因為它正被以下頁面使用：';
 $lang['ref_hidden']            = '一些參考內容位於您沒有讀取權限的頁面中';
@@ -188,11 +190,17 @@ $lang['external_edit']         = '外部編輯';
 $lang['summary']               = '編輯摘要';
 $lang['noflash']               = '顯示此內容需要 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
 $lang['download']              = '下載程式碼片段';
-$lang['mail_newpage']          = '增加的頁面:';
-$lang['mail_changed']          = '變更的頁面:';
-$lang['mail_subscribe_list']   = '命名空間中更動的頁面:';
-$lang['mail_new_user']         = '新使用者:';
-$lang['mail_upload']           = '已上傳檔案:';
+$lang['tools']                 = '工具';
+$lang['user_tools']            = '用戶工具';
+$lang['site_tools']            = '網站工具';
+$lang['page_tools']            = '頁面工具';
+$lang['skip_to_content']       = '跳至內容';
+$lang['sidebar']               = '側欄';
+$lang['mail_newpage']          = '增加的頁面：';
+$lang['mail_changed']          = '變更的頁面：';
+$lang['mail_subscribe_list']   = '分類空間中更動的頁面：';
+$lang['mail_new_user']         = '新使用者：';
+$lang['mail_upload']           = '已上傳檔案：';
 $lang['changes_type']          = '檢視最近更新類型';
 $lang['pages_changes']         = '頁面';
 $lang['media_changes']         = '多媒體檔案';
@@ -221,7 +229,7 @@ $lang['qb_media']              = '加入圖片或檔案';
 $lang['qb_sig']                = '插入簽名';
 $lang['qb_smileys']            = '表情符號';
 $lang['qb_chars']              = '特殊字元';
-$lang['upperns']               = '前往父層命名空間';
+$lang['upperns']               = '前往父分類空間';
 $lang['admin_register']        = '新增使用者';
 $lang['metaedit']              = '編輯後設資料';
 $lang['metasaveerr']           = '後設資料寫入失敗';
@@ -247,7 +255,7 @@ $lang['subscr_unsubscribe_success'] = '已將 %s 移除自 %s 的訂閱列表';
 $lang['subscr_unsubscribe_error'] = '將 %s 移除自 %s 的訂閱列表時發生錯誤';
 $lang['subscr_already_subscribed'] = '%s 已經被 %s 訂閱了';
 $lang['subscr_not_subscribed'] = '%s 尚未被 %s 訂閱';
-$lang['subscr_m_not_subscribed'] = '您尚未訂閱目前的頁面或命名空間。';
+$lang['subscr_m_not_subscribed'] = '您尚未訂閱目前的頁面或分類空間。';
 $lang['subscr_m_new_header']   = '加入訂閱';
 $lang['subscr_m_current_header'] = '目前訂閱';
 $lang['subscr_m_unsubscribe']  = '取消訂閱';
@@ -258,6 +266,7 @@ $lang['subscr_style_digest']   = '對每個頁面發送更改的摘要信件 (
 $lang['subscr_style_list']     = '自上次發信以來更改的頁面的列表 (每 %.2f 天)';
 $lang['authmodfailed']         = '帳號認證的設定不正確，請通知該維基管理員。';
 $lang['authtempfail']          = '帳號認證目前暫不提供，若本狀況持續發生的話，請通知該維基管理員。';
+$lang['authpwdexpire']         = '您的密碼將在 %d 天內到期，請馬上更換新密碼。';
 $lang['i_chooselang']          = '選擇您的語系';
 $lang['i_installer']           = 'DokuWiki 安裝工具';
 $lang['i_wikiname']            = '維基名稱';
@@ -282,7 +291,7 @@ $lang['i_pol1']                = '公開的維基 (任何人可讀取，註冊
 $lang['i_pol2']                = '封閉的維基 (只有註冊使用者可讀取、寫入、上傳)';
 $lang['i_retry']               = '重試';
 $lang['i_license']             = '請選擇您想要的內容發布許可協議：';
-$lang['recent_global']         = '您正在閱讀命名空間： <b>%s</b> 中的變更。您亦可觀看整個維基的<a href="%s">最近更新</a>。';
+$lang['recent_global']         = '您正在閱讀分類空間： <b>%s</b> 中的變更。您亦可觀看整個維基的<a href="%s">最近更新</a>。';
 $lang['years']                 = '%d 年前';
 $lang['months']                = '%d 個月前';
 $lang['weeks']                 = '%d 週前';
@@ -301,7 +310,7 @@ $lang['media_list_thumbs']     = '縮圖';
 $lang['media_list_rows']       = '列表';
 $lang['media_sort_name']       = '名稱';
 $lang['media_sort_date']       = '日期';
-$lang['media_namespaces']      = '選擇命名空間';
+$lang['media_namespaces']      = '選擇分類空間';
 $lang['media_files']           = '在 %s 中的檔案';
 $lang['media_upload']          = '上傳至 %s';
 $lang['media_search']          = '在 %s 中搜尋';
@@ -310,8 +319,7 @@ $lang['media_viewold']         = '%s 在 %s';
 $lang['media_edit']            = '編輯 %s';
 $lang['media_history']         = '%s 的歷史紀錄';
 $lang['media_meta_edited']     = '元資料已編輯';
-$lang['media_perm_read']       = '抱歉，您沒有足夠權限讀取檔案';
+$lang['media_perm_read']       = '抱歉，您沒有足夠權限讀取檔案。';
 $lang['media_perm_upload']     = '抱歉，您沒有足夠權限上傳檔案。';
 $lang['media_update']          = '上傳新的版本';
 $lang['media_restore']         = '還原這個版本';
-$lang['plugin_install_err']    = '插件安裝錯誤。將插件目錄 "%s" 重新命名為 "%s"';
