@@ -50,7 +50,7 @@ $lang['btn_backtomedia']       = '返回到媒体文件选择工具';
 $lang['btn_subscribe']         = '订阅本页更改';
 $lang['btn_profile']           = '更新个人信息';
 $lang['btn_reset']             = '重设';
-$lang['btn_resendpwd']         = '发送新密码';
+$lang['btn_resendpwd']         = '设置新密码';
 $lang['btn_draft']             = '编辑草稿';
 $lang['btn_recover']           = '恢复草稿';
 $lang['btn_draftdel']          = '删除草稿';
@@ -87,7 +87,7 @@ $lang['profnoempty']           = '不允许使用空的用户名或邮件地址
 $lang['profchanged']           = '用户信息更新成功。';
 $lang['pwdforget']             = '忘记密码？立即获取新密码';
 $lang['resendna']              = '本维基不支持二次发送密码。';
-$lang['resendpwd']             = '发送新密码给';
+$lang['resendpwd']             = '设置新密码用于';
 $lang['resendpwdmissing']      = '对不起，您必须填写所有的区域。';
 $lang['resendpwdnouser']       = '对不起，在我们的用户数据中找不到该用户。';
 $lang['resendpwdbadauth']      = '对不起，该认证码错误。请使用完整的确认链接。';
@@ -100,6 +100,7 @@ $lang['searchmedia_in']        = '在%s中查找';
 $lang['txt_upload']            = '选择要上传的文件';
 $lang['txt_filename']          = '上传并重命名为（可选）';
 $lang['txt_overwrt']           = '覆盖已存在的同名文件';
+$lang['maxuploadsize']         = '上传限制。每个文件 %s';
 $lang['lockedby']              = '目前已被下列人员锁定';
 $lang['lockexpire']            = '预计锁定解除于';
 $lang['js']['willexpire']      = '您对本页的独有编辑权将于一分钟之后解除。\n为了防止与其他人的编辑冲突，请使用预览按钮重设计时器。';
@@ -189,11 +190,17 @@ $lang['lastmod']               = '最后更改';
 $lang['by']                    = '由';
 $lang['deleted']               = '移除';
 $lang['created']               = '创建';
-$lang['restored']              = '已恢复为旧版';
+$lang['restored']              = '已恢复为旧版 (%s)';
 $lang['external_edit']         = '外部编辑';
 $lang['summary']               = '编辑摘要';
 $lang['noflash']               = '需要 <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash 插件</a> 来播放本内容。 ';
 $lang['download']              = '下载片段';
+$lang['tools']                 = '工具';
+$lang['user_tools']            = '用户工具';
+$lang['site_tools']            = '站点工具';
+$lang['page_tools']            = '页面工具';
+$lang['skip_to_content']       = '跳至内容';
+$lang['sidebar']               = '侧边栏';
 $lang['mail_newpage']          = '添加页面：';
 $lang['mail_changed']          = '更改页面：';
 $lang['mail_subscribe_list']   = '命名空间中改变的页面：';
@@ -264,6 +271,7 @@ $lang['subscr_style_digest']   = '对每个页面发送更改的摘要邮件（
 $lang['subscr_style_list']     = '自上封邮件以来更改的页面的列表（每 %.2f 天）';
 $lang['authmodfailed']         = '错误的用户认证设置。请通知维基管理员。';
 $lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
+$lang['authpwdexpire']         = '您的密码将在 %d 天内过期，请尽快更改';
 $lang['i_chooselang']          = '选择您的语言';
 $lang['i_installer']           = 'DokuWiki 安装工具';
 $lang['i_wikiname']            = '维基名称';
@@ -290,7 +298,6 @@ $lang['i_pol1']                = '公共的维基（任何人都有读的权限
 $lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
 $lang['i_retry']               = '重试';
 $lang['i_license']             = '请选择您希望的内容发布许可协议：';
-
 $lang['recent_global']         = '您当前看到的是<b>%s</b> 名称空间的变动。你还可以在<a href="%s">查看整个维基的近期变动</a>。';
 $lang['years']                 = '%d年前';
 $lang['months']                = '%d月前';
@@ -314,8 +321,8 @@ $lang['media_namespaces']      = '选择命名空间';
 $lang['media_files']           = '在 %s 中的文件';
 $lang['media_upload']          = '上传到 <strong>%s</strong> 命名空间。';
 $lang['media_search']          = '在 <strong>%s</strong> 命名空间中搜索。';
-$lang['media_view']            = '%s 在 %s';
-$lang['media_viewold']         = '%s ';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s 在 %s';
 $lang['media_edit']            = '编辑 %s';
 $lang['media_history']         = '%s 的历史纪录';
 $lang['media_meta_edited']     = '元数据已编辑';
@@ -323,4 +330,3 @@ $lang['media_perm_read']       = '抱歉，您没有足够权限读取这些文
 $lang['media_perm_upload']     = '抱歉，您没有足够权限来上传文件。';
 $lang['media_update']          = '上传新版本';
 $lang['media_restore']         = '恢复这个版本';
-$lang['plugin_install_err']    = '插件安装不正确。重命名插件目录“%s”为“%s”。';
