@@ -21,9 +21,10 @@ if(!defined('DOKU_INC')) die('meh.');
  * @param   int       $lvl  Recursion Level
  * @author  Andreas Gohr <andi@splitbrain.org>
  */
-function search(&$data,$base,$func,$opts,$dir='',$lvl=1){
+function search(&$data,$base,$func,$opts,$dir='',$lvl=1,$sort=false){
     $dirs   = array();
     $files  = array();
+    $filepaths = array();
 
     //read in directories and files
     $dh = @opendir($base.'/'.$dir);
@@ -35,9 +36,14 @@ function search(&$data,$base,$func,$opts,$dir='',$lvl=1){
             continue;
         }
         $files[] = $dir.'/'.$file;
+        $filepaths[] = $base.'/'.$dir.'/'.$file;
     }
     closedir($dh);
-    sort($files);
+    if ($sort == 'date') {
+        @array_multisort(array_map('filemtime', $filepaths), SORT_NUMERIC, SORT_DESC, $files);
+    } else {
+        sort($files);
+    }
     sort($dirs);
 
     //give directories to userfunction then recurse
@@ -78,8 +84,8 @@ function search_callback($func,&$data,$base,$file,$type,$lvl,$opts){
  * return values for files are ignored
  *
  * All functions should check the ACL for document READ rights
- * namespaces (directories) are NOT checked as this would break
- * the recursion (You can have an nonreadable dir over a readable
+ * namespaces (directories) are NOT checked (when sneaky_index is 0) as this
+ * would break the recursion (You can have an nonreadable dir over a readable
  * one deeper nested) also make sure to check the file type (for example
  * in case of lockfiles).
  */
@@ -101,45 +107,22 @@ function search_qsearch(&$data,$base,$file,$type,$lvl,$opts){
 /**
  * Build the browsable index of pages
  *
- * $opts['ns'] is the current namespace
+ * $opts['ns'] is the currently viewed namespace
  *
  * @author  Andreas Gohr <andi@splitbrain.org>
  */
 function search_index(&$data,$base,$file,$type,$lvl,$opts){
     global $conf;
-    $return = true;
+    $opts = array(
+        'pagesonly' => true,
+        'listdirs' => true,
+        'listfiles' => !$opts['nofiles'],
+        'sneakyacl' => $conf['sneaky_index'],
+        // Hacky, should rather use recmatch
+        'depth' => preg_match('#^'.preg_quote($file, '#').'(/|$)#','/'.$opts['ns']) ? 0 : -1
+    );
 
-    $item = array();
-
-    if($type == 'd' && !preg_match('#^'.$file.'(/|$)#','/'.$opts['ns'])){
-        //add but don't recurse
-        $return = false;
-    }elseif($type == 'f' && ($opts['nofiles'] || substr($file,-4) != '.txt')){
-        //don't add
-        return false;
-    }
-
-    $id = pathID($file,($type == 'd'));
-
-    if($type=='d' && $conf['sneaky_index'] && auth_quickaclcheck($id.':') < AUTH_READ){
-        return false;
-    }
-
-    //check hidden
-    if(isHiddenPage($id)){
-        return false;
-    }
-
-    //check ACL
-    if($type=='f' && auth_quickaclcheck($id) < AUTH_READ){
-        return false;
-    }
-
-    $data[]=array( 'id'    => $id,
-            'type'  => $type,
-            'level' => $lvl,
-            'open'  => $return );
-    return $return;
+    return search_universal($data, $base, $file, $type, $lvl, $opts);
 }
 
 /**
@@ -188,7 +171,7 @@ function search_media(&$data,$base,$file,$type,$lvl,$opts){
         return false;
     }
 
-    $info['file']     = basename($file);
+    $info['file']     = utf8_basename($file);
     $info['size']     = filesize($base.'/'.$file);
     $info['mtime']    = filemtime($base.'/'.$file);
     $info['writable'] = is_writable($base.'/'.$file);
@@ -606,7 +589,7 @@ function search_universal(&$data,$base,$file,$type,$lvl,$opts){
     $item['open']  = $return;
 
     if($opts['meta']){
-        $item['file']       = basename($file);
+        $item['file']       = utf8_basename($file);
         $item['size']       = filesize($base.'/'.$file);
         $item['mtime']      = filemtime($base.'/'.$file);
         $item['rev']        = $item['mtime'];
