@@ -41,9 +41,13 @@ $lang['lang']                  = 'لغة الواجهة';
 $lang['basedir']               = 'مسار الخادوم (مثال. <code>/dokuwiki/</code>) اترك فارغا للاكتشاف التلقائي.';
 $lang['baseurl']               = 'عنوان الخادوم (مثال. <code>http://www.yourserver.com</code>). اترك فارغا للاكتشاف التلقائي.';
 $lang['savedir']               = 'دليل حفظ البيانات';
+$lang['cookiedir']             = 'مسار الكعكات. اترك فارغا لاستخدام baseurl.';
 $lang['start']                 = 'اسم صفحة البداية';
 $lang['title']                 = 'عنوان الويكي';
 $lang['template']              = 'القالب';
+$lang['tagline']               = 'Tagline (في حال دعم القالب له)
+';
+$lang['sidebar']               = 'اسم صفحة الشريط الجانبي (في حال دعم القالب له). تركه فارغا يعطل الشريط الجانبي.';
 $lang['license']               = 'تحت أي رخصة تريد اصدار المحتوى؟';
 $lang['fullpath']              = 'اظهر المحتوى الكامل للصفحات في ';
 $lang['recent']                = 'أحدث التغييرات';
@@ -64,6 +68,7 @@ $lang['useheading']            = 'استخدم اول ترويسة كأسم لل
 $lang['refcheck']              = 'التحقق من مرجع الوسائط';
 $lang['refshow']               = 'عدد مراجع الوسائط لتعرض';
 $lang['allowdebug']            = 'مكّن التنقيح <b>عطّلها إن لم تكن بحاجلة لها!</b>';
+$lang['mediarevisions']        = 'تفعيل إصدارات الوسائط؟';
 $lang['usewordblock']          = 'احجز الغثاء بناء على قائمة كلمات';
 $lang['indexdelay']            = 'التأخير قبل الفهرسة (ثوان)';
 $lang['relnofollow']           = 'استخدم rel="nofollow" للروابط الخارجية';
@@ -86,8 +91,8 @@ $lang['disableactions_other']  = 'اجراءات أخرى (مفصولة بالف
 $lang['sneaky_index']          = 'افتراضيا، ستعرض دوكو ويكي كل اسماء النطاقات في عرض الفهرس. تفعيل هذا الخيار سيخفي مالا يملك المستخدم صلاحية قراءته. قد يؤدي هذا إلى اخفاء نطاقات فرعية متاحة. وقد يؤدي لجعل صفحة الفهرس معطلة في بعض اعدادات ACL.';
 $lang['auth_security_timeout'] = 'زمن انتهاء أمان المواثقة (ثوان)';
 $lang['securecookie']          = 'هل يفرض على كعكات التصفح المعدة عبر HTTPS ان ترسل فقط عبر HTTPS من قبل المتصفح؟ عطل هذا إن كان الولوج للويكي مؤمنا فقط عبر SSL لكن تصفح الويكي غير مؤمن.';
-$lang['xmlrpc']                = 'مكّن/عطل واجهة XML-RPC.';
-$lang['xmlrpcuser']            = 'احصر الوصول لـ XML-RPC بمستخدمين أو مجموعات مفصولة بالفاصلة هنا. اتركها فارغة لتمكين الوصول للجميع.';
+$lang['remote']                = 'مكّن نظام API البعيد. يسمح هذا لبرامج أخرى بالوصول للويكي عبر XML-RPC أو آليات أخرى.';
+$lang['remoteuser']            = 'احصر الوصول البعيد ل API لمستخدمين ومجموعات يفصل بينها بالفاصلة هنا. اترك فارغا لتمكين الجميع.';
 $lang['updatecheck']           = 'تحقق من التحديثات و تنبيهات الأمان؟ دوكو ويكي ستحتاج للاتصال ب update.dokuwiki.org لأجل ذلك';
 $lang['userewrite']            = 'استعمل عناوين URLs جميلة';
 $lang['useslash']              = 'استخدم الشرطة كفاصل النطاق في العناوين';
@@ -111,10 +116,13 @@ $lang['jpg_quality']           = 'دقة ضغط JPG (0-100)';
 $lang['subscribers']           = 'مكن دعم اشتراك الصفحة';
 $lang['subscribe_time']        = 'المهلة بعد ارسال قوائم الاشتراكات والملخصات (ثوان); هذا يجب أن يكون أقل من الوقت المخصص في أيام أحدث التغييرات.';
 $lang['compress']              = 'رُص مخرجات CSS و جافا سكربت';
+$lang['cssdatauri']            = 'الحجم بالبايتات للصور المذكورة في CSS التي ستُضمن في صفحة-التنسيق لخفض طلبات HTTP. لن تعمل هذه التقنية في IE 7 أو أقل! <code>400</code> إلى <code>600</code> بايت تعد قيمة جيدة. اضبط إلى <code>0</code> لتعطلها.';
 $lang['hidepages']             = 'أخف الصفحات المنطبق عليها (تعابير شرطية)';
 $lang['send404']               = 'ارسل "HTTP 404/Page Not Found" للصفحات غير الموجودة';
 $lang['sitemap']               = 'ولد خرائط موقع جوجل (أيام)';
+$lang['broken_iua']            = 'هل الوظيفة ignore_user_abort معطلة على جهازك؟ قد يؤدي ذلك لتعطيل فهرسة البحث. IIS+PHP/CGI تعرف بأنها لاتعمل. أنظر <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">العلة 852</a> لمزيد من المعلومات.';
 $lang['xsendfile']             = 'استخدم ترويسة X-Sendfile لتمكين خادم الوب من تقديم ملفات ثابتة؟ يجب أن يكون خادم الوب داعما له.';
+$lang['renderer_xhtml']        = 'المحرك ليستخدم لمخرجات الويكي الأساسية وفق (xhtml).';
 $lang['renderer__core']        = '%s (نواة دوكو ويكي)';
 $lang['renderer__plugin']      = '%s (ملحق)';
 $lang['rememberme']            = 'اسمح بكعكات الدخول الدائم (تذكرني)';
@@ -124,6 +132,7 @@ $lang['rss_content']           = 'مالذي يعرض في عناصر تلقيم
 $lang['rss_update']            = 'تحديث تلقيم XML (ثوان)';
 $lang['recent_days']           = 'مدة إبقاء أحدث التغييرات (ايام)';
 $lang['rss_show_summary']      = 'تلقيم XML يظهر ملخصا في العنوان';
+$lang['rss_media']             = 'مانوع التغييرات التي ستدرج في تغذية XML؟';
 $lang['target____wiki']        = 'النافذة الهدف للروابط الداخلية';
 $lang['target____interwiki']   = 'النافذة الهدف للروابط الممرة interwiki';
 $lang['target____extern']      = 'النافذة الهدف للروابط الخارجية';
