@@ -10,6 +10,7 @@
  * @author Lefty <lefty@multihost.cz>
  * @author Vojta Beran <xmamut@email.cz>
  * @author zbynek.krivka@seznam.cz
+ * @author Bohumir Zamecnik <bohumir.zamecnik@gmail.com>
  */
 $lang['menu']                  = 'Správa nastavení';
 $lang['error']                 = 'Nastavení nebyla změněna kvůli alespoň jedné neplatné položce,
@@ -42,26 +43,27 @@ $lang['_template_sufix']       = 'Nastavení šablon';
 $lang['_msg_setting_undefined'] = 'Chybí metadata položky.';
 $lang['_msg_setting_no_class'] = 'Chybí třída položky.';
 $lang['_msg_setting_no_default'] = 'Chybí výchozí hodnota položky.';
-$lang['fmode']                 = 'Přístupová práva pro vytváření souborů';
-$lang['dmode']                 = 'Přístupová práva pro vytváření adresářů';
-$lang['lang']                  = 'Jazyk';
-$lang['basedir']               = 'Kořenový adresář (např. <code>/dokuwiki/</code>). Pro autodetekci nechte prázdné.';
-$lang['baseurl']               = 'Kořenové URL (např. <code>http://www.yourserver.com</code>). Pro autodetekci nechte prázdné.';
-$lang['savedir']               = 'Adresář pro ukládání dat';
-$lang['cookiedir']             = 'Cesta pro cookie. Není-li vyplněno, použije se kořenové URL.';
-$lang['start']                 = 'Název úvodní stránky';
 $lang['title']                 = 'Název celé wiki';
+$lang['start']                 = 'Název úvodní stránky';
+$lang['lang']                  = 'Jazyk';
 $lang['template']              = 'Šablona';
 $lang['license']               = 'Pod jakou licencí má být tento obsah publikován?';
-$lang['fullpath']              = 'Ukazovat plnou cestu ke stránkám v patičce';
+$lang['savedir']               = 'Adresář pro ukládání dat';
+$lang['basedir']               = 'Kořenový adresář (např. <code>/dokuwiki/</code>). Pro autodetekci nechte prázdné.';
+$lang['baseurl']               = 'Kořenové URL (např. <code>http://www.yourserver.com</code>). Pro autodetekci nechte prázdné.';
+$lang['cookiedir']             = 'Cesta pro cookie. Není-li vyplněno, použije se kořenové URL.';
+$lang['dmode']                 = 'Přístupová práva pro vytváření adresářů';
+$lang['fmode']                 = 'Přístupová práva pro vytváření souborů';
+$lang['allowdebug']            = 'Povolit debugování. <b>Vypněte, pokud to nepotřebujete!</b>';
 $lang['recent']                = 'Nedávné změny';
+$lang['recent_days']           = 'Jak staré nedávných změny uchovávat (ve dnech)';
 $lang['breadcrumbs']           = 'Počet odkazů na navštívené stránky';
 $lang['youarehere']            = 'Hierarchická "drobečková" navigace';
+$lang['fullpath']              = 'Ukazovat plnou cestu ke stránkám v patičce';
 $lang['typography']            = 'Provádět typografické nahrazování';
-$lang['htmlok']                = 'Povolit vložené HTML';
-$lang['phpok']                 = 'Povolit vložené PHP';
 $lang['dformat']               = 'Formát data (viz PHP funkci <a href="http://www.php.net/strftime">strftime</a>)';
 $lang['signature']             = 'Podpis';
+$lang['showuseras']            = 'Co se má přesně zobrazit, když se ukazuje uživatel, který naposledy editoval stránku';
 $lang['toptoclevel']           = 'Nejvyšší úroveň, kterou začít automaticky generovaný obsah';
 $lang['tocminheads']           = 'Nejnižší počet hlavních nadpisů, aby se vygeneroval obsah';
 $lang['maxtoclevel']           = 'Maximální počet úrovní v automaticky generovaném obsahu';
@@ -69,15 +71,13 @@ $lang['maxseclevel']           = 'Nejnižší úroveň pro editaci i po sekcích
 $lang['camelcase']             = 'Používat CamelCase v odkazech';
 $lang['deaccent']              = 'Čistit názvy stránek';
 $lang['useheading']            = 'Používat první nadpis jako název stránky';
-$lang['refcheck']              = 'Kontrolovat odkazy na média (před vymazáním)';
-$lang['refshow']               = 'Počet zobrazených odkazů na média';
-$lang['allowdebug']            = 'Povolit debugování. <b>Vypněte, pokud to nepotřebujete!</b>';
-$lang['usewordblock']          = 'Blokovat spam za použití seznamu známých spamových slov';
-$lang['indexdelay']            = 'Časová prodleva před indexací (v sekundách)';
-$lang['relnofollow']           = 'Používat rel="nofollow" na externí odkazy';
-$lang['mailguard']             = 'Metoda "zamaskování" emailových adres';
-$lang['iexssprotect']          = 'Zkontrolovat nahrané soubory vůči možnému škodlivému JavaScriptu či HTML';
-$lang['showuseras']            = 'Co se má přesně zobrazit, když se ukazuje uživatel, který naposledy editoval stránku';
+$lang['sneaky_index']          = 'Ve výchozím nastavení DokuWiki zobrazuje v indexu všechny
+jmenné prostory. Zapnutím této volby se skryjí ty jmenné prostory,
+k nimž uživatel nemá právo pro čtení, což může ale způsobit, že
+vnořené jmenné prostory, k nimž právo má, budou přesto skryty.
+To může mít za následek, že index bude při některých
+nastaveních ACL nepoužitelný.';
+$lang['hidepages']             = 'Skrýt stránky odpovídající vzoru (regulární výrazy)';
 $lang['useacl']                = 'Používat přístupová práva (ACL)';
 $lang['autopasswd']            = 'Generovat hesla automaticky';
 $lang['authtype']              = 'Metoda autentizace';
@@ -86,65 +86,65 @@ $lang['defaultgroup']          = 'Výchozí skupina';
 $lang['superuser']             = 'Superuživatel - skupina nebo uživatel s plnými právy pro přístup ke všem stránkách bez ohledu na nastavení ACL';
 $lang['manager']               = 'Manažer - skupina nebo uživatel s přístupem k některým správcovským funkcím';
 $lang['profileconfirm']        = 'Potvrdit změny v profilu zadáním hesla';
+$lang['rememberme']            = 'Povolit trvaté přihlašovací cookies (zapamatuj si mě)';
 $lang['disableactions']        = 'Vypnout DokuWiki akce';
 $lang['disableactions_check']  = 'Zkontrolovat';
 $lang['disableactions_subscription'] = 'Přihlásit se/Odhlásit se ze seznamu pro odběr změn';
 $lang['disableactions_wikicode'] = 'Prohlížet zdrojové kódy/Export wiki textu';
 $lang['disableactions_other']  = 'Další akce (oddělené čárkou)';
-$lang['sneaky_index']          = 'Ve výchozím nastavení DokuWiki zobrazuje v indexu všechny
-jmenné prostory. Zapnutím této volby se skryjí ty jmenné prostory,
-k nimž uživatel nemá právo pro čtení, což může ale způsobit, že
-vnořené jmenné prostory, k nimž právo má, budou přesto skryty.
-To může mít za následek, že index bude při některých
-nastaveních ACL nepoužitelný.';
 $lang['auth_security_timeout'] = 'Časový limit pro autentikaci (v sekundách)';
 $lang['securecookie']          = 'Má prohlížeč posílat cookies nastavené přes HTTPS opět jen přes HTTPS? Vypněte tuto volbu, pokud chcete, aby bylo pomocí SSL zabezpečeno pouze přihlašování do wiki, ale obsah budete prohlížet nezabezpečeně.';
-$lang['xmlrpc']                = 'Povolit/Zakázat rozhraní XML-RPC.';
-$lang['xmlrpcuser']            = 'Omezit přístup pomocí XML-RPC pouze na zde zadané skupiny či uživatele (oddělené čárkami). Necháte-li pole prázdné, dáte přístup komukoliv.';
-$lang['updatecheck']           = 'Kontrolovat aktualizace a bezpečnostní varování? DokuWiki potřebuje pro tuto funkci přístup k update.dokuwiki.org';
-$lang['userewrite']            = 'Používat "pěkná" URL';
-$lang['useslash']              = 'Používat lomítko jako oddělovač jmenných prostorů v URL';
+$lang['usewordblock']          = 'Blokovat spam za použití seznamu známých spamových slov';
+$lang['relnofollow']           = 'Používat rel="nofollow" na externí odkazy';
+$lang['indexdelay']            = 'Časová prodleva před indexací (v sekundách)';
+$lang['mailguard']             = 'Metoda "zamaskování" emailových adres';
+$lang['iexssprotect']          = 'Zkontrolovat nahrané soubory vůči možnému škodlivému JavaScriptu či HTML';
 $lang['usedraft']              = 'Během editace ukládat koncept automaticky';
-$lang['sepchar']               = 'Znak pro oddělování slov v názvech stránek';
-$lang['canonical']             = 'Používat plně kanonická URL';
-$lang['fnencode']              = 'Metoda pro kódování ne-ASCII názvů souborů';
-$lang['autoplural']            = 'Kontrolovat plurálové tvary v odkazech';
-$lang['compression']           = 'Metoda komprese pro staré verze';
-$lang['cachetime']             = 'Maximální životnost cache (v sekundách)';
+$lang['htmlok']                = 'Povolit vložené HTML';
+$lang['phpok']                 = 'Povolit vložené PHP';
 $lang['locktime']              = 'Maximální životnost zámkových souborů (v sekundách)';
-$lang['fetchsize']             = 'Maximální velikost souboru (v bajtech), co ještě fetch.php bude stahovat z externích zdrojů';
-$lang['notify']                = 'Posílat oznámení o změnách na následující emailovou adresu';
-$lang['registernotify']        = 'Posílat informace o nově registrovaných uživatelích na tuto mailovou adresu';
-$lang['mailfrom']              = 'E-mailová adresa, která se bude používat pro automatické maily';
-$lang['mailprefix']            = 'Předpona předmětu e-mailu, která se bude používat pro automatické maily';
-$lang['gzip_output']           = 'Používat pro xhtml Content-Encoding gzip';
-$lang['gdlib']                 = 'Verze GD knihovny';
-$lang['im_convert']            = 'Cesta k nástroji convert z balíku ImageMagick';
-$lang['jpg_quality']           = 'Kvalita komprese JPEG (0-100)';
-$lang['subscribers']           = 'Možnost přihlásit se k odběru novinek stránky';
-$lang['subscribe_time']        = 'Časový interval v sekundách, ve kterém jsou posílány změny a souhrny změn. Interval by neměl být kratší než čas uvedený v recent_days.';
-$lang['compress']              = 'Zahustit CSS a JavaScript výstup';
-$lang['cssdatauri']            = 'Velikost [v bajtech] obrázků odkazovaných v CSS souborech, které budou pro ušetření HTTP požadavku vestavěny do stylu. Tato technika nefunguje v IE 7 a starším. Doporučená hodnota je mezi <code>400</code> a <code>600</code> bajty. Pro vypnutí nastavte na <code>0</code>.';
-$lang['hidepages']             = 'Skrýt stránky odpovídající vzoru (regulární výrazy)';
-$lang['send404']               = 'Posílat "HTTP 404/Page Not Found" pro neexistují stránky';
-$lang['sitemap']               = 'Generovat Google sitemap (interval ve dnech)';
-$lang['broken_iua']            = 'Je na vašem systému funkce ignore_user_abort porouchaná? To může způsobovat nefunkčnost vyhledávacího indexu. O kombinaci IIS+PHP/CGI je známo, že nefunguje správně. Viz <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> pro více informací.';
-$lang['xsendfile']             = 'Používat X-Sendfile hlavničky pro download statických souborů z webserveru? Je však požadována podpora této funkce na straně Vašeho webserveru.';
-$lang['renderer_xhtml']        = 'Vykreslovací jádro pro hlavní (xhtml) výstup wiki';
-$lang['renderer__core']        = '%s (jádro DokuWiki)';
-$lang['renderer__plugin']      = '%s (plugin)';
-$lang['rememberme']            = 'Povolit trvaté přihlašovací cookies (zapamatuj si mě)';
-$lang['rss_type']              = 'Typ XML kanálu';
-$lang['rss_linkto']            = 'XML kanál odkazuje na';
-$lang['rss_content']           = 'Co zobrazovat v položkách XML kanálu?';
-$lang['rss_update']            = 'Interval aktualizace XML kanálu (v sekundách)';
-$lang['recent_days']           = 'Jak staré nedávných změny uchovávat (ve dnech)';
-$lang['rss_show_summary']      = 'XML kanál ukazuje souhrn v titulku';
+$lang['cachetime']             = 'Maximální životnost cache (v sekundách)';
 $lang['target____wiki']        = 'Cílové okno pro interní odkazy';
 $lang['target____interwiki']   = 'Cílové okno pro interwiki odkazy';
 $lang['target____extern']      = 'Cílové okno pro externí odkazy';
 $lang['target____media']       = 'Cílové okno pro odkazy na média';
 $lang['target____windows']     = 'Cílové okno pro odkazy na windows sdílení';
+$lang['refcheck']              = 'Kontrolovat odkazy na média (před vymazáním)';
+$lang['refshow']               = 'Počet zobrazených odkazů na média';
+$lang['gdlib']                 = 'Verze GD knihovny';
+$lang['im_convert']            = 'Cesta k nástroji convert z balíku ImageMagick';
+$lang['jpg_quality']           = 'Kvalita komprese JPEG (0-100)';
+$lang['fetchsize']             = 'Maximální velikost souboru (v bajtech), co ještě fetch.php bude stahovat z externích zdrojů';
+$lang['subscribers']           = 'Možnost přihlásit se k odběru novinek stránky';
+$lang['subscribe_time']        = 'Časový interval v sekundách, ve kterém jsou posílány změny a souhrny změn. Interval by neměl být kratší než čas uvedený v recent_days.';
+$lang['notify']                = 'Posílat oznámení o změnách na následující emailovou adresu';
+$lang['registernotify']        = 'Posílat informace o nově registrovaných uživatelích na tuto mailovou adresu';
+$lang['mailfrom']              = 'E-mailová adresa, která se bude používat pro automatické maily';
+$lang['mailprefix']            = 'Předpona předmětu e-mailu, která se bude používat pro automatické maily';
+$lang['sitemap']               = 'Generovat Google sitemap (interval ve dnech)';
+$lang['rss_type']              = 'Typ XML kanálu';
+$lang['rss_linkto']            = 'XML kanál odkazuje na';
+$lang['rss_content']           = 'Co zobrazovat v položkách XML kanálu?';
+$lang['rss_update']            = 'Interval aktualizace XML kanálu (v sekundách)';
+$lang['rss_show_summary']      = 'XML kanál ukazuje souhrn v titulku';
+$lang['updatecheck']           = 'Kontrolovat aktualizace a bezpečnostní varování? DokuWiki potřebuje pro tuto funkci přístup k update.dokuwiki.org';
+$lang['userewrite']            = 'Používat "pěkná" URL';
+$lang['useslash']              = 'Používat lomítko jako oddělovač jmenných prostorů v URL';
+$lang['sepchar']               = 'Znak pro oddělování slov v názvech stránek';
+$lang['canonical']             = 'Používat plně kanonická URL';
+$lang['fnencode']              = 'Metoda pro kódování ne-ASCII názvů souborů';
+$lang['autoplural']            = 'Kontrolovat plurálové tvary v odkazech';
+$lang['compression']           = 'Metoda komprese pro staré verze';
+$lang['gzip_output']           = 'Používat pro xhtml Content-Encoding gzip';
+$lang['compress']              = 'Zahustit CSS a JavaScript výstup';
+$lang['cssdatauri']            = 'Velikost [v bajtech] obrázků odkazovaných v CSS souborech, které budou pro ušetření HTTP požadavku vestavěny do stylu. Tato technika nefunguje v IE 7 a starším. Doporučená hodnota je mezi <code>400</code> a <code>600</code> bajty. Pro vypnutí nastavte na <code>0</code>.';
+$lang['send404']               = 'Posílat "HTTP 404/Page Not Found" pro neexistují stránky';
+$lang['broken_iua']            = 'Je na vašem systému funkce ignore_user_abort porouchaná? To může způsobovat nefunkčnost vyhledávacího indexu. O kombinaci IIS+PHP/CGI je známo, že nefunguje správně. Viz <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> pro více informací.';
+$lang['xsendfile']             = 'Používat X-Sendfile hlavničky pro download statických souborů z webserveru? Je však požadována podpora této funkce na straně Vašeho webserveru.';
+$lang['renderer_xhtml']        = 'Vykreslovací jádro pro hlavní (xhtml) výstup wiki';
+$lang['renderer__core']        = '%s (jádro DokuWiki)';
+$lang['renderer__plugin']      = '%s (plugin)';
+$lang['dnslookups']            = 'DokuWiki zjišťuje DNS jména pro vzdálené IP adresy uživatelů, kteří editují stránky. Pokud máte pomalý, nebo nefunkční DNS server, nebo nepotřebujete tuto funkci, tak tuto volbu zrušte.';
 $lang['proxy____host']         = 'Název proxy serveru';
 $lang['proxy____port']         = 'Proxy port';
 $lang['proxy____user']         = 'Proxy uživatelské jméno';
