@@ -7,6 +7,7 @@
  * @author omidmr@gmail.com
  * @author Omid Mottaghi <omidmr@gmail.com>
  * @author Mohammad Reza Shoaei <shoaei@gmail.com>
+ * @author Milad DZand <M.DastanZand@gmail.com>
  */
 $lang['menu']                  = 'تنظیمات پیکر‌بندی';
 $lang['error']                 = 'به دلیل ایراد در مقادیر وارد شده، تنظیمات اعمال نشد، خواهشمندیم تغییرات را مجددن کنترل نمایید و دوباره ارسال کنید.<br/> مقادیر مشکل‌دار با کادر قرمز مشخص شده‌اند.';
@@ -28,6 +29,8 @@ $lang['_anti_spam']            = 'تنظیمات ضد-اسپم';
 $lang['_editing']              = 'تنظیمات ویرایش';
 $lang['_links']                = 'تنظیمات پیوند';
 $lang['_media']                = 'تنظیمات رسانه‌ها (فایل‌ها)';
+$lang['_notifications']        = 'تنظیمات آگاه سازی';
+$lang['_syndication']          = 'تنظیمات پیوند';
 $lang['_advanced']             = 'تنظیمات پیشرفته';
 $lang['_network']              = 'تنظیمات شبکه';
 $lang['_plugin_sufix']         = 'تنظیمات افزونه';
@@ -35,25 +38,29 @@ $lang['_template_sufix']       = 'تنظیمات قالب';
 $lang['_msg_setting_undefined'] = 'داده‌نمایی برای تنظیمات وجود ندارد';
 $lang['_msg_setting_no_class'] = 'هیچ دسته‌ای برای تنظیمات وجود ندارد.';
 $lang['_msg_setting_no_default'] = 'بدون مقدار پیش‌فرض';
-$lang['fmode']                 = 'دسترسی پیش‌فرض فایل‌ها در زمان ایجاد';
-$lang['dmode']                 = 'زبان';
+$lang['title']                 = 'عنوان ویکی';
+$lang['start']                 = 'نام صفحه‌ی آغازین';
 $lang['lang']                  = 'زبان';
+$lang['template']              = 'قالب';
+$lang['tagline']               = 'خط تگ (اگر قالب از آن پشتیبانی می کند)';
+$lang['sidebar']               = 'نام نوار صفحه کناری (اگر قالب از آن پشتیبانی می کند) ، فیلد خالی نوار کناری غیر فعال خواهد کرد.';
+$lang['license']               = 'لایسنس مطالب ویکی';
+$lang['savedir']               = 'شاخه‌ی ذخیره‌سازی داده‌ها';
 $lang['basedir']               = 'شاخه‌ی اصلی';
 $lang['baseurl']               = 'آدرس اصلی';
-$lang['savedir']               = 'شاخه‌ی ذخیره‌سازی داده‌ها';
-$lang['start']                 = 'نام صفحه‌ی آغازین';
-$lang['title']                 = 'عنوان ویکی';
-$lang['template']              = 'قالب';
-$lang['license']               = 'لایسنس مطالب ویکی';
-$lang['fullpath']              = 'نمایش دادن مسیر کامل صفحات در پایین صفحه';
+$lang['cookiedir']             = 'مسیر کوکی ها. برای استفاده از آدرس پایه ، آن را خالی بگذارید.';
+$lang['dmode']                 = 'زبان';
+$lang['fmode']                 = 'دسترسی پیش‌فرض فایل‌ها در زمان ایجاد';
+$lang['allowdebug']            = 'امکان کرم‌زدایی (debug) <b>اگر نیازی ندارید، غیرفعال کنید</b>';
 $lang['recent']                = 'تغییرات اخیر';
+$lang['recent_days']           = 'چند تغییر در خوراک نمایش داده شود به روز';
 $lang['breadcrumbs']           = 'تعداد ردپاها';
 $lang['youarehere']            = 'ردپای درختی';
+$lang['fullpath']              = 'نمایش دادن مسیر کامل صفحات در پایین صفحه';
 $lang['typography']            = 'جای‌گزاری متن‌ها انجام شود';
-$lang['htmlok']                = 'امکان افزودن HTML باشد';
-$lang['phpok']                 = 'امکان افزودن PHP باشد';
 $lang['dformat']               = 'فرمت تاریخ (راهنمای تابع <a href="http://www.php.net/strftime">strftime</a> را مشاهده کنید)';
 $lang['signature']             = 'امضا';
+$lang['showuseras']            = 'چگونه آخرین کاربر ویرایش کننده، یک صفحه نمایش داده شود';
 $lang['toptoclevel']           = 'بیشترین عمق برای «فهرست مطالب»';
 $lang['tocminheads']           = 'حداقل مقدار عنوان‌های یک صفحه، برای تشخیص این‌که «فهرست مطالب» (TOC) ایجاد شود';
 $lang['maxtoclevel']           = 'حداکثر عمق «فهرست مطالب»';
@@ -61,15 +68,8 @@ $lang['maxseclevel']           = 'بیش‌ترین سطح ویرایش بخش
 $lang['camelcase']             = 'از «حالت شتری» (CamelCase) برای پیوندها استفاده شود';
 $lang['deaccent']              = 'تمیز کردن نام صفحات';
 $lang['useheading']            = 'استفاده از اولین عنوان برای نام صفحه';
-$lang['refcheck']              = 'بررسی کردن مرجع رسانه‌ها';
-$lang['refshow']               = 'تعداد مراجعی که برای یک رسانه نمایش داده شود';
-$lang['allowdebug']            = 'امکان کرم‌زدایی (debug) <b>اگر نیازی ندارید، غیرفعال کنید</b>';
-$lang['usewordblock']          = 'اسپم‌ها را براساس لیست کلمات مسدود کن';
-$lang['indexdelay']            = 'مقدار تاخیر پیش از فهرست‌بندی (ثانیه)';
-$lang['relnofollow']           = 'از «rel=nofollow» در پیوندهای خروجی استفاده شود';
-$lang['mailguard']             = 'مبهم کردن آدرس‌های ایمیل';
-$lang['iexssprotect']          = 'بررسی کردن فایل‌های ارسال شده را برای کدهای HTML یا JavaScript مخرب';
-$lang['showuseras']            = 'چگونه آخرین کاربر ویرایش کننده، یک صفحه نمایش داده شود';
+$lang['sneaky_index']          = 'به طور پیش‌فرض، DokuWiki در فهرست تمامی فضای‌نام‌ها را نمایش می‌دهد. فعال کردن این گزینه، مواردی را که کاربر حق خواندنشان را ندارد مخفی می‌کند. این گزینه ممکن است باعث دیده نشدن زیرفضای‌نام‌هایی شود که دسترسی خواندن به آن‌ها وجود دارد. و ممکن است باعث شود که فهرست در حالاتی از دسترسی‌ها، غیرقابل استفاده شود.';
+$lang['hidepages']             = 'مخفی کردن صفحات با فرمت زیر (از عبارات منظم استفاده شود)';
 $lang['useacl']                = 'استفاده از مدیریت دسترسی‌ها';
 $lang['autopasswd']            = 'ایجاد خودکار گذرواژه‌ها';
 $lang['authtype']              = 'روش معتبرسازی';
@@ -78,59 +78,71 @@ $lang['defaultgroup']          = 'گروه پیش‌فرض';
 $lang['superuser']             = 'کاربر اصلی - گروه، کاربر یا لیستی که توسط ویرگول جدا شده از کاربرها و گروه‌ها (مثل user1,@group1,user2) با دسترسی کامل به همه‌ی صفحات و امکانات سیستم، فارغ از دسترسی‌های آن کاربر.';
 $lang['manager']               = 'مدیر - گروه، کاربر یا لیستی که توسط ویرگول جدا شده از کاربرها و گروه‌ها (مثل user1,@group1,user2) با دسترسی‌های خاص به بخش‌های متفاوت';
 $lang['profileconfirm']        = 'تغییرات پروفایل با وارد کردن گذرواژه تایید شود';
+$lang['rememberme']            = 'امکان ورود دایم، توسط کوکی، وجود داشته باشد (مرا به خاطر بسپار)';
 $lang['disableactions']        = 'غیرفعال کردن فعالیت‌های DokuWiki';
 $lang['disableactions_check']  = 'بررسی';
 $lang['disableactions_subscription'] = 'عضویت/عدم عضویت';
 $lang['disableactions_wikicode'] = 'نمایش سورس/برون‌بری خام';
 $lang['disableactions_other']  = 'فعالیت‌های دیگر (با ویرگول انگلیسی «,» از هم جدا کنید)';
-$lang['sneaky_index']          = 'به طور پیش‌فرض، DokuWiki در فهرست تمامی فضای‌نام‌ها را نمایش می‌دهد. فعال کردن این گزینه، مواردی را که کاربر حق خواندنشان را ندارد مخفی می‌کند. این گزینه ممکن است باعث دیده نشدن زیرفضای‌نام‌هایی شود که دسترسی خواندن به آن‌ها وجود دارد. و ممکن است باعث شود که فهرست در حالاتی از دسترسی‌ها، غیرقابل استفاده شود.';
 $lang['auth_security_timeout'] = 'زمان انقضای معتبرسازی به ثانیه';
 $lang['securecookie']          = 'آیا کوکی‌ها باید با قرارداد HTTPS ارسال شوند؟ این گزینه را زمانی که فقط صفحه‌ی ورود ویکی‌تان با SSL امن شده است، اما ویکی را ناامن مرور می‌کنید، غیرفعال نمایید.';
-$lang['xmlrpc']                = 'فعال/غیرفعال کردن XML-RPC';
-$lang['xmlrpcuser']            = 'محمدود کردن دسترسی به XML-RPC توسط گروه های جدا شده توسط ویرگول ویا اعضای داده شده در اینجا. این مکان را خالی بگزارید تا به همه دسترسی داده شود.';
-$lang['updatecheck']           = 'هشدارهای به روز رسانی و امنیتی بررسی شود؟ برای این‌کار DokuWiki با سرور update.dokuwiki.org تماس خواهد گرفت.';
-$lang['userewrite']            = 'از زیباکننده‌ی آدرس‌ها استفاده شود';
-$lang['useslash']              = 'از اسلش «/» برای جداکننده‌ی آدرس فضای‌نام‌ها استفاده شود';
+$lang['remote']                = 'سیستم API راه دور را فعال کنید . این به سایر کاربردها اجازه می دهد که به ویکی از طریق XML-RPC یا سایر مکانیزم ها دسترسی داشته باشند.';
+$lang['remoteuser']            = 'محدود کردن دسترسی API راه دور به گروه های جدا شده با ویرگول یا کاربران داده شده در این جا. برای دادن دسترسی به همه این فیلد را خالی بگذارید.';
+$lang['usewordblock']          = 'اسپم‌ها را براساس لیست کلمات مسدود کن';
+$lang['relnofollow']           = 'از «rel=nofollow» در پیوندهای خروجی استفاده شود';
+$lang['indexdelay']            = 'مقدار تاخیر پیش از فهرست‌بندی (ثانیه)';
+$lang['mailguard']             = 'مبهم کردن آدرس‌های ایمیل';
+$lang['iexssprotect']          = 'بررسی کردن فایل‌های ارسال شده را برای کدهای HTML یا JavaScript مخرب';
 $lang['usedraft']              = 'ایجاد خودکار چرک‌نویس در زمان نگارش';
-$lang['sepchar']               = 'کلمه‌ی جداکننده‌ی نام صفحات';
-$lang['canonical']             = 'استفاده از آدرس‌های استاندارد';
-$lang['fnencode']              = 'روش تغییر نام فایل‌هایی با فرمتی غیر از اسکی';
-$lang['autoplural']            = 'بررسی جمع بودن در پیوندها';
-$lang['compression']           = 'روش فشرده‌سازی برای فایل‌های خُرد';
-$lang['cachetime']             = 'بیشینه‌ی زمان حافظه‌ی موقت (cache) به ثانیه';
+$lang['htmlok']                = 'امکان افزودن HTML باشد';
+$lang['phpok']                 = 'امکان افزودن PHP باشد';
 $lang['locktime']              = 'بیشینه‌ی زمان قفل شدن فایل‌ها به ثانیه';
-$lang['fetchsize']             = 'بیشینه‌ی حجمی که فایل fetch.php می‌تواند دریافت کند (به بایت)';
-$lang['notify']                = 'تغییرات به این ایمیل ارسال شود';
-$lang['registernotify']        = 'اطلاعات کاربران تازه وارد به این ایمیل ارسال شود';
-$lang['mailfrom']              = 'آدرس ایمیلی که برای ایمیل‌های خودکار استفاده می‌شود';
-$lang['mailprefix']            = 'پیشوند تیتر ایمیل (جهت ایمیل های خودکار)';
-$lang['gzip_output']           = 'استفاده از gzip برای xhtmlها';
-$lang['gdlib']                 = 'نگارش کتاب‌خانه‌ی GD';
-$lang['im_convert']            = 'مسیر ابزار convert از برنامه‌ی ImageMagick';
-$lang['jpg_quality']           = 'کیفیت فشرده سازی JPEG (از 0 تا 100)';
-$lang['subscribers']           = 'توانایی عضویت در صفحات باشد';
-$lang['subscribe_time']        = 'زمان مورد نیاز برای ارسال خبر نامه ها (ثانیه); این مقدار می بایست کمتر زمانی باشد که در recent_days تعریف شده است.';
-$lang['compress']              = 'فشرده‌سازی کد‌های CSS و JavaScript';
-$lang['hidepages']             = 'مخفی کردن صفحات با فرمت زیر (از عبارات منظم استفاده شود)';
-$lang['send404']               = 'ارسال «HTTP 404/Page Not Found» برای صفحاتی که وجود ندارند';
-$lang['sitemap']               = 'تولید کردن نقشه‌ی سایت توسط گوگل (روز)';
-$lang['broken_iua']            = 'آیا تابع ignore_user_about در ویکی شما کار نمی‌کند؟ ممکن است فهرست جستجوی شما کار نکند. IIS به همراه PHP/CGI باعث خراب شدن این گزینه می‌شود. برای اطلاعات بیشتر <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">باگ ۸۵۲</a> را مشاهده کنید.';
-$lang['xsendfile']             = 'استفاده از هدر X-Sendfile، تا به وب‌سرور  توانایی ارسال فایل‌های ثابت را بدهد. وب‌سرور شما باید این مورد را پشتیبانی کند.';
-$lang['renderer_xhtml']        = 'مفسری که برای خروجی اصلی ویکی استفاده شود';
-$lang['renderer__core']        = '%s (هسته‌ی dokuwiki)';
-$lang['renderer__plugin']      = '%s (افزونه)';
-$lang['rememberme']            = 'امکان ورود دایم، توسط کوکی، وجود داشته باشد (مرا به خاطر بسپار)';
-$lang['rss_type']              = 'نوع خوراک';
-$lang['rss_linkto']            = 'خوراک به کجا لینک شود';
-$lang['rss_content']           = 'چه چیزی در تکه‌های خوراک نمایش داده شود؟';
-$lang['rss_update']            = 'زمان به روز رسانی خوراک به ثانیه';
-$lang['recent_days']           = 'چند تغییر در خوراک نمایش داده شود به روز';
-$lang['rss_show_summary']      = 'خوراک مختصری از مطلب را در عنوان نمایش دهد';
+$lang['cachetime']             = 'بیشینه‌ی زمان حافظه‌ی موقت (cache) به ثانیه';
 $lang['target____wiki']        = 'پنجره‌ی هدف در پیوند‌های داخلی';
 $lang['target____interwiki']   = 'پنجره‌ی هدف در پیوند‌های داخل ویکی';
 $lang['target____extern']      = 'پنجره‌ی هدف در پیوند‌های خارجی';
 $lang['target____media']       = 'پنجره‌ی هدف در پیوند‌های رسانه‌ها';
 $lang['target____windows']     = 'پنجره‌ی هدف در پیوند‌های پنجره‌ای';
+$lang['mediarevisions']        = 'تجدید نظر رسانه ، فعال؟';
+$lang['refcheck']              = 'بررسی کردن مرجع رسانه‌ها';
+$lang['refshow']               = 'تعداد مراجعی که برای یک رسانه نمایش داده شود';
+$lang['gdlib']                 = 'نگارش کتاب‌خانه‌ی GD';
+$lang['im_convert']            = 'مسیر ابزار convert از برنامه‌ی ImageMagick';
+$lang['jpg_quality']           = 'کیفیت فشرده سازی JPEG (از 0 تا 100)';
+$lang['fetchsize']             = 'بیشینه‌ی حجمی که فایل fetch.php می‌تواند دریافت کند (به بایت)';
+$lang['subscribers']           = 'توانایی عضویت در صفحات باشد';
+$lang['subscribe_time']        = 'زمان مورد نیاز برای ارسال خبر نامه ها (ثانیه); این مقدار می بایست کمتر زمانی باشد که در recent_days تعریف شده است.';
+$lang['notify']                = 'تغییرات به این ایمیل ارسال شود';
+$lang['registernotify']        = 'اطلاعات کاربران تازه وارد به این ایمیل ارسال شود';
+$lang['mailfrom']              = 'آدرس ایمیلی که برای ایمیل‌های خودکار استفاده می‌شود';
+$lang['mailprefix']            = 'پیشوند تیتر ایمیل (جهت ایمیل های خودکار)';
+$lang['htmlmail']              = 'فرستادن با ظاهر بهتر ، امّا با اندازه بیشتر در ایمیل های چند قسمتی HTML.
+برای استفاده از ایمیل متنی ، غیر فعال کنید.';
+$lang['sitemap']               = 'تولید کردن نقشه‌ی سایت توسط گوگل (روز)';
+$lang['rss_type']              = 'نوع خوراک';
+$lang['rss_linkto']            = 'خوراک به کجا لینک شود';
+$lang['rss_content']           = 'چه چیزی در تکه‌های خوراک نمایش داده شود؟';
+$lang['rss_update']            = 'زمان به روز رسانی خوراک به ثانیه';
+$lang['rss_show_summary']      = 'خوراک مختصری از مطلب را در عنوان نمایش دهد';
+$lang['rss_media']             = 'چه نوع تغییراتی باید در خوراک XML لیست شود؟';
+$lang['updatecheck']           = 'هشدارهای به روز رسانی و امنیتی بررسی شود؟ برای این‌کار DokuWiki با سرور update.dokuwiki.org تماس خواهد گرفت.';
+$lang['userewrite']            = 'از زیباکننده‌ی آدرس‌ها استفاده شود';
+$lang['useslash']              = 'از اسلش «/» برای جداکننده‌ی آدرس فضای‌نام‌ها استفاده شود';
+$lang['sepchar']               = 'کلمه‌ی جداکننده‌ی نام صفحات';
+$lang['canonical']             = 'استفاده از آدرس‌های استاندارد';
+$lang['fnencode']              = 'روش تغییر نام فایل‌هایی با فرمتی غیر از اسکی';
+$lang['autoplural']            = 'بررسی جمع بودن در پیوندها';
+$lang['compression']           = 'روش فشرده‌سازی برای فایل‌های خُرد';
+$lang['gzip_output']           = 'استفاده از gzip برای xhtmlها';
+$lang['compress']              = 'فشرده‌سازی کد‌های CSS و JavaScript';
+$lang['cssdatauri']            = 'اندازه بایت هایی که تصاویر ارجاع شده به فایل های CSS باید به درستی درون stylesheet جایگذاری شود تا سربار سرایند درخواست HTTP را کاهش دهد. این روش در IE 7 و پایین تر کار نمی کند! مقادیر <code>400</code> تا <code>600</code> بایت مقدار خوبی است. برای غیر فعال کردن <code>0</code> قرار دهید.';
+$lang['send404']               = 'ارسال «HTTP 404/Page Not Found» برای صفحاتی که وجود ندارند';
+$lang['broken_iua']            = 'آیا تابع ignore_user_about در ویکی شما کار نمی‌کند؟ ممکن است فهرست جستجوی شما کار نکند. IIS به همراه PHP/CGI باعث خراب شدن این گزینه می‌شود. برای اطلاعات بیشتر <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">باگ ۸۵۲</a> را مشاهده کنید.';
+$lang['xsendfile']             = 'استفاده از هدر X-Sendfile، تا به وب‌سرور  توانایی ارسال فایل‌های ثابت را بدهد. وب‌سرور شما باید این مورد را پشتیبانی کند.';
+$lang['renderer_xhtml']        = 'مفسری که برای خروجی اصلی ویکی استفاده شود';
+$lang['renderer__core']        = '%s (هسته‌ی dokuwiki)';
+$lang['renderer__plugin']      = '%s (افزونه)';
+$lang['dnslookups']            = 'DokuWiki نام هاست ها را برای آدرسهای IP یِ صفحات ویرایشی کاربران ، جستجو می کند. اگر یک سرور DNS کند یا نا کارامد دارید یا این ویژگی را نمی خواهید ، این گزینه را غیر فعال کنید.';
 $lang['proxy____host']         = 'آدرس سرور پروکسی';
 $lang['proxy____port']         = 'پورت پروکسی';
 $lang['proxy____user']         = 'نام کاربری پروکسی';
