@@ -14,6 +14,7 @@
  * @author Grzegorz Widła <dzesdzes@gmail.com>
  * @author Łukasz Chmaj <teachmeter@gmail.com>
  * @author Begina Felicysym <begina.felicysym@wp.eu>
+ * @author Aoi Karasu <aoikarasu@gmail.com>
  */
 $lang['menu']                  = 'Ustawienia';
 $lang['error']                 = 'Ustawienia nie zostały zapisane z powodu błędnych wartości, przejrzyj je i ponów próbę zapisu. <br/> Niepoprawne wartości są wyróżnione kolorem czerwonym.';
@@ -35,6 +36,8 @@ $lang['_anti_spam']            = 'Spam';
 $lang['_editing']              = 'Edycja';
 $lang['_links']                = 'Odnośniki';
 $lang['_media']                = 'Media';
+$lang['_notifications']        = 'Ustawienia powiadomień';
+$lang['_syndication']          = 'Ustawienia RSS';
 $lang['_advanced']             = 'Zaawansowane';
 $lang['_network']              = 'Sieć';
 $lang['_plugin_sufix']         = 'Wtyczki';
@@ -42,26 +45,29 @@ $lang['_template_sufix']       = 'Motywy';
 $lang['_msg_setting_undefined'] = 'Brak danych o ustawieniu.';
 $lang['_msg_setting_no_class'] = 'Brak kategorii ustawień.';
 $lang['_msg_setting_no_default'] = 'Brak wartości domyślnej.';
-$lang['fmode']                 = 'Tryb tworzenia pliku';
-$lang['dmode']                 = 'Tryb tworzenia katalogu';
+$lang['title']                 = 'Tytuł wiki';
+$lang['start']                 = 'Tytuł strony początkowej';
 $lang['lang']                  = 'Język';
+$lang['template']              = 'Motyw';
+$lang['tagline']               = 'Motto (jeśli szablon daje taką możliwość)';
+$lang['sidebar']               = 'Nazwa strony paska bocznego (jeśli szablon je obsługuje), puste pole wyłącza pasek boczny';
+$lang['license']               = 'Pod jaką licencją publikować treści wiki?';
+$lang['savedir']               = 'Katalog z danymi';
 $lang['basedir']               = 'Katalog główny';
 $lang['baseurl']               = 'Główny URL';
-$lang['savedir']               = 'Katalog z danymi';
 $lang['cookiedir']             = 'Ścieżka plików ciasteczek. Zostaw puste by użyć baseurl.';
-$lang['start']                 = 'Tytuł strony początkowej';
-$lang['title']                 = 'Tytuł wiki';
-$lang['template']              = 'Motyw';
-$lang['license']               = 'Pod jaką licencją publikować treści wiki?';
-$lang['fullpath']              = 'Wyświetlanie pełnych ścieżek';
+$lang['dmode']                 = 'Tryb tworzenia katalogu';
+$lang['fmode']                 = 'Tryb tworzenia pliku';
+$lang['allowdebug']            = 'Debugowanie (niebezpieczne!)';
 $lang['recent']                = 'Ilość ostatnich zmian';
+$lang['recent_days']           = 'Ilość ostatnich zmian (w dniach)';
 $lang['breadcrumbs']           = 'Długość śladu';
 $lang['youarehere']            = 'Ślad według struktury';
+$lang['fullpath']              = 'Wyświetlanie pełnych ścieżek';
 $lang['typography']            = 'Konwersja cudzysłowu, myślników itp.';
-$lang['htmlok']                = 'Wstawki HTML';
-$lang['phpok']                 = 'Wstawki PHP';
 $lang['dformat']               = 'Format daty';
 $lang['signature']             = 'Podpis';
+$lang['showuseras']            = 'Sposób wyświetlania nazwy użytkownika, który ostatnio edytował stronę';
 $lang['toptoclevel']           = 'Minimalny poziom spisu treści';
 $lang['tocminheads']           = 'Minimalna liczba nagłówków niezbędna do wytworzenia spisu treści.';
 $lang['maxtoclevel']           = 'Maksymalny poziom spisu treści';
@@ -69,16 +75,8 @@ $lang['maxseclevel']           = 'Maksymalny poziom podziału na sekcje edycyjne
 $lang['camelcase']             = 'Bikapitalizacja odnośników (CamelCase)';
 $lang['deaccent']              = 'Podmieniaj znaki spoza ASCII w nazwach';
 $lang['useheading']            = 'Pierwszy nagłówek jako tytuł';
-$lang['refcheck']              = 'Sprawdzanie odwołań przed usunięciem pliku';
-$lang['refshow']               = 'Ilość pokazywanych odwołań do pliku';
-$lang['allowdebug']            = 'Debugowanie (niebezpieczne!)';
-$lang['mediarevisions']        = 'Włączyć wersjonowanie multimediów?';
-$lang['usewordblock']          = 'Blokowanie spamu na podstawie słów';
-$lang['indexdelay']            = 'Okres indeksowania w sekundach';
-$lang['relnofollow']           = 'Nagłówek rel="nofollow" dla odnośników zewnętrznych';
-$lang['mailguard']             = 'Utrudnianie odczytu adresów e-mail';
-$lang['iexssprotect']          = 'Wykrywanie złośliwego kodu JavaScript i HTML w plikach';
-$lang['showuseras']            = 'Sposób wyświetlania nazwy użytkownika, który ostatnio edytował stronę';
+$lang['sneaky_index']          = 'Domyślnie, Dokuwiki pokazuje wszystkie katalogi w indeksie. Włączenie tej opcji ukryje katalogi, do których użytkownik nie ma praw. Może to spowodować ukrycie podkatalogów, do których użytkownik ma prawa. Ta opcja może spowodować błędne działanie indeksu w połączeniu z pewnymi konfiguracjami praw dostępu.';
+$lang['hidepages']             = 'Ukrywanie stron pasujących do wzorca (wyrażenie regularne)';
 $lang['useacl']                = 'Kontrola uprawnień ACL';
 $lang['autopasswd']            = 'Automatyczne generowanie haseł';
 $lang['authtype']              = 'Typ autoryzacji';
@@ -87,60 +85,70 @@ $lang['defaultgroup']          = 'Domyślna grupa';
 $lang['superuser']             = 'Administrator - grupa lub użytkownik z pełnymi uprawnieniami';
 $lang['manager']               = 'Menadżer - grupa lub użytkownik z uprawnieniami do zarządzania wiki';
 $lang['profileconfirm']        = 'Potwierdzanie zmiany profilu hasłem';
+$lang['rememberme']            = 'Pozwól na ciasteczka automatycznie logujące (pamiętaj mnie)';
 $lang['disableactions']        = 'Wyłącz akcje DokuWiki';
 $lang['disableactions_check']  = 'Sprawdzanie';
 $lang['disableactions_subscription'] = 'Subskrypcje';
 $lang['disableactions_wikicode'] = 'Pokazywanie źródeł';
 $lang['disableactions_other']  = 'Inne akcje (oddzielone przecinkiem)';
-$lang['sneaky_index']          = 'Domyślnie, Dokuwiki pokazuje wszystkie katalogi w indeksie. Włączenie tej opcji ukryje katalogi, do których użytkownik nie ma praw. Może to spowodować ukrycie podkatalogów, do których użytkownik ma prawa. Ta opcja może spowodować błędne działanie indeksu w połączeniu z pewnymi konfiguracjami praw dostępu.';
 $lang['auth_security_timeout'] = 'Czas wygaśnięcia uwierzytelnienia (w sekundach)';
 $lang['securecookie']          = 'Czy ciasteczka wysłane do przeglądarki przez HTTPS powinny być przez nią odsyłane też tylko przez HTTPS? Odznacz tę opcję tylko wtedy, gdy logowanie użytkowników jest zabezpieczone SSL, ale przeglądanie stron odbywa się bez zabezpieczenia.';
-$lang['xmlrpc']                = 'Włącz/wyłącz interfejs XML-RPC';
-$lang['xmlrpcuser']            = 'Lista użytkowników i grup, którzy mogą korzystać z protokołu XML-RPC. Nazwy grup i użytkowników rozdziel przecinkami, puste pole oznacza dostęp dla wszystkich.';
-$lang['updatecheck']           = 'Sprawdzanie aktualizacji i bezpieczeństwa. DokuWiki będzie kontaktować się z serwerem update.dokuwiki.org.';
-$lang['userewrite']            = 'Proste adresy URL';
-$lang['useslash']              = 'Używanie ukośnika jako separatora w adresie URL';
+$lang['remote']                = 'Włącz API zdalnego dostępu. Pozwoli to innym aplikacjom na dostęp do wiki poprzez XML-RPC lub inne mechanizmy.';
+$lang['remoteuser']            = 'Ogranicz dostęp poprzez API zdalnego dostępu do podanych grup lub użytkowników, oddzielonych przecinkami. Pozostaw to pole puste by pozwolić na dostęp be ograniczeń.';
+$lang['usewordblock']          = 'Blokowanie spamu na podstawie słów';
+$lang['relnofollow']           = 'Nagłówek rel="nofollow" dla odnośników zewnętrznych';
+$lang['indexdelay']            = 'Okres indeksowania w sekundach';
+$lang['mailguard']             = 'Utrudnianie odczytu adresów e-mail';
+$lang['iexssprotect']          = 'Wykrywanie złośliwego kodu JavaScript i HTML w plikach';
 $lang['usedraft']              = 'Automatyczne zapisywanie szkicu podczas edycji';
-$lang['sepchar']               = 'Znak rozdzielający wyrazy nazw';
-$lang['canonical']             = 'Kanoniczne adresy URL';
-$lang['fnencode']              = 'Metoda kodowana nazw pików bez użycia ASCII.';
-$lang['autoplural']            = 'Automatyczne tworzenie liczby mnogiej';
-$lang['compression']           = 'Metoda kompresji dla usuniętych plików';
-$lang['cachetime']             = 'Maksymalny wiek cache w sekundach';
+$lang['htmlok']                = 'Wstawki HTML';
+$lang['phpok']                 = 'Wstawki PHP';
 $lang['locktime']              = 'Maksymalny wiek blokad w sekundach';
-$lang['fetchsize']             = 'Maksymalny rozmiar pliku (w bajtach) jaki można pobrać z zewnątrz';
-$lang['notify']                = 'Wysyłanie powiadomień na adres e-mail';
-$lang['registernotify']        = 'Prześlij informacje o nowych użytkownikach na adres e-mail';
-$lang['mailfrom']              = 'Adres e-mail tego wiki';
-$lang['mailprefix']            = 'Prefiks tematu e-mail do automatycznych wiadomości';
-$lang['gzip_output']           = 'Używaj kodowania GZIP dla zawartości XHTML';
-$lang['gdlib']                 = 'Wersja biblioteki GDLib';
-$lang['im_convert']            = 'Ścieżka do programu imagemagick';
-$lang['jpg_quality']           = 'Jakość kompresji JPG (0-100)';
-$lang['subscribers']           = 'Subskrypcja';
-$lang['subscribe_time']        = 'Czas po którym są wysyłane listy subskrypcji i streszczenia (sek.); Powinna być to wartość większa niż podana w zmiennej recent_days.';
-$lang['compress']              = 'Kompresja arkuszy CSS i plików JavaScript';
-$lang['cssdatauri']            = 'Rozmiar w bajtach, poniżej którego odwołania do obrazów w plikach CSS powinny być osadzone bezpośrednio w arkuszu stylów by zmniejszyć ogólne żądania nagłówków HTTP. Technika ta nie działa w IE 7 i poniżej! <code>400</code> do <code>600</code> bajtów jest dobrą wartością. Ustaw <code>0</code> aby wyłączyć.';
-$lang['hidepages']             = 'Ukrywanie stron pasujących do wzorca (wyrażenie regularne)';
-$lang['send404']               = 'Nagłówek "HTTP 404/Page Not Found" dla nieistniejących stron';
-$lang['sitemap']               = 'Okres generowania Google Sitemap (w dniach)';
-$lang['broken_iua']            = 'Czy funkcja "ignore_user_abort" działa? Jeśli nie, może to powodować problemy z indeksem przeszukiwania. Funkcja nie działa przy konfiguracji oprogramowania IIS+PHP/CGI. Szczegółowe informacje: <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
-$lang['xsendfile']             = 'Użyj nagłówka HTTP X-Sendfile w celu przesyłania statycznych plików. Serwer HTTP musi obsługiwać ten nagłówek.';
-$lang['renderer_xhtml']        = 'Mechanizm renderowania głównej treści strony (xhtml)';
-$lang['renderer__core']        = '%s (dokuwiki)';
-$lang['renderer__plugin']      = '%s (wtyczka)';
-$lang['rememberme']            = 'Pozwól na ciasteczka automatycznie logujące (pamiętaj mnie)';
-$lang['rss_type']              = 'Typ RSS';
-$lang['rss_linkto']            = 'Odnośniki w RSS';
-$lang['rss_content']           = 'Rodzaj informacji wyświetlanych w RSS ';
-$lang['rss_update']            = 'Okres aktualizacji RSS (w sekundach)';
-$lang['recent_days']           = 'Ilość ostatnich zmian (w dniach)';
-$lang['rss_show_summary']      = 'Podsumowanie w tytule';
+$lang['cachetime']             = 'Maksymalny wiek cache w sekundach';
 $lang['target____wiki']        = 'Okno docelowe odnośników wewnętrznych';
 $lang['target____interwiki']   = 'Okno docelowe odnośników do innych wiki';
 $lang['target____extern']      = 'Okno docelowe odnośników zewnętrznych';
 $lang['target____media']       = 'Okno docelowe odnośników do plików';
 $lang['target____windows']     = 'Okno docelowe odnośników zasobów Windows';
+$lang['mediarevisions']        = 'Włączyć wersjonowanie multimediów?';
+$lang['refcheck']              = 'Sprawdzanie odwołań przed usunięciem pliku';
+$lang['refshow']               = 'Ilość pokazywanych odwołań do pliku';
+$lang['gdlib']                 = 'Wersja biblioteki GDLib';
+$lang['im_convert']            = 'Ścieżka do programu imagemagick';
+$lang['jpg_quality']           = 'Jakość kompresji JPG (0-100)';
+$lang['fetchsize']             = 'Maksymalny rozmiar pliku (w bajtach) jaki można pobrać z zewnątrz';
+$lang['subscribers']           = 'Subskrypcja';
+$lang['subscribe_time']        = 'Czas po którym są wysyłane listy subskrypcji i streszczenia (sek.); Powinna być to wartość większa niż podana w zmiennej recent_days.';
+$lang['notify']                = 'Wysyłanie powiadomień na adres e-mail';
+$lang['registernotify']        = 'Prześlij informacje o nowych użytkownikach na adres e-mail';
+$lang['mailfrom']              = 'Adres e-mail tego wiki';
+$lang['mailprefix']            = 'Prefiks tematu e-mail do automatycznych wiadomości';
+$lang['htmlmail']              = 'Wysyłaj wiadomości e-mail w formacie HTML, które wyglądają lepiej, lecz ich rozmiar jest większy. Wyłącz wysyłanie wiadomości zawierających tekst niesformatowany.';
+$lang['sitemap']               = 'Okres generowania Google Sitemap (w dniach)';
+$lang['rss_type']              = 'Typ RSS';
+$lang['rss_linkto']            = 'Odnośniki w RSS';
+$lang['rss_content']           = 'Rodzaj informacji wyświetlanych w RSS ';
+$lang['rss_update']            = 'Okres aktualizacji RSS (w sekundach)';
+$lang['rss_show_summary']      = 'Podsumowanie w tytule';
+$lang['rss_media']             = 'Rodzaj zmian wyświetlanych w RSS';
+$lang['updatecheck']           = 'Sprawdzanie aktualizacji i bezpieczeństwa. DokuWiki będzie kontaktować się z serwerem update.dokuwiki.org.';
+$lang['userewrite']            = 'Proste adresy URL';
+$lang['useslash']              = 'Używanie ukośnika jako separatora w adresie URL';
+$lang['sepchar']               = 'Znak rozdzielający wyrazy nazw';
+$lang['canonical']             = 'Kanoniczne adresy URL';
+$lang['fnencode']              = 'Metoda kodowana nazw pików bez użycia ASCII.';
+$lang['autoplural']            = 'Automatyczne tworzenie liczby mnogiej';
+$lang['compression']           = 'Metoda kompresji dla usuniętych plików';
+$lang['gzip_output']           = 'Używaj kodowania GZIP dla zawartości XHTML';
+$lang['compress']              = 'Kompresja arkuszy CSS i plików JavaScript';
+$lang['cssdatauri']            = 'Rozmiar w bajtach, poniżej którego odwołania do obrazów w plikach CSS powinny być osadzone bezpośrednio w arkuszu stylów by zmniejszyć ogólne żądania nagłówków HTTP. Technika ta nie działa w IE 7 i poniżej! <code>400</code> do <code>600</code> bajtów jest dobrą wartością. Ustaw <code>0</code> aby wyłączyć.';
+$lang['send404']               = 'Nagłówek "HTTP 404/Page Not Found" dla nieistniejących stron';
+$lang['broken_iua']            = 'Czy funkcja "ignore_user_abort" działa? Jeśli nie, może to powodować problemy z indeksem przeszukiwania. Funkcja nie działa przy konfiguracji oprogramowania IIS+PHP/CGI. Szczegółowe informacje: <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>.';
+$lang['xsendfile']             = 'Użyj nagłówka HTTP X-Sendfile w celu przesyłania statycznych plików. Serwer HTTP musi obsługiwać ten nagłówek.';
+$lang['renderer_xhtml']        = 'Mechanizm renderowania głównej treści strony (xhtml)';
+$lang['renderer__core']        = '%s (dokuwiki)';
+$lang['renderer__plugin']      = '%s (wtyczka)';
+$lang['dnslookups']            = 'DokiWiki wyszuka nazwy hostów dla zdalnych adresów IP użytkowników edytujących strony. Jeśli twój serwer DNS działa zbyt wolno, uległ awarii lub nie chcesz używać wyszukiwania, wyłącz tę opcję.';
 $lang['proxy____host']         = 'Proxy - serwer';
 $lang['proxy____port']         = 'Proxy - port';
 $lang['proxy____user']         = 'Proxy - nazwa użytkownika';
