@@ -39,33 +39,38 @@ $lang['_anti_spam']            = 'Configurações do anti-spam';
 $lang['_editing']              = 'Configurações de edição';
 $lang['_links']                = 'Configurações de link';
 $lang['_media']                = 'Configurações de mídia';
+$lang['_notifications']        = 'Configurações de notificação';
+$lang['_syndication']          = 'Configurações de sindicância';
 $lang['_advanced']             = 'Configurações avançadas';
 $lang['_network']              = 'Configurações de rede';
 $lang['_plugin_sufix']         = 'Configurações de plug-ins';
-$lang['_template_sufix']       = 'Configurações de modelos';
+$lang['_template_sufix']       = 'Configurações do modelo';
 $lang['_msg_setting_undefined'] = 'Nenhum metadado configurado.';
 $lang['_msg_setting_no_class'] = 'Nenhuma classe definida.';
 $lang['_msg_setting_no_default'] = 'Nenhum valor padrão.';
-$lang['fmode']                 = 'Modo de criação do arquivo';
-$lang['dmode']                 = 'Modo de criação do diretório';
+$lang['title']                 = 'Título do wiki';
+$lang['start']                 = 'Nome da página inicial';
 $lang['lang']                  = 'Idioma';
+$lang['template']              = 'Modelo, ou a aparência do wiki.';
+$lang['tagline']               = 'Slogan (caso o modelo suporte isso)';
+$lang['sidebar']               = 'Nome da página da barra lateral (caso o modelo suporte isso). Deixe em branco para desabilitar a barra lateral.';
+$lang['license']               = 'Sob qual licença o seu conteúdo deve ser disponibilizado?';
+$lang['savedir']               = 'Diretório para salvar os dados';
 $lang['basedir']               = 'Diretório base';
 $lang['baseurl']               = 'URL base';
-$lang['savedir']               = 'Diretório para salvar os dados';
 $lang['cookiedir']             = 'Caminhos dos cookies. Deixe em branco para usar a url base.';
-$lang['start']                 = 'Nome da página inicial';
-$lang['title']                 = 'Título do wiki';
-$lang['template']              = 'Modelo';
-$lang['license']               = 'Sob qual licença o seu conteúdo deve ser disponibilizado?';
-$lang['fullpath']              = 'Indica o caminho completo das páginas no rodapé';
+$lang['dmode']                 = 'Modo de criação do diretório';
+$lang['fmode']                 = 'Modo de criação do arquivo';
+$lang['allowdebug']            = 'Habilitar a depuração <b>(desabilite se não for necessário!)</b>';
 $lang['recent']                = 'Modificações recentes';
+$lang['recent_days']           = 'Quantas mudanças recentes devem ser mantidas (dias)?';
 $lang['breadcrumbs']           = 'Número de elementos na trilha de páginas visitadas';
 $lang['youarehere']            = 'Trilha hierárquica';
+$lang['fullpath']              = 'Indica o caminho completo das páginas no rodapé';
 $lang['typography']            = 'Efetuar modificações tipográficas';
-$lang['htmlok']                = 'Permitir incorporação de HTML';
-$lang['phpok']                 = 'Permitir incorporação de PHP';
 $lang['dformat']               = 'Formato da data (veja a função <a href="http://www.php.net/strftime">strftime</a> do PHP)';
 $lang['signature']             = 'Assinatura';
+$lang['showuseras']            = 'O que exibir quando mostrar o usuário que editou a página pela última vez';
 $lang['toptoclevel']           = 'Nível mais alto para a tabela de conteúdos';
 $lang['tocminheads']           = 'Quantidade mínima de cabeçalhos para a construção da tabela de conteúdos.';
 $lang['maxtoclevel']           = 'Nível máximo para entrar na tabela de conteúdos';
@@ -73,15 +78,8 @@ $lang['maxseclevel']           = 'Nível máximo para gerar uma seção de ediç
 $lang['camelcase']             = 'Usar CamelCase para links';
 $lang['deaccent']              = '"Limpar" os nomes das páginas';
 $lang['useheading']            = 'Usar o primeiro cabeçalho como nome da página';
-$lang['refcheck']              = 'Verificação de referência da mídia';
-$lang['refshow']               = 'Número de referências de mídia a exibir';
-$lang['allowdebug']            = 'Habilitar a depuração <b>(desabilite se não for necessário!)</b>';
-$lang['usewordblock']          = 'Bloquear spam baseado em lista de palavras';
-$lang['indexdelay']            = 'Tempo de espera antes da indexação (seg)';
-$lang['relnofollow']           = 'Usar rel="nofollow" em links externos';
-$lang['mailguard']             = 'Obscurecer endereços de e-mail';
-$lang['iexssprotect']          = 'Verificar a existência de possíveis códigos maliciosos em HTML ou JavaScript nos arquivos enviados';
-$lang['showuseras']            = 'O que exibir quando mostrar o usuário que editou a página pela última vez';
+$lang['sneaky_index']          = 'Por padrão, o DokuWiki irá exibir todos os espaços de nomes na visualização do índice. Ao habilitar essa opção, serão escondidos aqueles que o usuário não tiver permissão de leitura. Isso pode resultar na omissão de subespaços de nomes, tornando o índice inútil para certas configurações de ACL.';
+$lang['hidepages']             = 'Esconder páginas correspondentes (expressão regular)';
 $lang['useacl']                = 'Usar listas de controle de acesso';
 $lang['autopasswd']            = 'Gerar senhas automaticamente';
 $lang['authtype']              = 'Método de autenticação';
@@ -90,60 +88,70 @@ $lang['defaultgroup']          = 'Grupo padrão';
 $lang['superuser']             = 'Superusuário - um grupo, usuário ou uma lista separada por vírgulas (usuário1,@grupo1,usuário2) que tenha acesso completo a todas as páginas e funções, independente das definições da ACL';
 $lang['manager']               = 'Gerente - um grupo, usuário ou uma lista separada por vírgulas (usuário1,@grupo1,usuário2) que tenha acesso a certas funções de gerenciamento';
 $lang['profileconfirm']        = 'Confirmar mudanças no perfil com a senha';
+$lang['rememberme']            = 'Permitir cookies de autenticação permanentes ("Lembre-se de mim")';
 $lang['disableactions']        = 'Desabilitar as ações do DokuWiki';
 $lang['disableactions_check']  = 'Verificação';
 $lang['disableactions_subscription'] = 'Monitoramento';
 $lang['disableactions_wikicode'] = 'Ver a fonte/Exportar sem processamento';
 $lang['disableactions_other']  = 'Outras ações (separadas por vírgula)';
-$lang['sneaky_index']          = 'Por padrão, o DokuWiki irá exibir todos os espaços de nomes na visualização do índice. Ao habilitar essa opção, serão escondidos aqueles que o usuário não tiver permissão de leitura. Isso pode resultar na omissão de subespaços de nomes, tornando o índice inútil para certas configurações de ACL.';
 $lang['auth_security_timeout'] = 'Tempo limite de segurança para autenticações (seg)';
 $lang['securecookie']          = 'Os cookies definidos via HTTPS devem ser enviados para o navegador somente via HTTPS? Desabilite essa opção quando somente a autenticação do seu wiki for realizada de maneira segura via SSL e a navegação, de maneira insegura.';
-$lang['xmlrpc']                = 'Habilitar/desabilitar interface XML-RPC.';
-$lang['xmlrpcuser']            = 'Acesso Restrito ao XML-RPC para grupos separados por virgula ou usuários aqui. Deixe em branco para conveder acesso a todos.';
-$lang['updatecheck']           = 'Verificar atualizações e avisos de segurança? O DokuWiki precisa contactar o "splitbrain.org" para efetuar esse recurso.';
-$lang['userewrite']            = 'Usar URLs "limpas"';
-$lang['useslash']              = 'Usar a barra como separador de espaços de nomes nas URLs';
+$lang['remote']                = 'Habilitar o sistema de API remota. Isso permite que outras aplicações acessem o wiki via XML-RPC ou outros mecanismos.';
+$lang['remoteuser']            = 'Restringir o acesso à API remota aos grupos ou usuários definidos aqui (separados por vírgulas). Deixe em branco para permitir o acesso a qualquer um.';
+$lang['usewordblock']          = 'Bloquear spam baseado em lista de palavras';
+$lang['relnofollow']           = 'Usar rel="nofollow" em links externos';
+$lang['indexdelay']            = 'Tempo de espera antes da indexação (seg)';
+$lang['mailguard']             = 'Obscurecer endereços de e-mail';
+$lang['iexssprotect']          = 'Verificar a existência de possíveis códigos maliciosos em HTML ou JavaScript nos arquivos enviados';
 $lang['usedraft']              = 'Salvar o rascunho automaticamente durante a edição';
-$lang['sepchar']               = 'Separador de palavras no nome da página';
-$lang['canonical']             = 'Usar URLs absolutas (http://servidor/caminho)';
-$lang['fnencode']              = 'Método de codificação não-ASCII de nome de arquivos.';
-$lang['autoplural']            = 'Verificar formas plurais nos links';
-$lang['compression']           = 'Método de compressão para arquivos antigos';
-$lang['cachetime']             = 'Tempo máximo para o cache (seg)';
+$lang['htmlok']                = 'Permitir incorporação de HTML';
+$lang['phpok']                 = 'Permitir incorporação de PHP';
 $lang['locktime']              = 'Tempo máximo para o bloqueio de arquivos (seg)';
-$lang['fetchsize']             = 'Tamanho máximo (em bytes) que o "fetch.php" pode transferir do exterior';
-$lang['notify']                = 'Enviar notificações de mudança para esse endereço de e-mail';
-$lang['registernotify']        = 'Enviar informações de usuários registrados para esse endereço de e-mail';
-$lang['mailfrom']              = 'Endereço de e-mail a ser utilizado para mensagens automáticas';
-$lang['mailprefix']            = 'Prefixo do assunto dos e-mails de envio automático';
-$lang['gzip_output']           = 'Usar "Content-Encoding" do gzip para o código xhtml';
-$lang['gdlib']                 = 'Versão da biblioteca "GD Lib"';
-$lang['im_convert']            = 'Caminho para a ferramenta de conversão ImageMagick';
-$lang['jpg_quality']           = 'Qualidade de compressão do JPG (0-100)';
-$lang['subscribers']           = 'Habilitar o suporte ao monitoramento de páginas';
-$lang['subscribe_time']        = 'Tempo de espera antes do envio das listas e mensagens de monitoramento (segundos); este tempo deve ser menor que o especificado no parâmetro recent_days';
-$lang['compress']              = 'Compactar as saídas de CSS e JavaScript';
-$lang['cssdatauri']            = 'Tamanho máximo em bytes para o qual as imagens referenciadas em arquivos CSS devam ser incorporadas na folha de estilos (o arquivo CSS) para reduzir o custo dos pedidos HTTP. Essa técnica não funcionará na versões do IE < 8!  Valores de <code>400</code> a <code>600</code> são bons. Defina o valor <code>0</code> para desativar.';
-$lang['hidepages']             = 'Esconder páginas correspondentes (expressão regular)';
-$lang['send404']               = 'Enviar "HTTP 404/Página não encontrada" para páginas não existentes';
-$lang['sitemap']               = 'Gerar Google Sitemap (dias)';
-$lang['broken_iua']            = 'A função "ignore_user_abort" está com defeito no seu sistema? Isso pode causar um índice de busca defeituoso. IIS+PHP/CGI reconhecidamente possui esse erro. Veja o <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">bug 852</a> para mais informações.';
-$lang['xsendfile']             = 'Usar o cabeçalho "X-Sendfile" para permitir que o servidor web encaminhe arquivos estáticos? Seu servidor web precisa ter suporte a isso.';
-$lang['renderer_xhtml']        = 'Renderizador a ser utilizado para a saída principal (xhtml) do wiki';
-$lang['renderer__core']        = '%s (núcleo do DokuWiki)';
-$lang['renderer__plugin']      = '%s ("plug-in")';
-$lang['rememberme']            = 'Permitir cookies de autenticação permanentes ("Lembre-se de mim")';
-$lang['rss_type']              = 'Tipo de fonte XML';
-$lang['rss_linkto']            = 'Os links da fonte XML apontam para';
-$lang['rss_content']           = 'O que deve ser exibido nos itens da fonte XML?';
-$lang['rss_update']            = 'Intervalo de atualização da fonte XML (seg)';
-$lang['recent_days']           = 'Quantas mudanças recentes devem ser mantidas (dias)?';
-$lang['rss_show_summary']      = 'Resumo de exibição da fonte XML no título';
+$lang['cachetime']             = 'Tempo máximo para o cache (seg)';
 $lang['target____wiki']        = 'Parâmetro "target" para links internos';
 $lang['target____interwiki']   = 'Parâmetro "target" para links interwiki';
 $lang['target____extern']      = 'Parâmetro "target" para links externos';
 $lang['target____media']       = 'Parâmetro "target" para links de mídia';
 $lang['target____windows']     = 'Parâmetro "target" para links do Windows';
+$lang['mediarevisions']        = 'Habilitar revisões de mídias?';
+$lang['refcheck']              = 'Verificação de referência da mídia';
+$lang['refshow']               = 'Número de referências de mídia a exibir';
+$lang['gdlib']                 = 'Versão da biblioteca "GD Lib"';
+$lang['im_convert']            = 'Caminho para a ferramenta de conversão ImageMagick';
+$lang['jpg_quality']           = 'Qualidade de compressão do JPG (0-100)';
+$lang['fetchsize']             = 'Tamanho máximo (em bytes) que o "fetch.php" pode transferir do exterior';
+$lang['subscribers']           = 'Habilitar o suporte ao monitoramento de páginas';
+$lang['subscribe_time']        = 'Tempo de espera antes do envio das listas e mensagens de monitoramento (segundos); este tempo deve ser menor que o especificado no parâmetro recent_days';
+$lang['notify']                = 'Enviar notificações de mudança para esse endereço de e-mail';
+$lang['registernotify']        = 'Enviar informações de usuários registrados para esse endereço de e-mail';
+$lang['mailfrom']              = 'Endereço de e-mail a ser utilizado para mensagens automáticas';
+$lang['mailprefix']            = 'Prefixo do assunto dos e-mails de envio automático';
+$lang['htmlmail']              = 'Enviar e-mail HTML multipartes, que têm uma aparência melhor, mas um tamanho maior. Desabilite para enviar e-mails em texto puro.';
+$lang['sitemap']               = 'Gerar Google Sitemap (dias)';
+$lang['rss_type']              = 'Tipo de fonte XML';
+$lang['rss_linkto']            = 'Os links da fonte XML apontam para';
+$lang['rss_content']           = 'O que deve ser exibido nos itens da fonte XML?';
+$lang['rss_update']            = 'Intervalo de atualização da fonte XML (seg)';
+$lang['rss_show_summary']      = 'Resumo de exibição da fonte XML no título';
+$lang['rss_media']             = 'Que tipo de alterações devem ser listadas na fonte XML?';
+$lang['updatecheck']           = 'Verificar atualizações e avisos de segurança? O DokuWiki precisa contactar o "splitbrain.org" para efetuar esse recurso.';
+$lang['userewrite']            = 'Usar URLs "limpas"';
+$lang['useslash']              = 'Usar a barra como separador de espaços de nomes nas URLs';
+$lang['sepchar']               = 'Separador de palavras no nome da página';
+$lang['canonical']             = 'Usar URLs absolutas (http://servidor/caminho)';
+$lang['fnencode']              = 'Método de codificação não-ASCII de nome de arquivos.';
+$lang['autoplural']            = 'Verificar formas plurais nos links';
+$lang['compression']           = 'Método de compressão para arquivos antigos';
+$lang['gzip_output']           = 'Usar "Content-Encoding" do gzip para o código xhtml';
+$lang['compress']              = 'Compactar as saídas de CSS e JavaScript';
+$lang['cssdatauri']            = 'Tamanho máximo em bytes para o qual as imagens referenciadas em arquivos CSS devam ser incorporadas na folha de estilos (o arquivo CSS) para reduzir o custo dos pedidos HTTP. Essa técnica não funcionará na versões do IE < 8!  Valores de <code>400</code> a <code>600</code> são bons. Defina o valor <code>0</code> para desativar.';
+$lang['send404']               = 'Enviar "HTTP 404/Página não encontrada" para páginas não existentes';
+$lang['broken_iua']            = 'A função "ignore_user_abort" está com defeito no seu sistema? Isso pode causar um índice de busca defeituoso. IIS+PHP/CGI reconhecidamente possui esse erro. Veja o <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">bug 852</a> para mais informações.';
+$lang['xsendfile']             = 'Usar o cabeçalho "X-Sendfile" para permitir que o servidor web encaminhe arquivos estáticos? Seu servidor web precisa ter suporte a isso.';
+$lang['renderer_xhtml']        = 'Renderizador a ser utilizado para a saída principal (xhtml) do wiki';
+$lang['renderer__core']        = '%s (núcleo do DokuWiki)';
+$lang['renderer__plugin']      = '%s ("plug-in")';
+$lang['dnslookups']            = 'O DokuWiki procurará pelo nome de host dos endereços IP remotos dos usuários que estão editando as páginas. Caso você tenha um DNS lento, ele não esteja funcionando ou, ainda, você não queira esse recurso, desabilite essa opção.';
 $lang['proxy____host']         = 'Nome do servidor proxy';
 $lang['proxy____port']         = 'Porta do proxy';
 $lang['proxy____user']         = 'Nome de usuário do proxy';
