@@ -11,54 +11,56 @@
  * @author Ulrikhe Lukoie  <lukoie@gmail>.com
  * @author Kate Arzamastseva pshns@ukr.net
  */
-$lang['menu']                  = 'Настройка конфігурації';
+$lang['menu']                  = 'Налаштування Вікі';
 $lang['error']                 = 'Параметри не збережено через помилкові значення. Будь ласка, перегляньте ваші зміни та спробуйте ще раз
 <br />Помилкові значення будуть виділені червоною рамкою.';
 $lang['updated']               = 'Параметри успішно збережено.';
 $lang['nochoice']              = '(інших варіантів не існує)';
-$lang['locked']                = 'Неможливо записати файл настройки. Переконайтеся, <br />
+$lang['locked']                = 'Неможливо записати файл налаштувань. Переконайтеся, <br />
 що ім\'я та права доступу для локального файлу вказано правильно.';
 $lang['danger']                = 'УВАГА! Зміна цього параметру може призвести до недоступності вашої Вікі та меню конфігурації.';
 $lang['warning']               = 'УВАГА! Зміна цього параметру може призвести до непередбачуваних наслідків.';
 $lang['security']              = 'УВАГА! Зміна цього параметру може призвести до послаблення безпеки вашої Вікі.';
 $lang['_configuration_manager'] = 'Управління конфігурацією';
-$lang['_header_dokuwiki']      = 'Настройки ДокуВікі';
-$lang['_header_plugin']        = 'Настройки Доданків';
-$lang['_header_template']      = 'Настройки шаблонів';
-$lang['_header_undefined']     = 'Невизначені настройки';
-$lang['_basic']                = 'Базові настройки';
-$lang['_display']              = 'Настройки дисплея';
-$lang['_authentication']       = 'Настройки автентифікації';
-$lang['_anti_spam']            = 'Настройки Анти-спаму';
-$lang['_editing']              = 'Настройки редагування';
-$lang['_links']                = 'Настройки посилань';
-$lang['_media']                = 'Настройки медіа';
-$lang['_advanced']             = 'Розширені настройки';
-$lang['_network']              = 'Настройки мережі';
-$lang['_plugin_sufix']         = 'Настройки (доданок)';
-$lang['_template_sufix']       = 'Настройки (шаблон)';
+$lang['_header_dokuwiki']      = 'Налаштування ДокуВікі';
+$lang['_header_plugin']        = 'Налаштування Доданків';
+$lang['_header_template']      = 'Налаштування шаблонів';
+$lang['_header_undefined']     = 'Невизначені налаштування';
+$lang['_basic']                = 'Базові налаштування';
+$lang['_display']              = 'Налаштування відображення';
+$lang['_authentication']       = 'Налаштування автентифікації';
+$lang['_anti_spam']            = 'Налаштування Анти-спаму';
+$lang['_editing']              = 'Налаштування редагування';
+$lang['_links']                = 'Налаштування посилань';
+$lang['_media']                = 'Налаштування медіа';
+$lang['_notifications']        = 'Налаштування сповіщень';
+$lang['_advanced']             = 'Розширені налаштування';
+$lang['_network']              = 'Налаштування мережі';
+$lang['_plugin_sufix']         = 'Налаштування (доданок)';
+$lang['_template_sufix']       = 'Налаштування (шаблон)';
 $lang['_msg_setting_undefined'] = 'Немає метаданих параметру.';
 $lang['_msg_setting_no_class'] = 'Немає класу параметру.';
 $lang['_msg_setting_no_default'] = 'Немає значення за замовчуванням.';
-$lang['fmode']                 = 'Права для створених файлів';
-$lang['dmode']                 = 'Права для створених папок';
-$lang['lang']                  = 'Мова';
-$lang['basedir']               = 'Коренева папка';
-$lang['baseurl']               = 'Кореневий URL';
-$lang['savedir']               = 'Папка для збереження даних';
-$lang['start']                 = 'Назва стартової сторінки';
 $lang['title']                 = 'Назва Вікі';
+$lang['start']                 = 'Назва стартової сторінки';
+$lang['lang']                  = 'Мова';
 $lang['template']              = 'Шаблон';
 $lang['license']               = 'Під якою ліцензією слід публікувати вміст?';
-$lang['fullpath']              = 'Повний шлях до документу';
+$lang['savedir']               = 'Папка для збереження даних';
+$lang['basedir']               = 'Коренева папка';
+$lang['baseurl']               = 'Кореневий URL';
+$lang['dmode']                 = 'Права для створених папок';
+$lang['fmode']                 = 'Права для створених файлів';
+$lang['allowdebug']            = 'Дозволити відлагодження <b>вимкніть, якщо не потрібно!</b>';
 $lang['recent']                = 'Останні зміни';
+$lang['recent_days']           = 'Скільки останніх змін пам\'ятати (дні)';
 $lang['breadcrumbs']           = 'Ви відвідали (кількість сторінок, що показується)';
 $lang['youarehere']            = 'Показувати "Ви тут"';
+$lang['fullpath']              = 'Повний шлях до документу';
 $lang['typography']            = 'Замінювати типографські символи';
-$lang['htmlok']                = 'Дозволити HTML';
-$lang['phpok']                 = 'Дозволити PHP';
 $lang['dformat']               = 'Формат дати (дивіться функцію <a href="http://www.php.net/strftime">strftime</a> PHP)';
 $lang['signature']             = 'Підпис';
+$lang['showuseras']            = 'Що вказувати при відображенні користувача, який востаннє редагував сторінку';
 $lang['toptoclevel']           = 'Мінімальний рівень для змісту';
 $lang['tocminheads']           = 'Мінімальна кількість заголовків, необхідна для створення таблиці змісту';
 $lang['maxtoclevel']           = 'Максимальний рівень для таблиці змісту';
@@ -66,15 +68,8 @@ $lang['maxseclevel']           = 'Максимальний рівень секц
 $lang['camelcase']             = 'Використовувати CamelCase';
 $lang['deaccent']              = 'Транслітерація в іменах сторінок';
 $lang['useheading']            = 'Першій заголовок замість імені';
-$lang['refcheck']              = 'Перевіряти посилання на медіа-файлі';
-$lang['refshow']               = 'Показувати кількість медіа-посилань';
-$lang['allowdebug']            = 'Дозволити відлагодження <b>вимкніть, якщо не потрібно!</b>';
-$lang['usewordblock']          = 'Блокувати спам по списку слів';
-$lang['indexdelay']            = 'Затримка перед індексацією';
-$lang['relnofollow']           = 'Використовувати rel="nofollow"';
-$lang['mailguard']             = 'Кодувати адреси e-mail';
-$lang['iexssprotect']          = 'Перевірте оновлені файли на можливі заборонені Javascript чи HTML коди';
-$lang['showuseras']            = 'Що вказувати при відображенні користувача, який востаннє редагував сторінку';
+$lang['sneaky_index']          = 'За замовчуванням, ДокуВікі показує всі простори імен в змісті. Активація цієї опції сховає ті простори, де користувач не має прав на читання. Результатом може бути неможливість доступу до певних відкритих просторів імен. Це зробить неможливим використання змісту при певних конфігураціях.';
+$lang['hidepages']             = 'Ховати сторінки (regular expressions)';
 $lang['useacl']                = 'Використовувати ACL';
 $lang['autopasswd']            = 'Автоматичне створення паролів';
 $lang['authtype']              = 'Аутентифікація';
@@ -83,59 +78,63 @@ $lang['defaultgroup']          = 'Група за замовчуванням';
 $lang['superuser']             = 'Суперкористувач';
 $lang['manager']               = 'Менеджер - група, користувач чи розділений комами список user1,@group1,user2 з правами до певних функцій керування';
 $lang['profileconfirm']        = 'Підтверджувати зміни профілю паролем';
+$lang['rememberme']            = 'Дозволити постійні файли cookies для входу (Запам\'ятати мене)';
 $lang['disableactions']        = 'Заборонити дії ДокуВікі';
 $lang['disableactions_check']  = 'Перевірити';
 $lang['disableactions_subscription'] = 'Підписатись/Відписатись';
 $lang['disableactions_wikicode'] = 'Переглянути код/Експорт';
 $lang['disableactions_other']  = 'Інші дії (розділені комами)';
-$lang['sneaky_index']          = 'За замовчуванням, ДокуВікі показує всі простори імен в змісті. Активація цієї опції сховає ті простори, де користувач не має прав на читання. Результатом може бути неможливість доступу до певних відкритих просторів імен. Це зробить неможливим використання змісту при певних конфігураціях.';
 $lang['auth_security_timeout'] = 'Таймаут аутентифікації (в секундах)';
 $lang['securecookie']          = 'Чи повинен браузер надсилати файли cookies тільки через HTTPS? Вимкніть цей параметр, лише тоді, якщо вхід до Вікі захищено SSL, але перегляд сторінок відбувається у незахищеному режимі.';
-$lang['xmlrpc']                = 'Дозволити/заборонити XML-RPC інтерфейс';
-$lang['xmlrpcuser']            = 'Заборонити XML-RPC доступ до користувачів або груп поданих тут та розділених комою. Залишіть поле незаповненим, щоб дозволити доступ усім.';
-$lang['updatecheck']           = 'Перевірити наявність оновлень чи попереджень безпеки? Для цього ДокуВікі необхідно зв\'язатися зі update.dokuwiki.org.';
-$lang['userewrite']            = 'Красиві URL';
-$lang['useslash']              = 'Слеш, як розділювач просторів імен в URL';
+$lang['usewordblock']          = 'Блокувати спам по списку слів';
+$lang['relnofollow']           = 'Використовувати rel="nofollow"';
+$lang['indexdelay']            = 'Затримка перед індексацією';
+$lang['mailguard']             = 'Кодувати адреси e-mail';
+$lang['iexssprotect']          = 'Перевірте оновлені файли на можливі заборонені Javascript чи HTML коди';
 $lang['usedraft']              = 'Автоматично зберігати чернетку при редагуванні';
-$lang['sepchar']               = 'Розділювач слів у імені сторінки';
-$lang['canonical']             = 'Канонічні URL';
-$lang['fnencode']              = 'Метод для кодування імен файлів, що містять не ASCII символи.';
-$lang['autoplural']            = 'Перевіряти множину у посиланнях';
-$lang['compression']           = 'Метод стиснення attic файлів';
-$lang['cachetime']             = 'Максимальний вік кешу (сек)';
+$lang['htmlok']                = 'Дозволити HTML';
+$lang['phpok']                 = 'Дозволити PHP';
 $lang['locktime']              = 'Час блокування (сек)';
-$lang['fetchsize']             = 'Максимальний розмір (в байтах), що fetch.php може завантажувати з зовні';
-$lang['notify']                = 'E-mail для сповіщень';
-$lang['registernotify']        = 'Надсилати інформацію про нових користувачів на цю адресу';
-$lang['mailfrom']              = 'E-mail для автоматичних повідомлень';
-$lang['mailprefix']            = 'Префікс теми повідомлення, що використовується в автоматичній розсилці електронних листів';
-$lang['gzip_output']           = 'Використовувати gzip, як Content-Encoding для xhtml';
-$lang['gdlib']                 = 'Версія GD Lib';
-$lang['im_convert']            = 'Шлях до ImageMagick';
-$lang['jpg_quality']           = 'Якість компресії JPG (0-100)';
-$lang['subscribers']           = 'Підписка на зміни';
-$lang['subscribe_time']        = 'Час, після якого список підписки та дайджести будуть надіслані (сек.); Має бути меншим за час, вказаний у перемінній recent_days';
-$lang['compress']              = 'Стискати файли CSS та javascript';
-$lang['hidepages']             = 'Ховати сторінки (regular expressions)';
-$lang['send404']               = 'Надсилати "HTTP 404/Сторінка не знайдена " для неіснуючих сторінок';
-$lang['sitemap']               = 'Створювати мапу сайту для Google (дні)';
-$lang['broken_iua']            = 'У вашій системі зіпсована функція ignore_user_abort? Це може зіпсувати пошукову систему. IIS+PHP/CGI не працює. Дивіться <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> для отримання додаткової інформації';
-$lang['xsendfile']             = 'Використовувати заголовок X-Sendfile для доставки статичних файлів веб сервером? Ваш веб сервер повинен підтримувати цю функцію.';
-$lang['renderer_xhtml']        = 'Транслятор (Renderer) для основного виводу wiki (xhtml)';
-$lang['renderer__core']        = '%s (ядро докуВікі)';
-$lang['renderer__plugin']      = '%s (доданок)';
-$lang['rememberme']            = 'Дозволити постійні файли cookies для входу (Запам\'ятати мене)';
-$lang['rss_type']              = 'тип RSS';
-$lang['rss_linkto']            = 'посилання в RSS';
-$lang['rss_content']           = 'Що відображати в пунктах XML-feed';
-$lang['rss_update']            = 'Інтервал оновлення RSS (сек)';
-$lang['recent_days']           = 'Скільки останніх змін пам\'ятати (дні)';
-$lang['rss_show_summary']      = 'Показувати підсумки змін в заголовку XML-feed';
+$lang['cachetime']             = 'Максимальний вік кешу (сек)';
 $lang['target____wiki']        = 'Target для внутрішніх посилань';
 $lang['target____interwiki']   = 'Target для інтерВікі-посилань';
 $lang['target____extern']      = 'Target для зовнішніх посилань';
 $lang['target____media']       = 'Target для медіа-посилань';
 $lang['target____windows']     = 'Target для посилань на мережеві папки';
+$lang['refcheck']              = 'Перевіряти посилання на медіа-файлі';
+$lang['refshow']               = 'Показувати кількість медіа-посилань';
+$lang['gdlib']                 = 'Версія GD Lib';
+$lang['im_convert']            = 'Шлях до ImageMagick';
+$lang['jpg_quality']           = 'Якість компресії JPG (0-100)';
+$lang['fetchsize']             = 'Максимальний розмір (в байтах), що fetch.php може завантажувати з зовні';
+$lang['subscribers']           = 'Підписка на зміни';
+$lang['subscribe_time']        = 'Час, після якого список підписки та дайджести будуть надіслані (сек.); Має бути меншим за час, вказаний у перемінній recent_days';
+$lang['notify']                = 'E-mail для сповіщень';
+$lang['registernotify']        = 'Надсилати інформацію про нових користувачів на цю адресу';
+$lang['mailfrom']              = 'E-mail для автоматичних повідомлень';
+$lang['mailprefix']            = 'Префікс теми повідомлення, що використовується в автоматичній розсилці електронних листів';
+$lang['sitemap']               = 'Створювати мапу сайту для Google (дні)';
+$lang['rss_type']              = 'тип RSS';
+$lang['rss_linkto']            = 'посилання в RSS';
+$lang['rss_content']           = 'Що відображати в пунктах XML-feed';
+$lang['rss_update']            = 'Інтервал оновлення RSS (сек)';
+$lang['rss_show_summary']      = 'Показувати підсумки змін в заголовку XML-feed';
+$lang['updatecheck']           = 'Перевірити наявність оновлень чи попереджень безпеки? Для цього ДокуВікі необхідно зв\'язатися зі update.dokuwiki.org.';
+$lang['userewrite']            = 'Красиві URL';
+$lang['useslash']              = 'Слеш, як розділювач просторів імен в URL';
+$lang['sepchar']               = 'Розділювач слів у імені сторінки';
+$lang['canonical']             = 'Канонічні URL';
+$lang['fnencode']              = 'Метод для кодування імен файлів, що містять не ASCII символи.';
+$lang['autoplural']            = 'Перевіряти множину у посиланнях';
+$lang['compression']           = 'Метод стиснення attic файлів';
+$lang['gzip_output']           = 'Використовувати gzip, як Content-Encoding для xhtml';
+$lang['compress']              = 'Стискати файли CSS та javascript';
+$lang['send404']               = 'Надсилати "HTTP 404/Сторінка не знайдена " для неіснуючих сторінок';
+$lang['broken_iua']            = 'У вашій системі зіпсована функція ignore_user_abort? Це може зіпсувати пошукову систему. IIS+PHP/CGI не працює. Дивіться <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> для отримання додаткової інформації';
+$lang['xsendfile']             = 'Використовувати заголовок X-Sendfile для доставки статичних файлів веб сервером? Ваш веб сервер повинен підтримувати цю функцію.';
+$lang['renderer_xhtml']        = 'Транслятор (Renderer) для основного виводу wiki (xhtml)';
+$lang['renderer__core']        = '%s (ядро докуВікі)';
+$lang['renderer__plugin']      = '%s (доданок)';
 $lang['proxy____host']         = 'Адреса Proxy';
 $lang['proxy____port']         = 'Порт Proxy';
 $lang['proxy____user']         = 'Користувач Proxy';
@@ -183,7 +182,7 @@ $lang['xsendfile_o_2']         = 'Стандартний X-Sendfile заголо
 $lang['xsendfile_o_3']         = 'Фірмовий заголовок Nginx X-Accel-Redirect';
 $lang['showuseras_o_loginname'] = 'Логін';
 $lang['showuseras_o_username'] = 'Повне ім’я користувача';
-$lang['showuseras_o_email']    = 'E-mail користувача (прихована відповідно до настройок)';
+$lang['showuseras_o_email']    = 'E-mail користувача (прихована відповідно до налаштувань)';
 $lang['showuseras_o_email_link'] = 'E-mail користувача як посилання mailto:';
 $lang['useheading_o_0']        = 'Ніколи';
 $lang['useheading_o_navigation'] = 'Лише для навігації';
