@@ -9,17 +9,18 @@
  * @author Cheng-Wei Chien <e.cwchien@gmail.com>
  * @author Danny Lin
  * @author Shuo-Ting Jian <shoting@gmail.com>
+ * @author syaoranhinata@gmail.com
  */
-$lang['menu']                  = '系統配置設定';
+$lang['menu']                  = '系統設定';
 $lang['error']                 = '設定因為不合法的值而未更新，請檢查您的更改並重新送出。
 <br />不正確的值會被紅色方框包住。';
 $lang['updated']               = '成功地更新設定。';
 $lang['nochoice']              = '(無其他可用選項)';
 $lang['locked']                = '設定檔無法更新，若非故意，請確認本地檔名及權限正確。';
-$lang['danger']                = '危險：改變此選項可能使您無法存取維基及配置選單。';
+$lang['danger']                = '危險：改變此選項可能使您無法存取維基及設定選單。';
 $lang['warning']               = '警告：改變此選項可能導致不可預期的行為。';
 $lang['security']              = '安全性警告：改變此選項可能造成安全風險。';
-$lang['_configuration_manager'] = '配置管理';
+$lang['_configuration_manager'] = '設定管理器';
 $lang['_header_dokuwiki']      = 'DokuWiki 設定';
 $lang['_header_plugin']        = '插件設定';
 $lang['_header_template']      = '樣板設定';
@@ -38,26 +39,27 @@ $lang['_template_sufix']       = '樣板設定';
 $lang['_msg_setting_undefined'] = '設定的後設數據不存在。';
 $lang['_msg_setting_no_class'] = '設定的分類不存在。';
 $lang['_msg_setting_no_default'] = '無預設值';
-$lang['fmode']                 = '檔案建立模式';
-$lang['dmode']                 = '目錄建立模式';
-$lang['lang']                  = '語系';
-$lang['basedir']               = '根目錄';
-$lang['baseurl']               = '根路徑 (URL)';
-$lang['savedir']               = '儲存資料的目錄';
-$lang['cookiedir']             = 'Cookie 路徑。設定空白則使用 baseurl。';
-$lang['start']                 = '開始頁面的名稱';
 $lang['title']                 = '維基標題';
+$lang['start']                 = '開始頁面的名稱';
+$lang['lang']                  = '語系';
 $lang['template']              = '樣板';
 $lang['license']               = '您希望您的內容為何種授權方式？';
-$lang['fullpath']              = '顯示完整的路徑於頁面底部';
+$lang['savedir']               = '儲存資料的目錄';
+$lang['basedir']               = '根目錄';
+$lang['baseurl']               = '根路徑 (URL)';
+$lang['cookiedir']             = 'Cookie 路徑。設定空白則使用 baseurl。';
+$lang['dmode']                 = '目錄建立模式';
+$lang['fmode']                 = '檔案建立模式';
+$lang['allowdebug']            = '允許除錯 <b>(不需要請停用！)</b>';
 $lang['recent']                = '最近更新';
+$lang['recent_days']           = '儲存多少天內的變更';
 $lang['breadcrumbs']           = '導覽鏈數量';
 $lang['youarehere']            = '顯示階層式導覽鏈';
+$lang['fullpath']              = '顯示完整的路徑於頁面底部';
 $lang['typography']            = '進行字元替換';
-$lang['htmlok']                = '允許嵌入式 HTML';
-$lang['phpok']                 = '允許嵌入式 PHP';
 $lang['dformat']               = '日期格式 (參見 PHP 的 <a href="http://www.php.net/strftime">strftime</a> 函數)';
 $lang['signature']             = '簽名';
+$lang['showuseras']            = '將最後編輯頁面的使用者顯示為：';
 $lang['toptoclevel']           = '目錄表的最上層級';
 $lang['tocminheads']           = '決定是否建立目錄表的最少標題數量';
 $lang['maxtoclevel']           = '目錄表顯示的最大層級';
@@ -65,15 +67,8 @@ $lang['maxseclevel']           = '可編輯段落的最大層級';
 $lang['camelcase']             = '對連結使用 CamelCase';
 $lang['deaccent']              = '清理頁面名稱';
 $lang['useheading']            = '使用第一個標題作為頁面名稱';
-$lang['refcheck']              = '媒體連結檢查';
-$lang['refshow']               = '媒體連結的顯示數量';
-$lang['allowdebug']            = '允許除錯 <b>(不需要請停用！)</b>';
-$lang['usewordblock']          = '根據字詞表阻擋垃圾訊息';
-$lang['indexdelay']            = '建立索引前的延遲時間 (秒)';
-$lang['relnofollow']           = '外部連結使用 rel="nofollow"';
-$lang['mailguard']             = '混淆 E-mail 位址';
-$lang['iexssprotect']          = '檢查上傳的檔案中是否隱含惡意的 JavaScript 或 HTML 碼';
-$lang['showuseras']            = '將最後編輯頁面的使用者顯示為：';
+$lang['sneaky_index']          = '預設情況下，DokuWiki 會在索引頁會顯示所有分類空間。啟用此選項會隱藏用戶沒有閱讀權限的頁面，但也可能將能閱讀的子頁面一併隱藏。在特定 ACL 設定下，這可能導致索引無法使用。';
+$lang['hidepages']             = '隱藏匹配的界面 (正規式)';
 $lang['useacl']                = '使用存取控制名單';
 $lang['autopasswd']            = '自動產生密碼';
 $lang['authtype']              = '認證後台管理方式';
@@ -82,60 +77,65 @@ $lang['defaultgroup']          = '預設群組';
 $lang['superuser']             = '超級用戶 - 不論 ACL 如何設定，都能訪問所有頁面與功能的用戶組/用戶';
 $lang['manager']               = '管理員 - 能訪問相應管理功能的用戶组/用戶';
 $lang['profileconfirm']        = '修改個人資料時需要確認密碼';
+$lang['rememberme']            = '允許自動登入 (記住我)';
 $lang['disableactions']        = '停用的 DokuWiki 動作';
 $lang['disableactions_check']  = '檢查';
 $lang['disableactions_subscription'] = '訂閱/取消訂閱';
 $lang['disableactions_wikicode'] = '檢視原始碼/匯出原始檔';
 $lang['disableactions_other']  = '其他功能 (逗號分隔)';
-$lang['sneaky_index']          = '預設情況下，DokuWiki 會在索引頁會顯示所有命名空間。啟用此選項會隱藏用戶沒有閱讀權限的頁面，但也可能將能閱讀的子頁面一併隱藏。在特定 ACL 設定下，這可能導致索引無法使用。';
 $lang['auth_security_timeout'] = '安全認證的計時 (秒)';
 $lang['securecookie']          = 'HTTPS 頁面設定的 cookie 是否只能由瀏覽器經 HTTPS 傳送？取消此選項後，只有登入維基會被 SSL 保護而瀏覽時不會。';
-$lang['xmlrpc']                = '啟用/停用 XML-RPC 介面';
-$lang['xmlrpcuser']            = 'XML-RPC 存取權限將局限於在此提供的群組或使用者 (逗號分隔)。若要開放權限給所有人請留白。';
-$lang['updatecheck']           = '檢查更新與安全性警告？DokuWiki 需要聯繫 update.dokuwiki.org 才能使用此功能。';
-$lang['userewrite']            = '使用好看的 URL';
-$lang['useslash']              = '在 URL 中使用斜線作為命名空間的分隔字元';
+$lang['usewordblock']          = '根據字詞表阻擋垃圾訊息';
+$lang['relnofollow']           = '外部連結使用 rel="nofollow"';
+$lang['indexdelay']            = '建立索引前的延遲時間 (秒)';
+$lang['mailguard']             = '混淆 E-mail 位址';
+$lang['iexssprotect']          = '檢查上傳的檔案中是否隱含惡意的 JavaScript 或 HTML 碼';
 $lang['usedraft']              = '編輯時自動儲存草稿';
-$lang['sepchar']               = '頁面名稱中單字的分隔字元';
-$lang['canonical']             = '使用最典型的 URL';
-$lang['fnencode']              = '非 ASCII 文件名稱的編輯方法。';
-$lang['autoplural']            = '檢查複數形式的連結 (英文)';
-$lang['compression']           = 'attic 文件的壓縮方式';
-$lang['cachetime']             = '緩存的最大存在時間 (秒)';
+$lang['htmlok']                = '允許嵌入式 HTML';
+$lang['phpok']                 = '允許嵌入式 PHP';
 $lang['locktime']              = '檔案的最大鎖定時間 (秒)';
-$lang['fetchsize']             = 'fetch.php 可以從外部下載的最大檔案尺寸 (bytes)';
-$lang['notify']                = '寄送變更通知信到這個 E-mail 位址';
-$lang['registernotify']        = '寄送新使用者註冊資訊到這個 E-mail 位址';
-$lang['mailfrom']              = '自動發送郵件時使用的郵件地址';
-$lang['mailprefix']            = '自動發送郵件時使用的標題前綴';
-$lang['gzip_output']           = '對 xhtml 使用 gzip 內容編碼';
-$lang['gdlib']                 = 'GD Lib 版本';
-$lang['im_convert']            = 'ImageMagick 的轉換工具路徑';
-$lang['jpg_quality']           = 'JPG 壓縮品質(0-100)';
-$lang['subscribers']           = '啟用頁面訂閱';
-$lang['subscribe_time']        = '訂閱列表和摘要發送的時間間隔 (秒)；這個值應該小於指定的最近更改保留時間 (recent_days)。';
-$lang['compress']              = '壓縮 CSS 與 JavaScript 的輸出';
-$lang['cssdatauri']            = 'CSS 中所引用的圖片假如小於該數字大小(bytes)，將會被直接嵌入 CSS 中來減少 HTTP Request 的發送。此功能在 IE 7 及之下版本不支援。推薦使用 <code>400</code> 到 <code>600</code> 之間。設定為<code>0</code> 則停用。';
-$lang['hidepages']             = '隱藏匹配的界面 (正規式)';
-$lang['send404']               = '存取不存在的頁面時送出 "HTTP 404/Page Not Found"';
-$lang['sitemap']               = '產生 Google 站台地圖 (天)';
-$lang['broken_iua']            = 'ignore_user_abort 功能失效了？這有可能導致搜索索引不可用。IIS+PHP/CGI 已損壞。請參閱 <a href=\"http://bugs.splitbrain.org/?do=details&task_id=852\">Bug 852</a> 獲取更多信息。';
-$lang['xsendfile']             = '使用 X-Sendfile 頭讓服務器發送狀態文件？您的服務器需要支持該功能。';
-$lang['renderer_xhtml']        = '主要維基輸出 (xhtml) 的的渲染器';
-$lang['renderer__core']        = '%s (dokuwiki 核心)';
-$lang['renderer__plugin']      = '%s (插件)';
-$lang['rememberme']            = '允許自動登入 (記住我)';
-$lang['rss_type']              = 'XML feed 類型';
-$lang['rss_linkto']            = 'XML feed 連結到';
-$lang['rss_content']           = 'XML feed 項目中顯示什麼呢？';
-$lang['rss_update']            = 'XML feed 更新間隔時間 (秒)';
-$lang['recent_days']           = '儲存多少天內的變更';
-$lang['rss_show_summary']      = '於標題中顯示簡要的 XML feed';
+$lang['cachetime']             = '緩存的最大存在時間 (秒)';
 $lang['target____wiki']        = '內部連結的目標視窗';
 $lang['target____interwiki']   = '跨維基連結的目標視窗';
 $lang['target____extern']      = '外部連結的目標視窗';
 $lang['target____media']       = '媒體連結的目標視窗';
 $lang['target____windows']     = 'Windows 連結的目標視窗';
+$lang['refcheck']              = '媒體連結檢查';
+$lang['refshow']               = '媒體連結的顯示數量';
+$lang['gdlib']                 = 'GD Lib 版本';
+$lang['im_convert']            = 'ImageMagick 的轉換工具路徑';
+$lang['jpg_quality']           = 'JPG 壓縮品質(0-100)';
+$lang['fetchsize']             = 'fetch.php 可以從外部下載的最大檔案尺寸 (bytes)';
+$lang['subscribers']           = '啟用頁面訂閱';
+$lang['subscribe_time']        = '訂閱列表和摘要發送的時間間隔 (秒)；這個值應該小於指定的最近更改保留時間 (recent_days)。';
+$lang['notify']                = '寄送變更通知信到這個 E-mail 位址';
+$lang['registernotify']        = '寄送新使用者註冊資訊到這個 E-mail 位址';
+$lang['mailfrom']              = '自動發送郵件時使用的郵件地址';
+$lang['mailprefix']            = '自動發送郵件時使用的標題前綴';
+$lang['sitemap']               = '產生 Google 站台地圖 (天)';
+$lang['rss_type']              = 'XML feed 類型';
+$lang['rss_linkto']            = 'XML feed 連結到';
+$lang['rss_content']           = 'XML feed 項目中顯示什麼呢？';
+$lang['rss_update']            = 'XML feed 更新間隔時間 (秒)';
+$lang['rss_show_summary']      = '於標題中顯示簡要的 XML feed';
+$lang['rss_media']             = '在 XML feed 中應列出哪些變更？';
+$lang['updatecheck']           = '檢查更新與安全性警告？DokuWiki 需要聯繫 update.dokuwiki.org 才能使用此功能。';
+$lang['userewrite']            = '使用好看的 URL';
+$lang['useslash']              = '在 URL 中使用斜線作為分類空間的分隔字元';
+$lang['sepchar']               = '頁面名稱中單字的分隔字元';
+$lang['canonical']             = '使用最典型的 URL';
+$lang['fnencode']              = '非 ASCII 文件名稱的編輯方法。';
+$lang['autoplural']            = '檢查複數形式的連結 (英文)';
+$lang['compression']           = 'attic 文件的壓縮方式';
+$lang['gzip_output']           = '對 xhtml 使用 gzip 內容編碼';
+$lang['compress']              = '壓縮 CSS 與 JavaScript 的輸出';
+$lang['cssdatauri']            = 'CSS 中所引用的圖片假如小於該數字大小(bytes)，將會被直接嵌入 CSS 中來減少 HTTP Request 的發送。此功能在 IE 7 及之下版本不支援。推薦使用 <code>400</code> 到 <code>600</code> 之間。設定為<code>0</code> 則停用。';
+$lang['send404']               = '存取不存在的頁面時送出 "HTTP 404/Page Not Found"';
+$lang['broken_iua']            = 'ignore_user_abort 功能失效了？這有可能導致搜索索引不可用。IIS+PHP/CGI 已損壞。請參閱 <a href=\"http://bugs.splitbrain.org/?do=details&task_id=852\">Bug 852</a> 獲取更多信息。';
+$lang['xsendfile']             = '使用 X-Sendfile 頭讓服務器發送狀態文件？您的服務器需要支持該功能。';
+$lang['renderer_xhtml']        = '主要維基輸出 (xhtml) 的的渲染器';
+$lang['renderer__core']        = '%s (dokuwiki 核心)';
+$lang['renderer__plugin']      = '%s (插件)';
 $lang['proxy____host']         = 'Proxy 伺服器名稱';
 $lang['proxy____port']         = 'Proxy 連接埠';
 $lang['proxy____user']         = 'Proxy 使用者名稱';
