@@ -13,6 +13,7 @@
  * @author Timon Van Overveldt <timonvo@gmail.com>
  * @author Jeroen
  * @author Ricardo Guijt <ricardoguijt@gmail.com>
+ * @author Gerrit <klapinklapin@gmail.com>
  */
 $lang['menu']                  = 'Plugins beheren';
 $lang['download']              = 'Download en installeer een nieuwe plugin';
@@ -58,4 +59,4 @@ $lang['enabled']               = 'Plugin %s ingeschakeld.';
 $lang['notenabled']            = 'Plugin %s kon niet worden ingeschakeld, controleer bestandsrechten.';
 $lang['disabled']              = 'Plugin %s uitgeschakeld.';
 $lang['notdisabled']           = 'Plugin %s kon niet worden uitgeschakeld, controleer bestandsrechten.';
-$lang['packageinstalled']      = 'Plugin package (%d plugin%s: %s) succesvol geïnstalleerd.';
+$lang['packageinstalled']      = 'Plugin package (%d plugin(s): %s) succesvol geïnstalleerd.';
